@@ -6,14 +6,6 @@
 
 #include "cbmserb.h"
 
-#ifdef RUNTIME_LOADER
-# ifdef __cplusplus
-	extern "C" void vc20_runtime_loader_init(void);
-# else
-	extern void vc20_runtime_loader_init(void);
-# endif
-#endif
-
 #define KEY_ARROW_LEFT (readinputport(5)&0x8000)
 #define KEY_1 (readinputport(5)&0x4000)
 #define KEY_2 (readinputport(5)&0x2000)
@@ -154,27 +146,25 @@
 extern UINT8 *vc20_memory;
 extern UINT8 *vc20_memory_9400;
 
-extern WRITE_HANDLER ( vc20_write_9400 );
+WRITE8_HANDLER ( vc20_write_9400 );
 
 /* split for more performance */
 /* VIC reads bits 8 till 11 */
-extern int vic6560_dma_read_color (int offset);
+int vic6560_dma_read_color (int offset);
 
 /* VIC reads bits 0 till 7 */
-extern int vic6560_dma_read (int offset);
+int vic6560_dma_read (int offset);
 
-extern int vc20_rom_init (int id);
-extern int vc20_rom_load (int id);
+DEVICE_INIT(vc20_rom);
+DEVICE_LOAD(vc20_rom);
 
-extern void vc20_driver_init (void);
-extern void vic20_driver_init (void);
-extern void vic20ieee_driver_init (void);
-extern void vc20_driver_shutdown (void);
+void vc20_driver_init (void);
+void vic20_driver_init (void);
+void vic20ieee_driver_init (void);
+void vc20_driver_shutdown (void);
 
-extern void vc20_init_machine (void);
-extern void vc20_shutdown_machine (void);
-
-extern int vc20_frame_interrupt (void);
+MACHINE_INIT( vc20 );
+INTERRUPT_GEN( vc20_frame_interrupt );
 
 #endif
 
