@@ -19,7 +19,7 @@
 
 	Keyboard/Mouse      (Intel 8242)   80000060, 80000064
 	Real Time Clock     (BQ3285)       80000070, 80000074
-	IDE ATA Interface	               800001F0-F7, 800003F6-7
+	IDE ATA Interface                  800001F0-F7, 800003F6-7
 	COM2                               800002F8-F
 	GeekPort A/D Control               80000360-1
 	GeekPort A/D Data                  80000362-3
@@ -113,7 +113,6 @@ static UINT32 bebox_interrupts;
 static UINT32 bebox_crossproc_interrupts;
 
 
-
 /*************************************
  *
  *	Interrupts and Motherboard Registers
@@ -139,7 +138,6 @@ static void bebox_mbreg32_w(UINT32 *target, UINT64 data, UINT64 mem_mask)
 }
 
 
-
 READ64_HANDLER( bebox_cpu0_imask_r )		{ return ((UINT64) bebox_cpu_imask[0]) << 32; }
 READ64_HANDLER( bebox_cpu1_imask_r )		{ return ((UINT64) bebox_cpu_imask[1]) << 32; }
 READ64_HANDLER( bebox_interrupt_sources_r )	{ return ((UINT64) bebox_interrupts) << 32; }
@@ -241,7 +239,6 @@ WRITE64_HANDLER( bebox_processor_resets_w )
 }
 
 
-
 static void bebox_update_interrupts(void)
 {
 	int cpunum;
@@ -262,7 +259,6 @@ static void bebox_update_interrupts(void)
 }
 
 
-
 static void bebox_set_irq_bit(unsigned int interrupt_bit, int val)
 {
 	static const char *interrupt_names[32] =
@@ -327,7 +323,6 @@ static void bebox_set_irq_bit(unsigned int interrupt_bit, int val)
 }
 
 
-
 /*************************************
  *
  *	COM ports
@@ -341,7 +336,6 @@ static void bebox_uart_transmit(int id, int data)
 }
 
 
-
 static void bebox_uart_handshake(int id, int data)
 {
 	if (LOG_UART)
@@ -349,10 +343,9 @@ static void bebox_uart_handshake(int id, int data)
 }
 
 
-
 static const uart8250_interface bebox_uart_inteface =
 {
-	TYPE8250,
+	TYPE16550,
 	0,
 	NULL,
 	bebox_uart_transmit,
@@ -360,7 +353,6 @@ static const uart8250_interface bebox_uart_inteface =
 };
 
 
-
 /*************************************
  *
  *	Floppy Disk Controller
@@ -376,14 +368,12 @@ static void bebox_fdc_interrupt(int state)
 }
 
 
-
 static void bebox_fdc_dma_drq(int state, int read_)
 {
 	dma8237_drq_write(0, FDC_DMA, state);
 }
 
 
-
 static mess_image *bebox_fdc_get_image(int floppy_index)
 {
 	/* the BeBox boot ROM seems to query for floppy #1 when it should be
@@ -392,7 +382,6 @@ static mess_image *bebox_fdc_get_image(int floppy_index)
 }
 
 
-
 static const struct pc_fdc_interface bebox_fdc_interface =
 {
 	SMC37C78,
@@ -402,7 +391,6 @@ static const struct pc_fdc_interface bebox_fdc_interface =
 };
 
 
-
 /*************************************
  *
  *	8259 PIC
@@ -418,14 +406,12 @@ READ64_HANDLER( bebox_interrupt_ack_r )
 }
 
 
-
 static void bebox_pic_set_int_line(int interrupt)
 {
 	bebox_set_irq_bit(5, interrupt);
 }
 
 
-
 /*************************************
  *
  *	Floppy/IDE/ATA
@@ -439,7 +425,6 @@ READ64_HANDLER( bebox_800001F0_r ) { return read64be_with_read8_handler(bebox_80
 WRITE64_HANDLER( bebox_800001F0_w ) { write64be_with_write8_handler(bebox_800001F0_8_w, offset, data, mem_mask); }
 
 
-
 READ64_HANDLER( bebox_800003F0_r )
 {
 	UINT64 result = pc64be_fdc_r(offset, mem_mask | 0xFFFF);
@@ -459,7 +444,6 @@ READ64_HANDLER( bebox_800003F0_r )
 }
 
 
-
 WRITE64_HANDLER( bebox_800003F0_w )
 {
 	pc64be_fdc_w(offset, data, mem_mask | 0xFFFF);
@@ -472,7 +456,6 @@ WRITE64_HANDLER( bebox_800003F0_w )
 }
 
 
-
 static void bebox_ide_interrupt(int state)
 {
 	bebox_set_irq_bit(7, state);
@@ -480,14 +463,12 @@ static void bebox_ide_interrupt(int state)
 }
 
 
-
 static struct ide_interface bebox_ide_interface =
 {
 	bebox_ide_interrupt
 };
 
 
-
 /*************************************
  *
  *	Video card (Cirrus Logic CL-GD5430)
@@ -504,7 +485,6 @@ static READ64_HANDLER( bebox_video_r )
 }
 
 
-
 static WRITE64_HANDLER( bebox_video_w )
 {
 	UINT64 *mem = (UINT64 *) pc_vga_memory();
@@ -514,21 +494,18 @@ static WRITE64_HANDLER( bebox_video_w )
 }
 
 
-
 static READ64_HANDLER( bebox_vga_memory_r )
 {
 	return read64be_with_read8_handler(bebox_vga_memory_rh, offset, mem_mask);
 }
 
 
-
 static WRITE64_HANDLER( bebox_vga_memory_w )
 {
 	write64be_with_write8_handler(bebox_vga_memory_wh, offset, data, mem_mask);
 }
 
 
-
 static void bebox_map_vga_memory(offs_t begin, offs_t end, read8_handler rh, write8_handler wh)
 {
 	read64_handler rh64 = (rh == MRA8_BANK4) ? MRA64_BANK4 : bebox_vga_memory_r;
@@ -545,7 +522,6 @@ static void bebox_map_vga_memory(offs_t begin, offs_t end, read8_handler rh, wri
 }
 
 
-
 static const struct pc_vga_interface bebox_vga_interface =
 {
 	4,
@@ -558,7 +534,6 @@ static const struct pc_vga_interface bebox_vga_interface =
 };
 
 
-
 /*************************************
  *
  *	8237 DMA
@@ -568,7 +543,6 @@ static const struct pc_vga_interface bebox_vga_interface =
 static UINT16 dma_offset[2][4];
 static UINT8 at_pages[0x10];
 
-
 static READ8_HANDLER(at_page8_r)
 {
 	UINT8 data = at_pages[offset % 0x10];
@@ -592,7 +566,6 @@ static READ8_HANDLER(at_page8_r)
 }
 
 
-
 static WRITE8_HANDLER(at_page8_w)
 {
 	at_pages[offset % 0x10] = data;
@@ -619,21 +592,18 @@ static WRITE8_HANDLER(at_page8_w)
 }
 
 
-
 READ64_HANDLER(bebox_page_r)
 {
 	return read64be_with_read8_handler(at_page8_r, offset, mem_mask);
 }
 
 
-
 WRITE64_HANDLER(bebox_page_w)
 {
 	write64be_with_write8_handler(at_page8_w, offset, data, mem_mask);
 }
 
 
-
 static WRITE8_HANDLER(at_hipage8_w)
 {
 	switch(offset % 8)
@@ -658,21 +628,18 @@ static WRITE8_HANDLER(at_hipage8_w)
 }
 
 
-
 READ64_HANDLER(bebox_80000480_r)
 {
 	osd_die("NYI");
 }
 
 
-
 WRITE64_HANDLER(bebox_80000480_w)
 {
 	write64be_with_write8_handler(at_hipage8_w, offset, data, mem_mask);
 }
 
 
-
 static UINT8 bebox_dma_read_byte(int channel, offs_t offset)
 {
 	offs_t page_offset = (((offs_t) dma_offset[0][channel]) << 16)
@@ -681,7 +648,6 @@ static UINT8 bebox_dma_read_byte(int channel, offs_t offset)
 }
 
 
-
 static void bebox_dma_write_byte(int channel, offs_t offset, UINT8 data)
 {
 	offs_t page_offset = (((offs_t) dma_offset[0][channel]) << 16)
@@ -690,7 +656,6 @@ static void bebox_dma_write_byte(int channel, offs_t offset, UINT8 data)
 }
 
 
-
 static const struct dma8237_interface bebox_dma =
 {
 	0,
@@ -705,7 +670,6 @@ static const struct dma8237_interface bebox_dma =
 };
 
 
-
 /*************************************
  *
  *	8254 PIT
@@ -718,7 +682,6 @@ static void bebox_timer0_w(int state)
 }
 
 
-
 static const struct pit8253_config bebox_pit8254_config =
 {
 	TYPE8254,
@@ -742,7 +705,6 @@ static const struct pit8253_config bebox_pit8254_config =
 };
 
 
-
 /*************************************
  *
  *	Flash ROM
@@ -756,7 +718,6 @@ static READ8_HANDLER( bebox_flash8_r )
 }
 
 
-
 static WRITE8_HANDLER( bebox_flash8_w )
 {
 	offset = (offset & ~7) | (7 - (offset & 7));
@@ -764,21 +725,18 @@ static WRITE8_HANDLER( bebox_flash8_w )
 }
 
 
-
 READ64_HANDLER( bebox_flash_r )
 {
 	return read64be_with_read8_handler(bebox_flash8_r, offset, mem_mask);
 }
 
 
-
 WRITE64_HANDLER( bebox_flash_w )
 {
 	write64be_with_write8_handler(bebox_flash8_w, offset, data, mem_mask);
 }
 
 
-
 /*************************************
  *
  *	Keyboard
@@ -792,7 +750,6 @@ static void bebox_keyboard_interrupt(int state)
 }
 
 
-
 static const struct kbdc8042_interface bebox_8042_interface =
 {
 	KBDC8042_STANDARD,
@@ -801,7 +758,6 @@ static const struct kbdc8042_interface bebox_8042_interface =
 };
 
 
-
 /*************************************
  *
  *	SCSI
@@ -843,7 +799,6 @@ static READ64_HANDLER( scsi53c810_r )
 }
 
 
-
 static WRITE64_HANDLER( scsi53c810_w )
 {
 	int reg = offset*8;
@@ -874,7 +829,6 @@ static WRITE64_HANDLER( scsi53c810_w )
 }
 
 
-
 #define BYTE_REVERSE32(x)		(((x >> 24) & 0xff) | \
 								((x >> 8) & 0xff00) | \
 								((x << 8) & 0xff0000) | \
@@ -888,7 +842,6 @@ static UINT32 scsi53c810_fetch(UINT32 dsp)
 }
 
 
-
 static void scsi53c810_irq_callback(void)
 {
 	bebox_set_irq_bit(21, 1);
@@ -896,13 +849,11 @@ static void scsi53c810_irq_callback(void)
 }
 
 
-
 static void scsi53c810_dma_callback(UINT32 src, UINT32 dst, int length, int byteswap)
 {
 }
 
 
-
 static UINT32 scsi53c810_pci_read(int function, int offset)
 {
 	UINT32 result = 0;
@@ -928,7 +879,6 @@ static UINT32 scsi53c810_pci_read(int function, int offset)
 }
 
 
-
 static void scsi53c810_pci_write(int function, int offset, UINT32 data)
 {
 	offs_t addr;
@@ -965,13 +915,28 @@ static void scsi53c810_pci_write(int function, int offset, UINT32 data)
 }
 
 
-
 static const struct pci_device_info scsi53c810_callbacks =
 {
 	scsi53c810_pci_read,
 	scsi53c810_pci_write
 };
 
+static SCSIConfigTable dev_table =
+{
+	2, /* 2 SCSI devices */
+	{
+		{ SCSI_ID_0, 0, SCSI_DEVICE_HARDDISK },	/* SCSI ID 0, using HD 0, HD */
+		{ SCSI_ID_3, 0, SCSI_DEVICE_CDROM }	/* SCSI ID 3, using CHD 0, CD-ROM */
+	}
+};
+
+static struct LSI53C810interface scsi53c810_intf =
+{
+	&dev_table,		/* SCSI device table */
+	&scsi53c810_irq_callback,
+	&scsi53c810_dma_callback,
+	&scsi53c810_fetch,
+};
 
 
 /*************************************
@@ -985,16 +950,12 @@ NVRAM_HANDLER( bebox )
 	nvram_handler_intelflash(0, file, read_or_write);
 }
 
-
-
 MACHINE_INIT( bebox )
 {
 	cpunum_set_input_line(0, INPUT_LINE_RESET, CLEAR_LINE);
 	cpunum_set_input_line(1, INPUT_LINE_RESET, ASSERT_LINE);
 }
 
-
-
 DRIVER_INIT( bebox )
 {
 	int cpu;
@@ -1045,7 +1006,7 @@ DRIVER_INIT( bebox )
 	}
 
 	/* SCSI */
-	lsi53c810_init(scsi53c810_fetch, scsi53c810_irq_callback, scsi53c810_dma_callback);
+	lsi53c810_init(&scsi53c810_intf);
 
 	/* The following is a verrrry ugly hack put in to support NetBSD for
 	 * NetBSD.  When NetBSD/bebox it does most of its work on CPU #0 and then
