@@ -8,6 +8,7 @@
 #include <ctype.h>
 #include "driver.h"
 #include "cpu/m6502/m6502.h"
+#include "sound/sid6581.h"
 
 #define VERBOSE_DBG 1
 #include "includes/cbm.h"
@@ -15,8 +16,7 @@
 #include "includes/cbmserb.h"
 #include "includes/vc1541.h"
 #include "includes/vic4567.h"
-#include "includes/sid6581.h"
-#include "includes/state.h"
+#include "mscommon.h"
 
 #include "includes/c65.h"
 
@@ -35,7 +35,7 @@ UINT8 *c65_interface;
 /* processor has only 1 mega address space !? */
 /* and system 8 megabyte */
 /* dma controller and bankswitch hardware ?*/
-static READ_HANDLER(c65_read_mem)
+static  READ8_HANDLER(c65_read_mem)
 {
 	int data=0;
 
@@ -50,7 +50,7 @@ static READ_HANDLER(c65_read_mem)
 	return data;
 }
 
-static WRITE_HANDLER(c65_write_mem)
+static WRITE8_HANDLER(c65_write_mem)
 {
 	if (offset<0x20000)
 		c64_memory[offset]=data;
@@ -62,7 +62,7 @@ static WRITE_HANDLER(c65_write_mem)
 		if (C65_MAIN_MEMORY==C65_4096KB) c64_memory[offset]=data;
 	}
 #if 0
-	if (offset<0x100000) cpu_writemem20(offset,data);
+	if (offset<0x100000) program_write_byte_8(offset,data);
 	else c64_memory[offset]=data;
 #endif
 }
@@ -336,7 +336,7 @@ static void c65_fdc_state(void)
 
 static void c65_fdc_w(int offset, int data)
 {
-	DBG_LOG (1, "fdc write", ("%.5x %.2x %.2x\n", cpu_get_pc(), offset, data));
+	DBG_LOG (1, "fdc write", ("%.5x %.2x %.2x\n", activecpu_get_pc(), offset, data));
 	switch (offset&0xf) {
 	case 0:
 		c65_fdc.reg[0]=data;
@@ -417,7 +417,7 @@ static int c65_fdc_r(int offset)
 		data=c65_fdc.reg[offset&0xf];
 		break;
 	}
-	DBG_LOG (1, "fdc read", ("%.5x %.2x %.2x\n", cpu_get_pc(), offset, data));
+	DBG_LOG (1, "fdc read", ("%.5x %.2x %.2x\n", activecpu_get_pc(), offset, data));
 	return data;
 }
 
@@ -439,30 +439,30 @@ static int c65_fdc_r(int offset)
 static struct {
 	UINT8 reg;
 } expansion_ram= {0};
-static READ_HANDLER(c65_ram_expansion_r)
+static  READ8_HANDLER(c65_ram_expansion_r)
 {
 	int data=0xff;
 	if (C65_MAIN_MEMORY==C65_4096KB)
 		data=expansion_ram.reg;
-	DBG_LOG (1, "expansion read", ("%.5x %.2x %.2x\n", cpu_get_pc(),offset,data));
+	DBG_LOG (1, "expansion read", ("%.5x %.2x %.2x\n", activecpu_get_pc(),offset,data));
 	return data;
 }
 
-static WRITE_HANDLER(c65_ram_expansion_w)
+static WRITE8_HANDLER(c65_ram_expansion_w)
 {
-	DBG_LOG (1, "expansion write", ("%.5x %.2x %.2x\n", cpu_get_pc(), offset, data));
+	DBG_LOG (1, "expansion write", ("%.5x %.2x %.2x\n", activecpu_get_pc(), offset, data));
 	expansion_ram.reg=data;
 
 #if 0
 	if ( (data==0)&&(C65_MAIN_MEMORY==C65_512KB) ) {
-		memory_set_bankhandler_w (16, 0, MWA_BANK16);
+		memory_set_bankhandler_w (16, 0, MWA8_BANK16);
 	} else {
-		memory_set_bankhandler_w (16, 0, MWA_NOP);
+		memory_set_bankhandler_w (16, 0, MWA8_NOP);
 	}
 #endif
 }
 
-WRITE_HANDLER ( c65_write_io )
+static WRITE8_HANDLER ( c65_write_io )
 {
 	switch(offset&0xf00) {
 	case 0x000:
@@ -498,7 +498,7 @@ WRITE_HANDLER ( c65_write_io )
 	}
 }
 
-WRITE_HANDLER ( c65_write_io_dc00 )
+static WRITE8_HANDLER ( c65_write_io_dc00 )
 {
 	switch(offset&0xf00) {
 	case 0x000:
@@ -514,7 +514,7 @@ WRITE_HANDLER ( c65_write_io_dc00 )
 	}
 }
 
-static READ_HANDLER ( c65_read_io )
+static  READ8_HANDLER ( c65_read_io )
 {
 	switch(offset&0xf00) {
 	case 0x000:
@@ -549,7 +549,7 @@ static READ_HANDLER ( c65_read_io )
 	return 0xff;
 }
 
-static READ_HANDLER ( c65_read_io_dc00 )
+static  READ8_HANDLER ( c65_read_io_dc00 )
 {
 	switch(offset&0x300) {
 	case 0x000:
@@ -578,35 +578,46 @@ static int c65_io_on=0, c65_io_dc00_on=0;
 static void c65_bankswitch_interface(int value)
 {
 	static int old=0;
+	read8_handler rh;
+	write8_handler wh;
+
 	DBG_LOG (2, "c65 bankswitch", ("%.2x\n",value));
-	if (c65_io_on) {
-		if (value&1) {
-			cpu_setbank (8, c64_colorram+0x400);
-			cpu_setbank (9, c64_colorram+0x400);
-			memory_set_bankhandler_r (8, 0, MRA_BANK8);
-			memory_set_bankhandler_w (9, 0, MWA_BANK9);
-		} else {
-			memory_set_bankhandler_r (8, 0, c65_read_io_dc00);
-			memory_set_bankhandler_w (9, 0, c65_write_io_dc00);
+
+	if (c65_io_on)
+	{
+		if (value&1)
+		{
+			memory_set_bankptr (8, c64_colorram + 0x400);
+			memory_set_bankptr (9, c64_colorram + 0x400);
+			rh = MRA8_BANK8;
+			wh = MWA8_BANK9;
 		}
+		else
+		{
+			rh = c65_read_io_dc00;
+			wh = c65_write_io_dc00;
+		}
+		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0dc00, 0x0dfff, 0, 0, rh);
+		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0dc00, 0x0dfff, 0, 0, wh);
 	}
+
 	c65_io_dc00_on=!(value&1);
 #if 0
 	/* cartridge roms !?*/
-	if (value&0x08) { cpu_setbank (1, c64_roml); }
-	else { cpu_setbank (1, c64_memory + 0x8000); }
-	if (value&0x10) { cpu_setbank (2, c64_basic); }
-	else { cpu_setbank (2, c64_memory + 0xa000); }
+	if (value&0x08) { memory_set_bankptr (1, c64_roml); }
+	else { memory_set_bankptr (1, c64_memory + 0x8000); }
+	if (value&0x10) { memory_set_bankptr (2, c64_basic); }
+	else { memory_set_bankptr (2, c64_memory + 0xa000); }
 #endif
 	if ((old^value)&0x20) { /* bankswitching faulty when doing actual page */
-		if (value&0x20) { cpu_setbank (3, c65_interface); }
-		else { cpu_setbank (3, c64_memory + 0xc000); }
+		if (value&0x20) { memory_set_bankptr (3, c65_interface); }
+		else { memory_set_bankptr (3, c64_memory + 0xc000); }
 	}
 	c65_charset_select=value&0x40;
 #if 0
 	/* cartridge roms !?*/
-	if (value&0x80) { cpu_setbank (8, c64_kernal); }
-	else { cpu_setbank (6, c64_memory + 0xe000); }
+	if (value&0x80) { memory_set_bankptr (8, c64_kernal); }
+	else { memory_set_bankptr (6, c64_memory + 0xe000); }
 #endif
 	old=value;
 }
@@ -615,6 +626,8 @@ void c65_bankswitch (void)
 {
 	static int old = -1;
 	int data, loram, hiram, charen;
+	read8_handler rh4, rh8;
+	write8_handler wh5, wh9;
 
 	data = ((c64_port6510 & c64_ddr6510) | (c64_ddr6510 ^ 0xff)) & 7;
 	if (data == old)
@@ -628,80 +641,88 @@ void c65_bankswitch (void)
 	if ((!c64_game && c64_exrom)
 		|| (loram && hiram && !c64_exrom))
 	{
-		cpu_setbank (1, c64_roml);
+		memory_set_bankptr (1, c64_roml);
 	}
 	else
 	{
-		cpu_setbank (1, c64_memory + 0x8000);
+		memory_set_bankptr (1, c64_memory + 0x8000);
 	}
 
 	if ((!c64_game && c64_exrom && hiram)
 		|| (!c64_exrom))
 	{
-		cpu_setbank (2, c64_romh);
+		memory_set_bankptr (2, c64_romh);
 	}
 	else if (loram && hiram)
 	{
-		cpu_setbank (2, c64_basic);
+		memory_set_bankptr (2, c64_basic);
 	}
 	else
 	{
-		cpu_setbank (2, c64_memory + 0xa000);
+		memory_set_bankptr (2, c64_memory + 0xa000);
 	}
+
 	if ((!c64_game && c64_exrom)
 		|| (charen && (loram || hiram)))
 	{
-		c65_io_on=1;
-		memory_set_bankhandler_r (4, 0, c65_read_io);
-		memory_set_bankhandler_w (5, 0, c65_write_io);
-		cpu_setbank (6, c64_colorram);
-		cpu_setbank (7, c64_colorram);
+		c65_io_on = 1;
+		rh4 = c65_read_io;
+		wh5 = c65_write_io;
+		memory_set_bankptr (6, c64_colorram);
+		memory_set_bankptr (7, c64_colorram);
 
-		if (c65_io_dc00_on) {
-			memory_set_bankhandler_r (8, 0, c65_read_io_dc00);
-			memory_set_bankhandler_w (9, 0, c65_write_io_dc00);
-		} else {
-			memory_set_bankhandler_r (8, 0, MRA_BANK8);
-			memory_set_bankhandler_w (9, 0, MWA_BANK9);
-			cpu_setbank (8, c64_colorram+0x400);
-			cpu_setbank (9, c64_colorram+0x400);
-		}
-	}
-	else
-	{
-		c65_io_on=0;
-		memory_set_bankhandler_r (4, 0, MRA_BANK4);
-		memory_set_bankhandler_w (5, 0, MWA_BANK5);
-		cpu_setbank(5, c64_memory+0xd000);
-		cpu_setbank(7, c64_memory+0xd800);
-		cpu_setbank(9, c64_memory+0xdc00);
-		if (!charen && (loram || hiram))
+		if (c65_io_dc00_on)
 		{
-			cpu_setbank (4, c64_chargen);
-			cpu_setbank (6, c64_chargen+0x800);
-			cpu_setbank (8, c64_chargen+0xc00);
+			rh8 = c65_read_io_dc00;
+			wh9 = c65_write_io_dc00;
 		}
 		else
 		{
-			cpu_setbank (4, c64_memory + 0xd000);
-			cpu_setbank (6, c64_memory + 0xd800);
-			cpu_setbank (8, c64_memory + 0xdc00);
+			rh8 = MRA8_BANK8;
+			wh9 = MWA8_BANK9;
+			memory_set_bankptr (8, c64_colorram+0x400);
+			memory_set_bankptr (9, c64_colorram+0x400);
+		}
+		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0dc00, 0x0dfff, 0, 0, rh8);
+		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0dc00, 0x0dfff, 0, 0, wh9);
+	}
+	else
+	{
+		c65_io_on = 0;
+		rh4 = MRA8_BANK4;
+		wh5 = MWA8_BANK5;
+		memory_set_bankptr(5, c64_memory+0xd000);
+		memory_set_bankptr(7, c64_memory+0xd800);
+		memory_set_bankptr(9, c64_memory+0xdc00);
+		if (!charen && (loram || hiram))
+		{
+			memory_set_bankptr (4, c64_chargen);
+			memory_set_bankptr (6, c64_chargen+0x800);
+			memory_set_bankptr (8, c64_chargen+0xc00);
+		}
+		else
+		{
+			memory_set_bankptr (4, c64_memory + 0xd000);
+			memory_set_bankptr (6, c64_memory + 0xd800);
+			memory_set_bankptr (8, c64_memory + 0xdc00);
 		}
 	}
+	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0d000, 0x0d7ff, 0, 0, rh4);
+	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0d000, 0x0d7ff, 0, 0, wh5);
 
 	if (!c64_game && c64_exrom)
 	{
-		cpu_setbank (10, c64_romh);
+		memory_set_bankptr (10, c64_romh);
 	}
 	else
 	{
 		if (hiram)
 		{
-			cpu_setbank (10, c64_kernal);
+			memory_set_bankptr (10, c64_kernal);
 		}
 		else
 		{
-			cpu_setbank (10, c64_memory + 0xe000);
+			memory_set_bankptr (10, c64_memory + 0xe000);
 		}
 	}
 	old = data;
@@ -751,17 +772,14 @@ static void c65_common_driver_init (void)
 	c65=1;
 	c64_tape_on=0;
 	/*memset(c64_memory+0x40000, 0, 0x800000-0x40000); */
-	cbm_drive_open ();
 
-	cbm_drive_attach_fs (0);
-	cbm_drive_attach_fs (1);
+	cia6526_init();
 
 	c64_cia0.todin50hz = c64_cia1.todin50hz = c64_pal;
 	cia6526_config (0, &c64_cia0);
 	cia6526_config (1, &c64_cia1);
 	vic4567_init (c64_pal, c65_dma_read, c65_dma_read_color,
 				  c64_vic_interrupt, c65_bankswitch_interface);
-	state_add_function(c65_state);
 }
 
 void c65_driver_init (void)
@@ -784,17 +802,12 @@ void c65pal_driver_init (void)
 	c65_common_driver_init ();
 }
 
-void c65_driver_shutdown (void)
-{
-	cbm_drive_close ();
-}
-
-void c65_init_machine (void)
+MACHINE_INIT( c65 )
 {
 	memset(c64_memory+0x40000, 0xff, 0xc0000);
 
-	sid6581_reset(0);
-	sid6581_reset(1);
+	sndti_reset(SOUND_SID8580, 0);
+	sndti_reset(SOUND_SID8580, 1);
 
 	cbm_serial_reset_write (0);
 	cbm_drive_0_config (SERIAL8ON ? SERIAL : 0, 10);
@@ -812,25 +825,3 @@ void c65_init_machine (void)
 	c65_bankswitch_interface(0xff);
 	c65_bankswitch ();
 }
-
-void c65_shutdown_machine (void)
-{
-}
-
-void c65_state (void)
-{
-	char text[70];
-
-#if VERBOSE_DBG
-	cia6526_status (text, sizeof (text));
-	state_display_text (text);
-
-	snprintf (text, sizeof(text), "c65 vic:%.4x m6510:%d c64:%d",
-			  c64_vicaddr - c64_memory, c64_port6510 & 7, c64mode);
-#endif
-	cbm_drive_0_status (text, sizeof (text));
-	state_display_text (text);
-
-	cbm_drive_1_status (text, sizeof (text));
-	state_display_text (text);
-}
