@@ -133,34 +133,32 @@ bool pc1350_brk(void)
 /* currently enough to save the external ram */
 static void pc1350_load(void)
 {
-	FILE *file;
+	mame_file *file;
 	UINT8 *ram=memory_region(REGION_CPU1)+0x2000,
 		*cpu=sc61860_internal_ram();
 
-	if ( (file=(FILE*)osd_fopen(Machine->gamedrv->name,
-						 Machine->gamedrv->name, OSD_FILETYPE_NVRAM, 0))==NULL) {
+	if ( (file=mame_fopen(Machine->gamedrv->name, 0, FILETYPE_NVRAM, 0))==NULL) {
 		power=0;
 		return;
 	}
 
-	osd_fread(file, cpu, 96);
-	osd_fread(file, ram, 0x5000);
-	osd_fclose(file);
+	mame_fread(file, cpu, 96);
+	mame_fread(file, ram, 0x5000);
+	mame_fclose(file);
 }
 
 static void pc1350_save(void)
 {
-	FILE *file;
+	mame_file *file;
 	UINT8 *ram=memory_region(REGION_CPU1)+0x2000,
 		*cpu=sc61860_internal_ram();
 
-	if ( (file=(FILE*)osd_fopen(Machine->gamedrv->name,
-						 Machine->gamedrv->name, OSD_FILETYPE_NVRAM, 1))==NULL)
+	if ( (file=mame_fopen(Machine->gamedrv->name, 0, FILETYPE_NVRAM, 1))==NULL)
 		return;
 
-	osd_fwrite(file, cpu, 96);
-	osd_fwrite(file, ram, 0x5000);
-	osd_fclose(file);
+	mame_fwrite(file, cpu, 96);
+	mame_fwrite(file, ram, 0x5000);
+	mame_fclose(file);
 }
 
 static void pc1350_power_up(int param)
@@ -168,7 +166,7 @@ static void pc1350_power_up(int param)
 	power=0;
 }
 
-void init_pc1350(void)
+DRIVER_INIT( pc1350 )
 {
 	int i;
 	UINT8 *gfx=memory_region(REGION_GFX1);
@@ -179,19 +177,24 @@ void init_pc1350(void)
 	timer_set(1,0,pc1350_power_up);
 }
 
-void pc1350_machine_init(void)
+MACHINE_INIT( pc1350 )
 {
-	if (PC1350_RAM20K) {
-		install_mem_write_handler (0, 0x2000, 0x5fff, MWA_RAM);
-	} else if (PC1350_RAM12K) {
-		install_mem_write_handler (0, 0x2000, 0x3fff, MWA_NOP);
-		install_mem_write_handler (0, 0x4000, 0x5fff, MWA_RAM);
-	} else {
-		install_mem_write_handler (0, 0x2000, 0x5fff, MWA_NOP);
+	if (PC1350_RAM20K)
+	{
+		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x2000, 0x5fff, 0, 0, MWA8_RAM);
+	}
+	else if (PC1350_RAM12K)
+	{
+		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x2000, 0x3fff, 0, 0, MWA8_NOP);
+		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4000, 0x5fff, 0, 0, MWA8_RAM);
+	}
+	else
+	{
+		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x2000, 0x5fff, 0, 0, MWA8_NOP);
 	}
 }
 
-void pc1350_machine_stop(void)
+MACHINE_STOP( pc1350 )
 {
 	pc1350_save();
 }
