@@ -10,32 +10,32 @@
 #include "includes/riot6532.h"
 #include "includes/aim65.h"
 
-static MEMORY_READ_START( aim65_readmem )
+static ADDRESS_MAP_START( aim65_readmem , ADDRESS_SPACE_PROGRAM, 8)
 	/*     -03ff 1k version */
 	/*     -0fff 4k version */
-	{ 0x0000, 0x0fff, MRA_RAM },
+	AM_RANGE( 0x0000, 0x0fff) AM_READ( MRA8_RAM )
 /*	{ 0xa000, 0xa00f, via_1_r }, // user via */
-	{ 0xa400, 0xa47f, MRA_RAM }, /* riot6532 ram */
-	{ 0xa480, 0xa48f, riot_0_r },
-	{ 0xa800, 0xa80f, via_0_r },
-	{ 0xac00, 0xac03, pia_0_r },
-	{ 0xac04, 0xac43, MRA_RAM },
-	{ 0xb000, 0xffff, MRA_ROM },
-MEMORY_END
+	AM_RANGE( 0xa400, 0xa47f) AM_READ( MRA8_RAM ) /* riot6532 ram */
+	AM_RANGE( 0xa480, 0xa48f) AM_READ( riot_0_r )
+	AM_RANGE( 0xa800, 0xa80f) AM_READ( via_0_r )
+	AM_RANGE( 0xac00, 0xac03) AM_READ( pia_0_r )
+	AM_RANGE( 0xac04, 0xac43) AM_READ( MRA8_RAM )
+	AM_RANGE( 0xb000, 0xffff) AM_READ( MRA8_ROM )
+ADDRESS_MAP_END
 
-static MEMORY_WRITE_START( aim65_writemem )
-	{ 0x0000, 0x0fff, MWA_RAM },
+static ADDRESS_MAP_START( aim65_writemem , ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE( 0x0000, 0x0fff) AM_WRITE( MWA8_RAM )
 /*	{ 0xa000, 0xa00f, via_1_w }, // user via */
-	{ 0xa400, 0xa47f, MWA_RAM }, /* riot6532 ram */
-	{ 0xa480, 0xa48f, riot_0_w },
-	{ 0xa800, 0xa80f, via_0_w },
-	{ 0xac00, 0xac03, pia_0_w },
-	{ 0xac04, 0xac43, MWA_RAM },
-	{ 0xb000, 0xffff, MWA_ROM },
-MEMORY_END
+	AM_RANGE( 0xa400, 0xa47f) AM_WRITE( MWA8_RAM ) /* riot6532 ram */
+	AM_RANGE( 0xa480, 0xa48f) AM_WRITE( riot_0_w )
+	AM_RANGE( 0xa800, 0xa80f) AM_WRITE( via_0_w )
+	AM_RANGE( 0xac00, 0xac03) AM_WRITE( pia_0_w )
+	AM_RANGE( 0xac04, 0xac43) AM_WRITE( MWA8_RAM )
+	AM_RANGE( 0xb000, 0xffff) AM_WRITE( MWA8_ROM )
+ADDRESS_MAP_END
 
 #define DIPS_HELPER(bit, name, keycode, r) \
-   PORT_BITX(bit, IP_ACTIVE_HIGH, IPT_KEYBOARD, name, keycode, r)
+   PORT_BIT(bit, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME(name) PORT_CODE(keycode) PORT_CODE(r)
 
 INPUT_PORTS_START( aim65 )
 	PORT_START
@@ -97,19 +97,12 @@ INPUT_PORTS_START( aim65 )
 	DIPS_HELPER( 0x0800, "Right Shift", KEYCODE_RSHIFT, CODE_NONE)
 	DIPS_HELPER( 0x1000, "Space", KEYCODE_SPACE, CODE_NONE)
 	PORT_START
-    PORT_BITX(0x08, 0x08, IPT_DIPSWITCH_NAME | IPF_TOGGLE, "Terminal", CODE_NONE, CODE_NONE )
+    PORT_DIPNAME(0x08, 0x08, "Terminal")
 	PORT_DIPSETTING( 0x00, "TTY")
 	PORT_DIPSETTING( 0x08, "Keyboard")
-#if 0
-    PORT_BITX(0x03, 0x03, IPT_DIPSWITCH_NAME | IPF_TOGGLE, "RAM", CODE_NONE, CODE_NONE )
-	PORT_DIPSETTING( 0x00, "1 KBYTE")
-	PORT_DIPSETTING( 0x01, "2 KBYTE")
-	PORT_DIPSETTING( 0x02, "3 KBYTE")
-	PORT_DIPSETTING( 0x03, "4 KBYTE")
-#endif
 INPUT_PORTS_END
 
-static struct GfxLayout aim65_charlayout =
+static gfx_layout aim65_charlayout =
 {
         32,2,
         256,                                    /* 256 characters */
@@ -131,7 +124,7 @@ static struct GfxLayout aim65_charlayout =
         1*8
 };
 
-static struct GfxDecodeInfo aim65_gfxdecodeinfo[] = {
+static gfx_decode aim65_gfxdecodeinfo[] = {
 	{ REGION_GFX1, 0x0000, &aim65_charlayout,                     0, 2 },
     { -1 } /* end of array */
 };
@@ -140,78 +133,44 @@ static unsigned short aim65_colortable[1][2] = {
 	{ 0, 1 },
 };
 
-static struct MachineDriver machine_driver_aim65 =
-{
+
+static MACHINE_DRIVER_START( aim65 )
 	/* basic machine hardware */
-	{
-		{
-			CPU_M6502,
-			1000000,
-			aim65_readmem,aim65_writemem,0,0,
-			aim65_frame_int, 1,
-			0,0,
-        }
-	},
-	/* frames per second, VBL duration */
-	60, DEFAULT_60HZ_VBLANK_DURATION,
-	1,				/* single CPU */
-	aim65_machine_init,
-	0,/*pc1401_machine_stop, */
+	MDRV_CPU_ADD(M6502, 1000000)
+	MDRV_CPU_PROGRAM_MAP(aim65_readmem,aim65_writemem)
+	MDRV_FRAMES_PER_SECOND(60)
+	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
+	MDRV_INTERLEAVE(1)
 
-	600, 320, { 0, 600 - 1, 0, 320 - 1},
-	aim65_gfxdecodeinfo,			   /* graphics decode info */
-	sizeof (aim65_palette) / sizeof (aim65_palette[0]) + 32768,
-	sizeof (aim65_colortable) / sizeof(aim65_colortable[0][0]),
-	aim65_init_colors,		/* convert color prom */
+    /* video hardware */
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_SIZE(600, 320)
+	MDRV_VISIBLE_AREA(0, 600-1, 0, 320-1)
+	MDRV_GFXDECODE( aim65_gfxdecodeinfo )
+	MDRV_PALETTE_LENGTH(242 + 32768)
+	MDRV_COLORTABLE_LENGTH(sizeof (aim65_colortable) / sizeof(aim65_colortable[0][0]))
+	MDRV_PALETTE_INIT( aim65 )
 
-	VIDEO_TYPE_RASTER| VIDEO_SUPPORTS_DIRTY,	/* video flags */
-	0,						/* obsolete */
-    aim65_vh_start,
-	aim65_vh_stop,
-	aim65_vh_screenrefresh,
+	MDRV_VIDEO_START( aim65 )
+	MDRV_VIDEO_UPDATE( aim65 )
 
 	/* sound hardware */
-	0,0,0,0,
-	{
-		/* 300 hertz beeper */
-        { 0 }
-    }
-};
+	/* 300 hertz beeper */
+MACHINE_DRIVER_END
+
 
 ROM_START(aim65)
 	ROM_REGION(0x10000,REGION_CPU1, 0)
-/*	ROM_LOAD ("aim65bas.z26", 0xb000, 0x1000, 0x36a61f39) */
-/*	ROM_LOAD ("aim65bas.z25", 0xc000, 0x1000, 0xd7b42d2a) */
-/*	ROM_LOAD ("aim65ass.z24", 0xd000, 0x1000, 0x0878b399) */
-	ROM_LOAD ("aim65mon.z23", 0xe000, 0x1000, 0x90e44afe)
-	ROM_LOAD ("aim65mon.z22", 0xf000, 0x1000, 0xd01914b0)
+/*	ROM_LOAD ("aim65bas.z26", 0xb000, 0x1000, CRC(36a61f39)) */
+/*	ROM_LOAD ("aim65bas.z25", 0xc000, 0x1000, CRC(d7b42d2a)) */
+/*	ROM_LOAD ("aim65ass.z24", 0xd000, 0x1000, CRC(0878b399)) */
+	ROM_LOAD ("aim65mon.z23", 0xe000, 0x1000, CRC(90e44afe) SHA1(78e38601edf6bfc787b58750555a636b0cf74c5c))
+	ROM_LOAD ("aim65mon.z22", 0xf000, 0x1000, CRC(d01914b0) SHA1(e5b5ddd4cd43cce073a718ee4ba5221f2bc84eaf))
 	ROM_REGION(0x100,REGION_GFX1, 0)
 ROM_END
 
+SYSTEM_CONFIG_START(aim65)
+SYSTEM_CONFIG_END
 
-static const struct IODevice io_aim65[] = {
-    { IO_END }
-};
-
-#if 0
-void init_aim65(void)
-{
-	int i;
-	UINT8 *gfx=memory_region(REGION_GFX1);
-	for (i=0; i<256; i++) gfx[i]=i;
-
-}
-#endif
-
-/*    YEAR  NAME      PARENT    MACHINE   INPUT     INIT      MONITOR	COMPANY   FULLNAME */
-COMPX( 197?, aim65,	  0, 		aim65,  aim65, 	aim65,	  "Rockwell",  "AIM 65", GAME_NOT_WORKING|GAME_NO_SOUND)
-
-#ifdef RUNTIME_LOADER
-extern void aim65_runtime_loader_init(void)
-{
-	int i;
-	for (i=0; drivers[i]; i++) {
-		if ( strcmp(drivers[i]->name,"aim65")==0) drivers[i]=&driver_aim65;
-	}
-}
-#endif
+/*    YEAR	NAME	PARENT	COMPAT	MACHINE	INPUT	INIT	CONFIG	COMPANY		FULLNAME */
+COMPX(197?,	aim65,	0,		0,		aim65,	aim65,	aim65,	aim65,	"Rockwell",	"AIM 65",	GAME_NOT_WORKING|GAME_NO_SOUND)
