@@ -13,16 +13,16 @@
  0-0x3ffff rom
  0xc0000- 0xcffff ram also mapped at 0xd0000-0xdffff */
 
-static MEMORY_READ_START( readmem )
-	{ 0x00000, 0xfffff, MRA_ROM }, /* configured at runtime, complexe mmu */
-MEMORY_END
+static ADDRESS_MAP_START( readmem , ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE( 0x00000, 0xfffff) AM_READ( MRA8_ROM ) /* configured at runtime, complexe mmu */
+ADDRESS_MAP_END
 
-static MEMORY_WRITE_START( writemem )
-	{ 0x00000, 0xfffff, MWA_ROM },
-MEMORY_END
+static ADDRESS_MAP_START( writemem , ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE( 0x00000, 0xfffff) AM_WRITE( MWA8_ROM )
+ADDRESS_MAP_END
 
 #define DIPS_HELPER(bit, name, keycode, r) \
-   PORT_BITX(bit, IP_ACTIVE_HIGH, IPT_KEYBOARD, name, keycode, r)
+   PORT_BIT(bit, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME(name) PORT_CODE(keycode) PORT_CODE(r)
 
 
 INPUT_PORTS_START( hp48s )
@@ -151,15 +151,8 @@ INPUT_PORTS_START( hp48s )
 #endif
 INPUT_PORTS_END
 
-#if 0
-static struct DACinterface dac_interface =
-{
-	1,			/* number of DACs */
-	{ 100 } 	/* volume */
-};
-#endif
 
-static struct GfxLayout hp48_charlayout =
+static gfx_layout hp48_charlayout =
 {
         2,16,
         256,                                    /* 256 characters */
@@ -174,7 +167,7 @@ static struct GfxLayout hp48_charlayout =
         1*8
 };
 
-static struct GfxDecodeInfo hp48_gfxdecodeinfo[] = {
+static gfx_decode hp48_gfxdecodeinfo[] = {
 	{ REGION_GFX1, 0x0000, &hp48_charlayout,                     0, 8 },
     { -1 } /* end of array */
 };
@@ -184,143 +177,68 @@ static SATURN_CONFIG config={
 	hp48_mem_reset, hp48_mem_config, hp48_mem_unconfig, hp48_mem_id,
 	hp48_crc
 };
-static struct MachineDriver machine_driver_hp48s =
-{
+
+
+static MACHINE_DRIVER_START( hp48s )
 	/* basic machine hardware */
-	{
-		{
-			CPU_SATURN,
-			4000000,	/* 2 MHz */
-			readmem,writemem,0,0,
-			hp48_frame_int, 1,
-			0,0,
-			&config
-        }
-	},
-	/* frames per second, VBL duration */
-	64, DEFAULT_60HZ_VBLANK_DURATION,
-	1,				/* single CPU */
-	hp48_machine_init,
-	NULL,			/* stop machine */
+	MDRV_CPU_ADD_TAG("main", SATURN, 4000000)        /* 2 MHz */
+	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
+	MDRV_CPU_CONFIG(config)
+	MDRV_FRAMES_PER_SECOND(64)
+	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
+	MDRV_INTERLEAVE(1)
+
+	MDRV_MACHINE_INIT( hp48 )
 
 	/* video hardware (well, actually there was no video ;) */
 	/* scanned with 300 dpi, scaled x 55%, y 55% for perfect display 2x2 pixels */
-	339, 775, { 0, 339-1, 0, 775-1 },
-	hp48_gfxdecodeinfo,			   /* graphics decode info */
-	sizeof (hp48_palette) / sizeof (hp48_palette[0]) ,
-	sizeof (hp48_colortable) / sizeof(hp48_colortable[0][0]),
-	hp48_init_colors,		/* convert color prom */
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_SIZE(339, 775)
+	MDRV_VISIBLE_AREA(0, 339-1, 0, 775-1)
+	MDRV_GFXDECODE( hp48_gfxdecodeinfo )
+	MDRV_PALETTE_LENGTH( 248 )
+	MDRV_COLORTABLE_LENGTH( sizeof (hp48_colortable) / sizeof(hp48_colortable[0][0]) )
+	MDRV_PALETTE_INIT( hp48 )
 
-	VIDEO_TYPE_RASTER | VIDEO_SUPPORTS_DIRTY,	/* video flags */
-	0,						/* obsolete */
-	hp48_vh_start,
-	hp48_vh_stop,
-	hp48_vh_screenrefresh,
+	MDRV_VIDEO_START( hp48 )
+	MDRV_VIDEO_UPDATE( hp48 )
+MACHINE_DRIVER_END
 
-	/* sound hardware */
-	0,0,0,0,
-	{
-        { 0 }
-    }
-};
 
-static struct MachineDriver machine_driver_hp48g =
-{
-	/* basic machine hardware */
-	{
-		{
-			CPU_SATURN,
-			8000000,	/* 4 MHz */
-			readmem,writemem,0,0,
-			hp48_frame_int, 1,
-			0,0,
-			&config
-        }
-	},
-	/* frames per second, VBL duration */
-	64, DEFAULT_60HZ_VBLANK_DURATION,
-	1,				/* single CPU */
-	hp48_machine_init,
-	NULL,			/* stop machine */
-
-	/* video hardware (well, actually there was no video ;) */
-	339, 775, { 0, 339-1, 0, 775-1 },
-	hp48_gfxdecodeinfo,			   /* graphics decode info */
-	sizeof (hp48_palette) / sizeof (hp48_palette[0]) ,
-	sizeof (hp48_colortable) / sizeof(hp48_colortable[0][0]),
-	hp48_init_colors,		/* convert color prom */
-
-	VIDEO_TYPE_RASTER | VIDEO_SUPPORTS_DIRTY,	/* video flags */
-	0,						/* obsolete */
-	hp48_vh_start,
-	hp48_vh_stop,
-	hp48_vh_screenrefresh,
-
-	/* sound hardware */
-	0,0,0,0,
-	{
-        { 0 }
-    }
-};
+static MACHINE_DRIVER_START( hp48g )
+	MDRV_IMPORT_FROM( hp48s )
+	MDRV_CPU_REPLACE( "main", SATURN, 8000000 )		/* 4 MHz */
+	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
+	MDRV_CPU_CONFIG(config)
+MACHINE_DRIVER_END
 
 ROM_START(hp48s)
 	ROM_REGION(0x1c0000,REGION_CPU1, 0)
 	/* version at 0x7fff0 little endian 6 characters */
 	/* 0x3fff8 in byte wide rom */
-/*	ROM_LOAD("sxrom-a", 0x00000, 0x40000, 0xa87696c7) */
-/*	ROM_LOAD("sxrom-b", 0x00000, 0x40000, 0x034f6ce4) */
-/*	ROM_LOAD("sxrom-c", 0x00000, 0x40000, 0xa9a0279d) */
-/*	ROM_LOAD("sxrom-d", 0x00000, 0x40000, 0x6e71244e) */
-/*	ROM_LOAD("sxrom-e", 0x00000, 0x40000, 0x704ffa08) */
-	ROM_LOAD("sxrom-e", 0x00000, 0x40000, 0xd4f1390b) /* differences only in the hardware window */
-/*	ROM_LOAD("rom.sx", 0x00000, 0x40000, 0x5619ccaf) //revision E bad dump */
-/*	ROM_LOAD("sxrom-j", 0x00000, 0x40000, 0x1a6378ef) */
+/*	ROM_LOAD("sxrom-a", 0x00000, 0x40000, CRC(a87696c7)) */
+/*	ROM_LOAD("sxrom-b", 0x00000, 0x40000, CRC(034f6ce4)) */
+/*	ROM_LOAD("sxrom-c", 0x00000, 0x40000, CRC(a9a0279d)) */
+/*	ROM_LOAD("sxrom-d", 0x00000, 0x40000, CRC(6e71244e)) */
+/*	ROM_LOAD("sxrom-e", 0x00000, 0x40000, CRC(704ffa08)) */
+	ROM_LOAD("sxrom-e", 0x00000, 0x40000, CRC(d4f1390b) SHA1(f6be01a05aedefa8a285d480e33458447cf2bdaa)) /* differences only in the hardware window */
+/*	ROM_LOAD("rom.sx", 0x00000, 0x40000, CRC(5619ccaf)) //revision E bad dump */
+/*	ROM_LOAD("sxrom-j", 0x00000, 0x40000, CRC(1a6378ef)) */
 	ROM_REGION(0x100,REGION_GFX1,0)
 ROM_END
 
 ROM_START(hp48g)
 	ROM_REGION(0x580000,REGION_CPU1, 0)
 	/* version at 0x7ffbf little endian 6 characters */
-/*	ROM_LOAD("gxrom-k", 0x00000, 0x80000, 0xbdd5d2ee) */
-/*	ROM_LOAD("gxrom-l", 0x00000, 0x80000, 0x70958e6b) */
-/*	ROM_LOAD("gxrom-m", 0x00000, 0x80000, 0xe21a09e4) */
-/*	ROM_LOAD("gxrom-p", 0x00000, 0x80000, 0x27f90428) */
-	ROM_LOAD("gxrom-r", 0x00000, 0x80000, 0x00ee1a62)
-/*	ROM_LOAD("rom.gx", 0x00000, 0x80000, 0xd6bb68c5) //revision R bad dump */
+/*	ROM_LOAD("gxrom-k", 0x00000, 0x80000, CRC(bdd5d2ee)) */
+/*	ROM_LOAD("gxrom-l", 0x00000, 0x80000, CRC(70958e6b)) */
+/*	ROM_LOAD("gxrom-m", 0x00000, 0x80000, CRC(e21a09e4)) */
+/*	ROM_LOAD("gxrom-p", 0x00000, 0x80000, CRC(27f90428)) */
+	ROM_LOAD("gxrom-r", 0x00000, 0x80000, CRC(00ee1a62))
+/*	ROM_LOAD("rom.gx", 0x00000, 0x80000, CRC(d6bb68c5)) //revision R bad dump */
 	ROM_REGION(0x100,REGION_GFX1,0)
 ROM_END
 
-static const struct IODevice io_hp48s[] = {
-    { IO_END }
-};
-
-#define io_hp48g io_hp48s
-
-/*    YEAR  NAME      PARENT    MACHINE   INPUT     INIT      MONITOR	COMPANY   FULLNAME */
-/* hp71b 84 cpu 1lf2 */
-/* hp71b    cpu 1lk7 */
-/* hp18c 86 */
-/* hp28c 87 */
-/* hp17b 88 cpu 1lt8 in lewis */
-/* hp19b 88 */
-/* hp27s 88 */
-/* hp28s 88 */
-/* hp48sx 91 cpu 1lt8 in clarke */
-/* hp48s (hp48sx with only 32kb ram) */
-/* hp48gx 93 cpu 1lt8 in yorke */
-/* hp48g (hp48gx with only 32kb ram) */
-/* hp38g  95 cpu 1lt8 in yorke */
-/* hp49???? */
-COMP( 1989, hp48s,	  0, 		hp48s,  hp48s, 	hp48s,	  "Hewlett Packard",  "HP48S/SX")
-COMP( 1993, hp48g,	  0, 		hp48g,  hp48s, 	hp48g,	  "Hewlett Packard",  "HP48G/GX")
-
-#ifdef RUNTIME_LOADER
-extern void hp48_runtime_loader_init(void)
-{
-	int i;
-	for (i=0; drivers[i]; i++) {
-		if ( strcmp(drivers[i]->name,"hp48s")==0) drivers[i]=&driver_hp48s;
-		if ( strcmp(drivers[i]->name,"hp48g")==0) drivers[i]=&driver_hp48g;
-	}
-}
-#endif
+/*   YEAR	NAME	PARENT	COMPAT	MACHINE	INPUT	INIT	CONFIG	MONITOR	COMPANY   FULLNAME */
+COMP(1989,	hp48s,	0,		0,		hp48s,	hp48s,	hp48s,	NULL,	"Hewlett Packard",  "HP48S/SX")
+COMP(1993,	hp48g,	0,		0,		hp48g,	hp48s,	hp48g,	NULL,	"Hewlett Packard",  "HP48G/GX")
