@@ -7,6 +7,7 @@
 #include "includes/mk2.h"
 #include "includes/rriot.h"
 #include "cpu/m6502/m6502.h"
+#include "sound/dac.h"
 
 #define M6504_MEMORY_LAYOUT
 
@@ -43,43 +44,43 @@ MOS MPS 6332 005 2179
   83, 84 contains display variables
  */
 /* only lower 12 address bits on bus! */
-static MEMORY_READ_START( mk2_readmem )
+static ADDRESS_MAP_START( mk2_readmem , ADDRESS_SPACE_PROGRAM, 8)
 #ifdef M6504_MEMORY_LAYOUT
-	MEMORY_ADDRESS_BITS(13) /* m6504 */
-	{ 0x0000, 0x01ff, MRA_RAM }, /* 2 2111, should be mirrored */
-	{ 0x0b00, 0x0b0f, rriot_0_r },
-	{ 0x0b80, 0x0bbf, MRA_RAM }, /* rriot ram */
-	{ 0x0c00, 0x0fff, MRA_ROM }, /* rriot rom */
-	{ 0x1000, 0x1fff, MRA_ROM },
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(13) ) /* m6504 */
+	AM_RANGE( 0x0000, 0x01ff) AM_READ( MRA8_RAM ) /* 2 2111, should be mirrored */
+	AM_RANGE( 0x0b00, 0x0b0f) AM_READ( rriot_0_r )
+	AM_RANGE( 0x0b80, 0x0bbf) AM_READ( MRA8_RAM ) /* rriot ram */
+	AM_RANGE( 0x0c00, 0x0fff) AM_READ( MRA8_ROM ) /* rriot rom */
+	AM_RANGE( 0x1000, 0x1fff) AM_READ( MRA8_ROM )
 #else
-	{ 0x0000, 0x01ff, MRA_RAM }, /* 2 2111, should be mirrored */
-	{ 0x8009, 0x8009, MRA_NOP },/* bit $8009 (ora #$80) causes false accesses */
-	{ 0x8b00, 0x8b0f, rriot_0_r },
-	{ 0x8b80, 0x8bbf, MRA_RAM }, /* rriot ram */
-	{ 0x8c00, 0x8fff, MRA_ROM }, /* rriot rom */
-	{ 0xf000, 0xffff, MRA_ROM },
+	AM_RANGE( 0x0000, 0x01ff) AM_READ( MRA8_RAM ) /* 2 2111, should be mirrored */
+	AM_RANGE( 0x8009, 0x8009) AM_READ( MRA8_NOP )/* bit $8009 (ora #$80) causes false accesses */
+	AM_RANGE( 0x8b00, 0x8b0f) AM_READ( rriot_0_r )
+	AM_RANGE( 0x8b80, 0x8bbf) AM_READ( MRA8_RAM ) /* rriot ram */
+	AM_RANGE( 0x8c00, 0x8fff) AM_READ( MRA8_ROM ) /* rriot rom */
+	AM_RANGE( 0xf000, 0xffff) AM_READ( MRA8_ROM )
 #endif
-MEMORY_END
+ADDRESS_MAP_END
 
-static MEMORY_WRITE_START( mk2_writemem )
+static ADDRESS_MAP_START( mk2_writemem , ADDRESS_SPACE_PROGRAM, 8)
 #ifdef M6504_MEMORY_LAYOUT
-	MEMORY_ADDRESS_BITS(13) /* m6504 */
-	{ 0x0000, 0x01ff, MWA_RAM },
-	{ 0x0b00, 0x0b0f, rriot_0_w },
-	{ 0x0b80, 0x0bbf, MWA_RAM },
-	{ 0x0c00, 0x0fff, MWA_ROM },
-	{ 0x1000, 0x1fff, MWA_ROM },
+	ADDRESS_MAP_FLAGS( AMEF_ABITS(13) ) /* m6504 */
+	AM_RANGE( 0x0000, 0x01ff) AM_WRITE( MWA8_RAM )
+	AM_RANGE( 0x0b00, 0x0b0f) AM_WRITE( rriot_0_w )
+	AM_RANGE( 0x0b80, 0x0bbf) AM_WRITE( MWA8_RAM )
+	AM_RANGE( 0x0c00, 0x0fff) AM_WRITE( MWA8_ROM )
+	AM_RANGE( 0x1000, 0x1fff) AM_WRITE( MWA8_ROM )
 #else
-	{ 0x0000, 0x01ff, MWA_RAM },
-	{ 0x8b00, 0x8b0f, rriot_0_w },
-	{ 0x8b80, 0x8bbf, MWA_RAM },
-	{ 0x8c00, 0x8fff, MWA_ROM },
-	{ 0xf000, 0xffff, MWA_ROM },
+	AM_RANGE( 0x0000, 0x01ff) AM_WRITE( MWA8_RAM )
+	AM_RANGE( 0x8b00, 0x8b0f) AM_WRITE( rriot_0_w )
+	AM_RANGE( 0x8b80, 0x8bbf) AM_WRITE( MWA8_RAM )
+	AM_RANGE( 0x8c00, 0x8fff) AM_WRITE( MWA8_ROM )
+	AM_RANGE( 0xf000, 0xffff) AM_WRITE( MWA8_ROM )
 #endif
-MEMORY_END
+ADDRESS_MAP_END
 
 #define DIPS_HELPER(bit, name, keycode, r) \
-   PORT_BITX(bit, IP_ACTIVE_HIGH, IPT_KEYBOARD, name, keycode, r)
+   PORT_BIT(bit, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME(name) PORT_CODE(keycode) PORT_CODE(r)
 
 INPUT_PORTS_START( mk2 )
 	PORT_START
@@ -117,68 +118,56 @@ DIPS_HELPER( 0x001, "NEW GAME", KEYCODE_F3, CODE_NONE) /* seams to be direct wir
 #endif
 INPUT_PORTS_END
 
-static int mk2_frame_int(void)
-{
-	return ignore_interrupt();
-}
-
-static void mk2_machine_init(void)
+static MACHINE_INIT( mk2 )
 {
 	rriot_reset(0);
 }
 
-static struct DACinterface mk2_dac={ 1, {80}}; /* silence is golden */
-
-static struct MachineDriver machine_driver_mk2 =
-{
+static MACHINE_DRIVER_START( mk2 )
 	/* basic machine hardware */
-	{
-		{
-			CPU_M6502, /* 6504 */
-			1000000,
-			mk2_readmem,mk2_writemem,0,0,
-			mk2_frame_int, 1,
-        }
-	},
-	/* frames per second, VBL duration */
-	60, DEFAULT_60HZ_VBLANK_DURATION, /* lcd! */
-	1,				/* single CPU */
-	mk2_machine_init,
-	0,/*pc1401_machine_stop, */
+	MDRV_CPU_ADD(M6502, 1000000)        /* 6504 */
+	MDRV_CPU_PROGRAM_MAP(mk2_readmem,mk2_writemem)
+	MDRV_FRAMES_PER_SECOND(60)
+	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
+	MDRV_INTERLEAVE(1)
 
-	252, 559, { 0, 252 - 1, 0, 559 - 1},
-	0, 			   /* graphics decode info */
-	sizeof (mk2_palette) / sizeof (mk2_palette[0]) + 32768,
-	sizeof (mk2_colortable) / sizeof(mk2_colortable[0][0]),
-	mk2_init_colors,		/* convert color prom */
+	MDRV_MACHINE_INIT( mk2 )
 
-	VIDEO_TYPE_RASTER,	/* video flags */
-	0,						/* obsolete */
-    mk2_vh_start,
-	mk2_vh_stop,
-	mk2_vh_screenrefresh,
+    /* video hardware */
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_SIZE(252, 559)
+	MDRV_VISIBLE_AREA(0, 252-1, 0, 559-1)
+	MDRV_PALETTE_LENGTH(242 + 32768)
+	MDRV_COLORTABLE_LENGTH(2)
+	MDRV_PALETTE_INIT(mk2)
+
+	MDRV_VIDEO_START( mk2 )
+	MDRV_VIDEO_UPDATE( mk2 )
 
 	/* sound hardware */
-	0,0,0,0,
-	{
-		{ SOUND_DAC, &mk2_dac }
-    }
-};
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80)
+MACHINE_DRIVER_END
+
 
 ROM_START(mk2)
 	ROM_REGION(0x10000,REGION_CPU1,0)
 #ifdef M6504_MEMORY_LAYOUT
-	ROM_LOAD("024_1879", 0x0c00, 0x0400, 0x4f28c443)
-	ROM_LOAD("005_2179", 0x1000, 0x1000, 0x6f10991b) /* chess mate 7.5 */
+	ROM_LOAD("024_1879", 0x0c00, 0x0400, CRC(4f28c443) SHA1(e33f8b7f38e54d7a6e0f0763f2328cc12cb0eade))
+	ROM_LOAD("005_2179", 0x1000, 0x1000, CRC(6f10991b) SHA1(90cdc5a15d9ad813ad20410f21081c6e3e481812)) /* chess mate 7.5 */
 #else
-	ROM_LOAD("024_1879", 0x8c00, 0x0400, 0x4f28c443)
-	ROM_LOAD("005_2179", 0xf000, 0x1000, 0x6f10991b) /* chess mate 7.5 */
+	ROM_LOAD("024_1879", 0x8c00, 0x0400, CRC(4f28c443) SHA1(e33f8b7f38e54d7a6e0f0763f2328cc12cb0eade))
+	ROM_LOAD("005_2179", 0xf000, 0x1000, CRC(6f10991b) SHA1(90cdc5a15d9ad813ad20410f21081c6e3e481812)) /* chess mate 7.5 */
 #endif
 ROM_END
 
-static const struct IODevice io_mk2[] = {
-    { IO_END }
-};
+/***************************************************************************
+
+  Game driver(s)
+
+***************************************************************************/
 
 /*
    port a
@@ -253,7 +242,7 @@ static void mk2_write_b(int chip, int value)
 
 static void mk2_irq(int chip, int level)
 {
-	cpu_set_irq_line(0, M6502_IRQ_LINE, level);
+	cpunum_set_input_line(0, M6502_IRQ_LINE, level);
 }
 
 static RRIOT_CONFIG riot={
@@ -263,20 +252,11 @@ static RRIOT_CONFIG riot={
 	mk2_irq
 };
 
-void init_mk2(void)
+static void init_mk2(void)
 {
-	rriot_config(0,&riot);
+	rriot_init(0,&riot);
 }
 
-CONS( 1979,	mk2,	0, 		mk2,	mk2,	mk2,	  "Quelle International",  "Chess Champion MK II")
+/*    YEAR  NAME    PARENT	COMPAT	MACHINE INPUT   INIT    CONFIG    COMPANY   FULLNAME */
+CONS( 1979,	mk2,	0,		0,		mk2,	mk2,	mk2,	NULL,	  "Quelle International",  "Chess Champion MK II")
 /* second design sold (same computer/program?) */
-
-#ifdef RUNTIME_LOADER
-extern void mk2_runtime_loader_init(void)
-{
-	int i;
-	for (i=0; drivers[i]; i++) {
-		if ( strcmp(drivers[i]->name,"mk2")==0) drivers[i]=&driver_mk2;
-	}
-}
-#endif
