@@ -8,13 +8,15 @@
 
 ****************************************************************************/
 
+#include <assert.h>
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "vidhrdw/vdc.h"
 #include "cpu/h6280/h6280.h"
 #include "includes/pce.h"
+#include "devices/cartslot.h"
 
-static int pce_interrupt(void)
+static INTERRUPT_GEN( pce_interrupt )
 {
     int ret = 0;
 
@@ -32,7 +34,7 @@ static int pce_interrupt(void)
     if(vdc.curline == ((vdc.vdc_data[RCR].w & 0x03FF) - 64))
     {
         vdc.status |= VDC_RR;
-        ret = H6280_INT_IRQ1;
+        ret = 1;
     }
 
     /* handle frame events */
@@ -44,84 +46,72 @@ static int pce_interrupt(void)
         if((vdc.vdc_data[DCR].w & DCR_DSR) || vdc.dvssr_write)
         {
             if(vdc.dvssr_write) vdc.dvssr_write = 0;
+#ifdef MAME_DEBUG
+			assert(((vdc.vdc_data[DVSSR].w<<1) + 512) <= 0x10000);
+#endif
             memcpy(&vdc.sprite_ram, &vdc.vram[vdc.vdc_data[DVSSR].w<<1], 512);
             vdc.status |= VDC_DS;   /* set satb done flag */
 
             /* generate interrupt if needed */
             if(vdc.vdc_data[DCR].w & DCR_DSC)
             {
-                ret = H6280_INT_IRQ1;
+                ret = 1;
             }
         }
 
         if(vdc.vdc_data[CR].w & CR_VR)  /* generate IRQ1 if enabled */
         {
-            ret = H6280_INT_IRQ1;
+            ret = 1;
         }
     }
-    return (ret);
+	if (ret)
+		cpunum_set_input_line(0, 0, PULSE_LINE);
 }
 
 /* stubs for the irq/psg/timer code */
 
-static WRITE_HANDLER ( pce_irq_w)
+static WRITE8_HANDLER ( pce_irq_w)
 {
 }
 
-static READ_HANDLER ( pce_irq_r )
+static  READ8_HANDLER ( pce_irq_r )
 {
     return 0x00;
 }
 
-static WRITE_HANDLER ( pce_timer_w )
+static WRITE8_HANDLER ( pce_timer_w )
 {
 }
 
-static READ_HANDLER ( pce_timer_r )
+static  READ8_HANDLER ( pce_timer_r )
 {
     return 0x00;
 }
 
-static WRITE_HANDLER ( pce_psg_w )
+static WRITE8_HANDLER ( pce_psg_w )
 {
 }
 
-static READ_HANDLER ( pce_psg_r )
+static  READ8_HANDLER ( pce_psg_r )
 {
     return 0x00;
 }
 
-MEMORY_READ_START( pce_readmem )
-    { 0x000000, 0x1EDFFF, MRA_ROM },
-    { 0x1EE000, 0x1EFFFF, MRA_RAM },
-    { 0x1F0000, 0x1F1FFF, MRA_RAM },
-    { 0x1FE000, 0x1FE003, vdc_r },
-    { 0x1FE400, 0x1FE407, vce_r },
-    { 0x1FE800, 0x1FE80F, pce_psg_r },
-    { 0x1FEC00, 0x1FEC00, pce_timer_r },
-    { 0x1FF000, 0x1FF000, pce_joystick_r },
-    { 0x1FF402, 0x1FF403, pce_irq_r },
-MEMORY_END
+ADDRESS_MAP_START( pce_mem , ADDRESS_SPACE_PROGRAM, 8)
+    AM_RANGE( 0x000000, 0x1EDFFF) AM_ROM
+    AM_RANGE( 0x1EE000, 0x1EFFFF) AM_RAM
+    AM_RANGE( 0x1F0000, 0x1F1FFF) AM_RAM	AM_BASE( &pce_user_ram )
+    AM_RANGE( 0x1FE000, 0x1FE003) AM_READWRITE( vdc_r, vdc_w )
+    AM_RANGE( 0x1FE400, 0x1FE407) AM_READWRITE( vce_r, vce_w )
+    AM_RANGE( 0x1FE800, 0x1FE80F) AM_READWRITE( pce_psg_r, pce_psg_w )
+    AM_RANGE( 0x1FEC00, 0x1FEC01) AM_READWRITE( pce_timer_r, pce_timer_w )
+    AM_RANGE( 0x1FF000, 0x1FF000) AM_READWRITE( pce_joystick_r, pce_joystick_w )
+    AM_RANGE( 0x1FF402, 0x1FF403) AM_READWRITE( pce_irq_r, pce_irq_w )
+ADDRESS_MAP_END
 
-MEMORY_WRITE_START( pce_writemem )
-    { 0x000000, 0x1EDFFF, MWA_ROM },
-    { 0x1EE000, 0x1EFFFF, MWA_RAM, &pce_save_ram },
-    { 0x1F0000, 0x1F1FFF, MWA_RAM, &pce_user_ram },
-    { 0x1FE000, 0x1FE003, vdc_w },
-    { 0x1FE400, 0x1FE407, vce_w },
-    { 0x1FE800, 0x1FE80F, pce_psg_w },
-    { 0x1FEC00, 0x1FEC01, pce_timer_w },
-    { 0x1FF000, 0x1FF000, pce_joystick_w },
-    { 0x1FF402, 0x1FF403, pce_irq_w },
-MEMORY_END
-
-PORT_READ_START( pce_readport )
-    { 0x00, 0x03, vdc_r },
-PORT_END
-
-PORT_WRITE_START( pce_writeport )
-    { 0x00, 0x03, vdc_w },
-PORT_END
+ADDRESS_MAP_START( pce_io , ADDRESS_SPACE_IO, 8)
+    AM_RANGE( 0x00, 0x03) AM_READWRITE( vdc_r, vdc_w )
+ADDRESS_MAP_END
 
 /* todo: alternate forms of input (multitap, mouse, etc.) */
 INPUT_PORTS_START( pce )
@@ -149,7 +139,7 @@ INPUT_PORTS_END
 
 
 #if 0
-static struct GfxLayout pce_bg_layout =
+static gfx_layout pce_bg_layout =
 {
         8, 8,
         2048,
@@ -160,7 +150,7 @@ static struct GfxLayout pce_bg_layout =
         32*8,
 };
 
-static struct GfxLayout pce_obj_layout =
+static gfx_layout pce_obj_layout =
 {
         16, 16,
         512,
@@ -171,65 +161,52 @@ static struct GfxLayout pce_obj_layout =
         128*8,
 };
 
-static struct GfxDecodeInfo pce_gfxdecodeinfo[] =
+static gfx_decode pce_gfxdecodeinfo[] =
 {
    { 1, 0x0000, &pce_bg_layout, 0, 0x10 },
    { 1, 0x0000, &pce_obj_layout, 0x100, 0x10 },
-MEMORY_END
+	{-1}
+};
 #endif
 
-static struct MachineDriver machine_driver_pce =
+
+static MACHINE_DRIVER_START( pce )
+	/* basic machine hardware */
+	MDRV_CPU_ADD(H6280, 7195090)
+	MDRV_CPU_PROGRAM_MAP(pce_mem, 0)
+	MDRV_CPU_IO_MAP(pce_io, 0)
+	MDRV_CPU_VBLANK_INT(pce_interrupt, VDC_LPF)
+	MDRV_FRAMES_PER_SECOND(60)
+	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
+	MDRV_INTERLEAVE(1)
+
+    /* video hardware */
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_SIZE(45*8, 32*8)
+	MDRV_VISIBLE_AREA(0*8, 45*8-1, 0*8, 32*8-1)
+	/* MDRV_GFXDECODE( pce_gfxdecodeinfo ) */
+	MDRV_PALETTE_LENGTH(512)
+	MDRV_COLORTABLE_LENGTH(512)
+
+	MDRV_VIDEO_START( pce )
+	MDRV_VIDEO_UPDATE( pce )
+
+	MDRV_NVRAM_HANDLER( pce )
+MACHINE_DRIVER_END
+
+static void pce_cartslot_getinfo(struct IODevice *dev)
 {
-    {
-        {
-            CPU_H6280,
-            7195090,
-            pce_readmem, pce_writemem, pce_readport, pce_writeport,
-            pce_interrupt, VDC_LPF
-        },
-    },
-    60, DEFAULT_60HZ_VBLANK_DURATION,
-    1,
-    pce_init_machine,
-    pce_stop_machine,
+	/* cartslot */
+	cartslot_device_getinfo(dev);
+	dev->count = 1;
+	dev->file_extensions = "pce\0";
+	dev->must_be_loaded = 1;
+	dev->load = device_load_pce_cart;
+}
 
-    45*8, 32*8, { 0*8, 45*8-1, 0*8, 32*8-1 },
-    0,
-    /*pce_gfxdecodeinfo,*/
-    512, 512,
-    0,
-    VIDEO_TYPE_RASTER,
-    0,		/* was... (256*2) */
-    pce_vh_start,
-    pce_vh_stop,
-    pce_vh_screenrefresh,
-    0, 0, 0, 0
-};
-
-static const struct IODevice io_pce[] = {
-    {
-		IO_CARTSLOT,		/* type */
-		1,					/* count */
-		"pce\0",            /* file extensions */
-		IO_RESET_ALL,		/* reset if file changed */
-        NULL,				/* id */
-		pce_load_rom,		/* init */
-		NULL,				/* exit */
-		NULL,				/* info */
-		NULL,               /* open */
-		NULL,               /* close */
-		NULL,               /* status */
-		NULL,               /* seek */
-		NULL,				/* tell */
-        NULL,               /* input */
-		NULL,               /* output */
-		NULL,               /* input_chunk */
-		NULL                /* output_chunk */
-	},
-	{ IO_END }
-};
-
-#define rom_pce NULL
+SYSTEM_CONFIG_START(pce)
+	CONFIG_DEVICE(pce_cartslot_getinfo)
+SYSTEM_CONFIG_END
 
 /***************************************************************************
 
@@ -237,6 +214,8 @@ static const struct IODevice io_pce[] = {
 
 ***************************************************************************/
 
-/*	   YEAR  NAME	   PARENT	 MACHINE   INPUT	 INIT	   COMPANY	 FULLNAME */
-CONSX( 1987, pce,	   0,		 pce,	   pce, 	 0,		   "Nippon Electronic Company", "PC Engine/TurboGrafx 16", GAME_NOT_WORKING | GAME_NO_SOUND )
+#define rom_pce NULL
+
+/*	   YEAR  NAME	   PARENT	COMPAT	MACHINE	INPUT	 INIT	CONFIG  COMPANY	 FULLNAME */
+CONSX( 1987, pce,	   0,		0,		pce,	pce, 	 0,		pce,	"Nippon Electronic Company", "PC Engine/TurboGrafx 16", GAME_NOT_WORKING | GAME_NO_SOUND )
 
