@@ -161,103 +161,102 @@ when problems start with -log and look into error.log file
 #include "includes/vc1541.h"
 #include "includes/vc20tape.h"
 #include "includes/vic6560.h"
+#include "devices/cartslot.h"
 
-static MEMORY_READ_START( vc20_readmem )
-	{0x0000, 0x03ff, MRA_RAM},
+static ADDRESS_MAP_START( vc20_readmem , ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE(0x0000, 0x03ff) AM_READ( MRA8_RAM)
 #if 0
-	{0x0400, 0x0fff, MRA_RAM},		   /* ram, rom or nothing; I think read 0xff! */
+	AM_RANGE(0x0400, 0x0fff) AM_READ( MRA8_RAM)		   /* ram, rom or nothing; I think read 0xff! */
 #endif
-	{0x1000, 0x1fff, MRA_RAM},
+	AM_RANGE(0x1000, 0x1fff) AM_READ( MRA8_RAM)
 #if 0
-	{0x2000, 0x3fff, MRA_RAM},		   /* ram, rom or nothing */
-	{0x4000, 0x5fff, MRA_RAM},		   /* ram, rom or nothing */
-	{0x6000, 0x7fff, MRA_RAM},		   /* ram, rom or nothing */
+	AM_RANGE(0x2000, 0x3fff) AM_READ( MRA8_RAM)		   /* ram, rom or nothing */
+	AM_RANGE(0x4000, 0x5fff) AM_READ( MRA8_RAM)		   /* ram, rom or nothing */
+	AM_RANGE(0x6000, 0x7fff) AM_READ( MRA8_RAM)		   /* ram, rom or nothing */
 #endif
-	{0x8000, 0x8fff, MRA_ROM},
-	{0x9000, 0x900f, vic6560_port_r},
-	{0x9010, 0x910f, MRA_NOP},
-	{0x9110, 0x911f, via_0_r},
-	{0x9120, 0x912f, via_1_r},
-	{0x9130, 0x93ff, MRA_NOP},
-	{0x9400, 0x97ff, MRA_RAM},		   /*color ram 4 bit */
-	{0x9800, 0x9fff, MRA_NOP},
+	AM_RANGE(0x8000, 0x8fff) AM_READ( MRA8_ROM)
+	AM_RANGE(0x9000, 0x900f) AM_READ( vic6560_port_r)
+	AM_RANGE(0x9010, 0x910f) AM_READ( MRA8_NOP)
+	AM_RANGE(0x9110, 0x911f) AM_READ( via_0_r)
+	AM_RANGE(0x9120, 0x912f) AM_READ( via_1_r)
+	AM_RANGE(0x9130, 0x93ff) AM_READ( MRA8_NOP)
+	AM_RANGE(0x9400, 0x97ff) AM_READ( MRA8_RAM)		   /*color ram 4 bit */
+	AM_RANGE(0x9800, 0x9fff) AM_READ( MRA8_NOP)
 #if 0
-	{0xa000, 0xbfff, MRA_RAM},		   /* or nothing */
+	AM_RANGE(0xa000, 0xbfff) AM_READ( MRA8_RAM)		   /* or nothing */
 #endif
-	{0xc000, 0xffff, MRA_ROM},
-MEMORY_END
+	AM_RANGE(0xc000, 0xffff) AM_READ( MRA8_ROM)
+ADDRESS_MAP_END
 
-static MEMORY_WRITE_START( vc20_writemem )
-	{0x0000, 0x03ff, MWA_RAM, &vc20_memory},
-	{0x1000, 0x1fff, MWA_RAM},
-	{0x8000, 0x8fff, MWA_ROM},
-	{0x9000, 0x900f, vic6560_port_w},
-	{0x9010, 0x910f, MWA_NOP},
-	{0x9110, 0x911f, via_0_w},
-	{0x9120, 0x912f, via_1_w},
-	{0x9130, 0x93ff, MWA_NOP},
-	{0x9400, 0x97ff, vc20_write_9400, &vc20_memory_9400},
-	{0x9800, 0x9fff, MWA_NOP},
-	{0xc000, 0xffff, MWA_NOP},		   /* MWA_ROM }, but logfile */
-MEMORY_END
+static ADDRESS_MAP_START( vc20_writemem , ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE(0x0000, 0x03ff) AM_WRITE( MWA8_RAM) AM_BASE( &vc20_memory)
+	AM_RANGE(0x1000, 0x1fff) AM_WRITE( MWA8_RAM)
+	AM_RANGE(0x8000, 0x8fff) AM_WRITE( MWA8_ROM)
+	AM_RANGE(0x9000, 0x900f) AM_WRITE( vic6560_port_w)
+	AM_RANGE(0x9010, 0x910f) AM_WRITE( MWA8_NOP)
+	AM_RANGE(0x9110, 0x911f) AM_WRITE( via_0_w)
+	AM_RANGE(0x9120, 0x912f) AM_WRITE( via_1_w)
+	AM_RANGE(0x9130, 0x93ff) AM_WRITE( MWA8_NOP)
+	AM_RANGE(0x9400, 0x97ff) AM_WRITE( vc20_write_9400) AM_BASE( &vc20_memory_9400)
+	AM_RANGE(0x9800, 0x9fff) AM_WRITE( MWA8_NOP)
+	AM_RANGE(0xc000, 0xffff) AM_WRITE( MWA8_NOP)		   /* MWA8_ROM , but logfile */
+ADDRESS_MAP_END
 
-static MEMORY_READ_START( vc20i_readmem )
-	{0x0000, 0x03ff, MRA_RAM},
+static ADDRESS_MAP_START( vc20i_readmem , ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE(0x0000, 0x03ff) AM_READ( MRA8_RAM)
 #if 0
-	{0x0400, 0x0fff, MRA_RAM},		   /* ram, rom or nothing; I think read 0xff! */
+	AM_RANGE(0x0400, 0x0fff) AM_READ( MRA8_RAM)		   /* ram, rom or nothing; I think read 0xff! */
 #endif
-	{0x1000, 0x1fff, MRA_RAM},
+	AM_RANGE(0x1000, 0x1fff) AM_READ( MRA8_RAM)
 #if 0
-	{0x2000, 0x3fff, MRA_RAM},		   /* ram, rom or nothing */
-	{0x4000, 0x5fff, MRA_RAM},		   /* ram, rom or nothing */
-	{0x6000, 0x7fff, MRA_RAM},		   /* ram, rom or nothing */
+	AM_RANGE(0x2000, 0x3fff) AM_READ( MRA8_RAM)		   /* ram, rom or nothing */
+	AM_RANGE(0x4000, 0x5fff) AM_READ( MRA8_RAM)		   /* ram, rom or nothing */
+	AM_RANGE(0x6000, 0x7fff) AM_READ( MRA8_RAM)		   /* ram, rom or nothing */
 #endif
-	{0x8000, 0x8fff, MRA_ROM},
-	{0x9000, 0x900f, vic6560_port_r},
-	{0x9010, 0x910f, MRA_NOP},
-	{0x9110, 0x911f, via_0_r},
-	{0x9120, 0x912f, via_1_r},
-	{0x9400, 0x97ff, MRA_RAM},		   /*color ram 4 bit */
-	{0x9800, 0x980f, via_4_r},
-	{0x9810, 0x981f, via_5_r},
-	{0xa000, 0xbfff, MRA_ROM},
-	{0xc000, 0xffff, MRA_ROM},
-MEMORY_END
+	AM_RANGE(0x8000, 0x8fff) AM_READ( MRA8_ROM)
+	AM_RANGE(0x9000, 0x900f) AM_READ( vic6560_port_r)
+	AM_RANGE(0x9010, 0x910f) AM_READ( MRA8_NOP)
+	AM_RANGE(0x9110, 0x911f) AM_READ( via_0_r)
+	AM_RANGE(0x9120, 0x912f) AM_READ( via_1_r)
+	AM_RANGE(0x9400, 0x97ff) AM_READ( MRA8_RAM)		   /*color ram 4 bit */
+	AM_RANGE(0x9800, 0x980f) AM_READ( via_4_r)
+	AM_RANGE(0x9810, 0x981f) AM_READ( via_5_r)
+	AM_RANGE(0xa000, 0xbfff) AM_READ( MRA8_ROM)
+	AM_RANGE(0xc000, 0xffff) AM_READ( MRA8_ROM)
+ADDRESS_MAP_END
 
-static MEMORY_WRITE_START( vc20i_writemem )
-	{0x0000, 0x03ff, MWA_RAM, &vc20_memory},
-	{0x1000, 0x1fff, MWA_RAM},
-	{0x8000, 0x8fff, MWA_ROM},
-	{0x9000, 0x900f, vic6560_port_w},
-	{0x9010, 0x910f, MWA_NOP},
-	{0x9110, 0x911f, via_0_w},
-	{0x9120, 0x912f, via_1_w},
-	{0x9400, 0x97ff, vc20_write_9400, &vc20_memory_9400},
-	{0x9800, 0x980f, via_4_w},
-	{0x9810, 0x981f, via_5_w},
-	{0xa000, 0xbfff, MWA_ROM},
-	{0xc000, 0xffff, MWA_NOP},		   /* MWA_ROM }, but logfile */
-MEMORY_END
+static ADDRESS_MAP_START( vc20i_writemem , ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE(0x0000, 0x03ff) AM_WRITE( MWA8_RAM) AM_BASE( &vc20_memory)
+	AM_RANGE(0x1000, 0x1fff) AM_WRITE( MWA8_RAM)
+	AM_RANGE(0x8000, 0x8fff) AM_WRITE( MWA8_ROM)
+	AM_RANGE(0x9000, 0x900f) AM_WRITE( vic6560_port_w)
+	AM_RANGE(0x9010, 0x910f) AM_WRITE( MWA8_NOP)
+	AM_RANGE(0x9110, 0x911f) AM_WRITE( via_0_w)
+	AM_RANGE(0x9120, 0x912f) AM_WRITE( via_1_w)
+	AM_RANGE(0x9400, 0x97ff) AM_WRITE( vc20_write_9400) AM_BASE( &vc20_memory_9400)
+	AM_RANGE(0x9800, 0x980f) AM_WRITE( via_4_w)
+	AM_RANGE(0x9810, 0x981f) AM_WRITE( via_5_w)
+	AM_RANGE(0xa000, 0xbfff) AM_WRITE( MWA8_ROM)
+	AM_RANGE(0xc000, 0xffff) AM_WRITE( MWA8_NOP)		   /* MWA8_ROM, but logfile */
+ADDRESS_MAP_END
 
 #define DIPS_HELPER(bit, name, keycode) \
-   PORT_BITX(bit, IP_ACTIVE_HIGH, IPT_KEYBOARD, name, keycode, IP_JOY_NONE)
+   PORT_BIT(bit, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME(name) PORT_CODE(keycode)
 
 #define DIPS_JOY \
 	PORT_START\
-	PORT_BITX( 0x01, IP_ACTIVE_HIGH, IPT_JOYSTICK_UP|IPF_8WAY, "Joystick Up", CODE_DEFAULT, CODE_NONE) \
-	PORT_BITX( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICK_DOWN|IPF_8WAY, "Joystick Down", CODE_DEFAULT, CODE_NONE) \
-	PORT_BITX( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT|IPF_8WAY, "Joystick Left", CODE_DEFAULT, CODE_NONE) \
-	PORT_BITX( 0x08, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT|IPF_8WAY, "Joystick Right", CODE_DEFAULT, CODE_NONE) \
-	PORT_BITX( 0x10, IP_ACTIVE_HIGH, IPT_BUTTON1, "Joystick Button", CODE_DEFAULT, CODE_NONE) \
-	PORT_BITX( 0x20, IP_ACTIVE_HIGH, IPT_BUTTON1, "Paddle 1 Button", KEYCODE_INSERT, CODE_NONE) \
-	PORT_BITX( 0x40, IP_ACTIVE_HIGH, IPT_BUTTON2, "Paddle 2 Button", KEYCODE_DEL, CODE_NONE) \
-	PORT_BITX( 0x80, IP_ACTIVE_HIGH, IPT_BUTTON1, "Lightpen Signal", KEYCODE_LALT, CODE_NONE) \
+	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_JOYSTICK_UP) PORT_NAME("Joystick Up")  PORT_8WAY\
+	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICK_DOWN) PORT_NAME("Joystick Down")  PORT_8WAY\
+	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT) PORT_NAME("Joystick Left")  PORT_8WAY\
+	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT) PORT_NAME("Joystick Right")  PORT_8WAY\
+	PORT_BIT( 0x10, IP_ACTIVE_HIGH, IPT_BUTTON1) PORT_NAME("Joystick Button") \
+	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_BUTTON1) PORT_NAME("Paddle 1 Button") PORT_CODE(KEYCODE_INSERT) \
+	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_BUTTON2) PORT_NAME("Paddle 2 Button") PORT_CODE(KEYCODE_DEL) \
+	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_BUTTON1) PORT_NAME("Lightpen Signal") PORT_CODE(KEYCODE_LALT) \
 	PORT_START \
-	PORT_ANALOGX(0xff,128,IPT_PADDLE|IPF_REVERSE,\
-			 30,20,0,255,KEYCODE_HOME,KEYCODE_PGUP,JOYCODE_NONE,JOYCODE_NONE)\
+	PORT_BIT(0xff,128,IPT_PADDLE) PORT_SENSITIVITY(30) PORT_KEYDELTA(20) PORT_MINMAX(0,255) PORT_CODE_DEC(KEYCODE_HOME) PORT_CODE_INC(KEYCODE_PGUP) PORT_REVERSE\
 	PORT_START \
-	PORT_ANALOGX(0xff,128,IPT_PADDLE|IPF_PLAYER2|IPF_REVERSE,\
-			 30,20,0,255,KEYCODE_END,KEYCODE_PGDN,JOYCODE_NONE,JOYCODE_NONE)
+	PORT_BIT(0xff,128,IPT_PADDLE) PORT_SENSITIVITY(30) PORT_KEYDELTA(20) PORT_MINMAX(0,255) PORT_CODE_DEC(KEYCODE_END) PORT_CODE_INC(KEYCODE_PGDN) PORT_PLAYER(2) PORT_REVERSE
 
 #define DIPS_INPUT \
 	PORT_START \
@@ -295,8 +294,7 @@ MEMORY_END
 	DIPS_HELPER( 0x0002, "RESTORE",               KEYCODE_PRTSCR)\
 	PORT_START \
 	DIPS_HELPER( 0x8000, "STOP RUN",          KEYCODE_TAB)\
-	PORT_BITX( 0x4000, IP_ACTIVE_HIGH, IPF_TOGGLE, \
-		   "SHIFT-LOCK (switch)", KEYCODE_CAPSLOCK, IP_JOY_NONE )\
+	PORT_BIT( 0x4000, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("SHIFT-LOCK (switch)") PORT_CODE(KEYCODE_CAPSLOCK) PORT_TOGGLE\
 	DIPS_HELPER( 0x2000, "A",                 KEYCODE_A)\
 	DIPS_HELPER( 0x1000, "S",                 KEYCODE_S)\
 	DIPS_HELPER( 0x0800, "D",                 KEYCODE_D)\
@@ -342,7 +340,7 @@ MEMORY_END
 #define DIPS_BOTH \
 	PORT_START \
 	PORT_DIPNAME ( 0x07, 0, "RAM Cartridge")\
-	PORT_DIPSETTING(	0, "None" )\
+	PORT_DIPSETTING(	0, DEF_STR( None ) )\
 	PORT_DIPSETTING(	1, "3k" )\
 	PORT_DIPSETTING(	2, "8k" )\
 	PORT_DIPSETTING(	3, "16k" )\
@@ -364,7 +362,7 @@ MEMORY_END
 	PORT_DIPSETTING( 0x00, DEF_STR( No ) )\
 	PORT_DIPSETTING( 0x80, DEF_STR( Yes ) )\
 	PORT_START \
-	PORT_DIPNAME   ( 0x80, 0x80, "Joystick")\
+	PORT_DIPNAME   ( 0x80, 0x80, DEF_STR( Joystick ))\
 	PORT_DIPSETTING( 0x00, DEF_STR( No ) )\
 	PORT_DIPSETTING( 0x80, DEF_STR( Yes ) )\
 	PORT_DIPNAME   ( 0x40, 0x40, "Paddles")\
@@ -392,14 +390,9 @@ MEMORY_END
 INPUT_PORTS_START (vic20)
 	DIPS_JOY
 	PORT_START							   /* in 16 lightpen X */
-	PORT_ANALOGX (0xff, 0, IPT_PADDLE | IPF_PLAYER3,
-				  30, 2, 0, (VIC6560_MAME_XSIZE - 1),
-				  KEYCODE_LEFT, KEYCODE_RIGHT,
-				  JOYCODE_1_LEFT, JOYCODE_1_RIGHT)
+	PORT_BIT (0xff, 0, IPT_PADDLE) PORT_SENSITIVITY(30) PORT_KEYDELTA(2) PORT_MINMAX(0,(VIC6560_MAME_XSIZE - 1)) PORT_CODE_DEC(KEYCODE_LEFT) PORT_CODE_INC(KEYCODE_RIGHT) PORT_CODE_DEC(JOYCODE_1_LEFT) PORT_CODE_INC(JOYCODE_1_RIGHT) PORT_PLAYER(3)
 	PORT_START							   /* in 17 lightpen Y */
-	PORT_ANALOGX (0xff, 0, IPT_PADDLE | IPF_PLAYER4,
-				  30, 2, 0, (VIC6560_MAME_YSIZE - 1),
-				  KEYCODE_UP, KEYCODE_DOWN, JOYCODE_1_UP, JOYCODE_1_DOWN)
+	PORT_BIT (0xff, 0, IPT_PADDLE) PORT_SENSITIVITY(30) PORT_KEYDELTA(2) PORT_MINMAX(0,(VIC6560_MAME_YSIZE - 1)) PORT_CODE_DEC(KEYCODE_UP) PORT_CODE_INC(KEYCODE_DOWN) PORT_CODE_DEC(JOYCODE_1_UP) PORT_CODE_INC(JOYCODE_1_DOWN) PORT_PLAYER(4)
 	DIPS_INPUT
 	DIPS_BOTH
 INPUT_PORTS_END
@@ -408,14 +401,9 @@ INPUT_PORTS_END
 INPUT_PORTS_START (vic1001)
 	DIPS_JOY
 	PORT_START							   /* in 16 lightpen X */
-	PORT_ANALOGX (0xff, 0, IPT_PADDLE | IPF_PLAYER3,
-				  30, 2, 0, (VIC6560_MAME_XSIZE - 1),
-				  KEYCODE_LEFT, KEYCODE_RIGHT,
-				  JOYCODE_1_LEFT, JOYCODE_1_RIGHT)
+	PORT_BIT (0xff, 0, IPT_PADDLE) PORT_SENSITIVITY(30) PORT_KEYDELTA(2) PORT_MINMAX(0,(VIC6560_MAME_XSIZE - 1)) PORT_CODE_DEC(KEYCODE_LEFT) PORT_CODE_INC(KEYCODE_RIGHT) PORT_CODE_DEC(JOYCODE_1_LEFT) PORT_CODE_INC(JOYCODE_1_RIGHT) PORT_PLAYER(3)
 	PORT_START							   /* in 17 lightpen Y */
-	PORT_ANALOGX (0xff, 0, IPT_PADDLE | IPF_PLAYER4,
-				  30, 2, 0, (VIC6560_MAME_YSIZE - 1),
-				  KEYCODE_UP, KEYCODE_DOWN, JOYCODE_1_UP, JOYCODE_1_DOWN)
+	PORT_BIT (0xff, 0, IPT_PADDLE) PORT_SENSITIVITY(30) PORT_KEYDELTA(2) PORT_MINMAX(0,(VIC6560_MAME_YSIZE - 1)) PORT_CODE_DEC(KEYCODE_UP) PORT_CODE_INC(KEYCODE_DOWN) PORT_CODE_DEC(JOYCODE_1_UP) PORT_CODE_INC(JOYCODE_1_DOWN) PORT_PLAYER(4)
 	PORT_START 
 	DIPS_HELPER( 0x8000, "Arrow-Left",        KEYCODE_TILDE)
 	DIPS_HELPER( 0x4000, "1 !   BLK",         KEYCODE_1)
@@ -451,8 +439,7 @@ INPUT_PORTS_START (vic1001)
 	DIPS_HELPER( 0x0002, "RESTORE",               KEYCODE_PRTSCR)
 	PORT_START 
 	DIPS_HELPER( 0x8000, "STOP RUN",          KEYCODE_TAB)
-	PORT_BITX( 0x4000, IP_ACTIVE_HIGH, IPF_TOGGLE, 
-		   "SHIFT-LOCK (switch)", KEYCODE_CAPSLOCK, IP_JOY_NONE )
+	PORT_BIT( 0x4000, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("SHIFT-LOCK (switch)") PORT_CODE(KEYCODE_CAPSLOCK) PORT_TOGGLE
 	DIPS_HELPER( 0x2000, "A",                 KEYCODE_A)
 	DIPS_HELPER( 0x1000, "S",                 KEYCODE_S)
 	DIPS_HELPER( 0x0800, "D",                 KEYCODE_D)
@@ -501,18 +488,13 @@ INPUT_PORTS_END
 INPUT_PORTS_START (vic20i)
 	DIPS_JOY
 	PORT_START							   /* in 16 lightpen X */
-	PORT_ANALOGX (0xff, 0, IPT_PADDLE | IPF_PLAYER3,
-				  30, 2, 0, (VIC6560_MAME_XSIZE - 1),
-				  KEYCODE_LEFT, KEYCODE_RIGHT,
-				  JOYCODE_1_LEFT, JOYCODE_1_RIGHT)
+	PORT_BIT (0xff, 0, IPT_PADDLE) PORT_SENSITIVITY(30) PORT_KEYDELTA(2) PORT_MINMAX(0,(VIC6560_MAME_XSIZE - 1)) PORT_CODE_DEC(KEYCODE_LEFT) PORT_CODE_INC(KEYCODE_RIGHT) PORT_CODE_DEC(JOYCODE_1_LEFT) PORT_CODE_INC(JOYCODE_1_RIGHT) PORT_PLAYER(3)
 	PORT_START							   /* in 17 lightpen Y */
-	PORT_ANALOGX (0xff, 0, IPT_PADDLE | IPF_PLAYER4,
-				  30, 2, 0, (VIC6560_MAME_YSIZE - 1),
-				  KEYCODE_UP, KEYCODE_DOWN, JOYCODE_1_UP, JOYCODE_1_DOWN)
+	PORT_BIT (0xff, 0, IPT_PADDLE) PORT_SENSITIVITY(30) PORT_KEYDELTA(2) PORT_MINMAX(0,(VIC6560_MAME_YSIZE - 1)) PORT_CODE_DEC(KEYCODE_UP) PORT_CODE_INC(KEYCODE_DOWN) PORT_CODE_DEC(JOYCODE_1_UP) PORT_CODE_INC(JOYCODE_1_DOWN) PORT_PLAYER(4)
 	DIPS_INPUT
 	PORT_START
 	PORT_DIPNAME ( 0x07, 0, "RAM Cartridge")
-	PORT_DIPSETTING(	0, "None" )
+	PORT_DIPSETTING(	0, DEF_STR( None ) )
 	PORT_DIPSETTING(	1, "3k" )
 	PORT_DIPSETTING(	2, "8k" )
 	PORT_DIPSETTING(	3, "16k" )
@@ -534,7 +516,7 @@ INPUT_PORTS_START (vic20i)
 	PORT_DIPSETTING( 0x00, DEF_STR( No ) )
 	PORT_DIPSETTING( 0x80, DEF_STR( Yes ) )
 	PORT_START
-	PORT_DIPNAME   ( 0x80, 0x80, "Joystick")
+	PORT_DIPNAME   ( 0x80, 0x80, DEF_STR( Joystick ))
 	PORT_DIPSETTING( 0x00, DEF_STR( No ) )
 	PORT_DIPSETTING( 0x80, DEF_STR( Yes ) )
 	PORT_DIPNAME   ( 0x40, 0x40, "Paddles")
@@ -568,15 +550,9 @@ INPUT_PORTS_END
 INPUT_PORTS_START (vc20)
 	DIPS_JOY
 	PORT_START							   /* in 16 lightpen X */
-	PORT_ANALOGX (0xff, 0, IPT_PADDLE | IPF_PLAYER3,
-				  30, 2, 0, (VIC6561_MAME_XSIZE - 1),
-				  KEYCODE_LEFT, KEYCODE_RIGHT,
-				  JOYCODE_1_LEFT, JOYCODE_1_RIGHT)
+	PORT_BIT (0xff, 0, IPT_PADDLE) PORT_SENSITIVITY(30) PORT_KEYDELTA(2) PORT_MINMAX(0,(VIC6561_MAME_XSIZE - 1)) PORT_CODE_DEC(KEYCODE_LEFT) PORT_CODE_INC(KEYCODE_RIGHT) PORT_CODE_DEC(JOYCODE_1_LEFT) PORT_CODE_INC(JOYCODE_1_RIGHT) PORT_PLAYER(3)
 	PORT_START							   /* in 17 lightpen Y */
-	PORT_ANALOGX (0x1ff, 0, IPT_PADDLE | IPF_PLAYER4,
-				  30, 2, 0, (VIC6561_MAME_YSIZE - 1),
-				  KEYCODE_UP, KEYCODE_DOWN,
-				  JOYCODE_1_UP, JOYCODE_1_DOWN)
+	PORT_BIT (0x1ff, 0, IPT_PADDLE) PORT_SENSITIVITY(30) PORT_KEYDELTA(2) PORT_MINMAX(0,(VIC6561_MAME_YSIZE - 1)) PORT_CODE_DEC(KEYCODE_UP) PORT_CODE_INC(KEYCODE_DOWN) PORT_CODE_DEC(JOYCODE_1_UP) PORT_CODE_INC(JOYCODE_1_DOWN) PORT_PLAYER(4)
 	DIPS_INPUT
 	DIPS_BOTH
 INPUT_PORTS_END
@@ -585,15 +561,9 @@ INPUT_PORTS_END
 INPUT_PORTS_START (vic20swe)
 	DIPS_JOY
 	PORT_START							   /* in 16 lightpen X */
-	PORT_ANALOGX (0xff, 0, IPT_PADDLE | IPF_PLAYER3,
-				  30, 2, 0, (VIC6561_MAME_XSIZE - 1),
-				  KEYCODE_LEFT, KEYCODE_RIGHT,
-				  JOYCODE_1_LEFT, JOYCODE_1_RIGHT)
+	PORT_BIT (0xff, 0, IPT_PADDLE) PORT_SENSITIVITY(30) PORT_KEYDELTA(2) PORT_MINMAX(0,(VIC6561_MAME_XSIZE - 1)) PORT_CODE_DEC(KEYCODE_LEFT) PORT_CODE_INC(KEYCODE_RIGHT) PORT_CODE_DEC(JOYCODE_1_LEFT) PORT_CODE_INC(JOYCODE_1_RIGHT) PORT_PLAYER(3)
 	PORT_START							   /* in 17 lightpen Y */
-	PORT_ANALOGX (0x1ff, 0, IPT_PADDLE | IPF_PLAYER4,
-				  30, 2, 0, (VIC6561_MAME_YSIZE - 1),
-				  KEYCODE_UP, KEYCODE_DOWN,
-				  JOYCODE_1_UP, JOYCODE_1_DOWN)
+	PORT_BIT (0x1ff, 0, IPT_PADDLE) PORT_SENSITIVITY(30) PORT_KEYDELTA(2) PORT_MINMAX(0,(VIC6561_MAME_YSIZE - 1)) PORT_CODE_DEC(KEYCODE_UP) PORT_CODE_INC(KEYCODE_DOWN) PORT_CODE_DEC(JOYCODE_1_UP) PORT_CODE_INC(JOYCODE_1_DOWN) PORT_PLAYER(4)
 	PORT_START 
 	DIPS_HELPER( 0x8000, "Arrow-Left",        KEYCODE_TILDE)
 	DIPS_HELPER( 0x4000, "1 !   BLK",         KEYCODE_1)
@@ -629,8 +599,7 @@ INPUT_PORTS_START (vic20swe)
 	DIPS_HELPER( 0x0002, "RESTORE",               KEYCODE_PRTSCR)
 	PORT_START 
 	DIPS_HELPER( 0x8000, "STOP RUN",          KEYCODE_TAB)
-	PORT_BITX( 0x4000, IP_ACTIVE_HIGH, IPF_TOGGLE, 
-		   "SHIFT-LOCK (switch)", KEYCODE_CAPSLOCK, IP_JOY_NONE )
+	PORT_BIT( 0x4000, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("SHIFT-LOCK (switch)") PORT_CODE(KEYCODE_CAPSLOCK) PORT_TOGGLE
 	DIPS_HELPER( 0x2000, "A",                 KEYCODE_A)
 	DIPS_HELPER( 0x1000, "S",                 KEYCODE_S)
 	DIPS_HELPER( 0x0800, "D",                 KEYCODE_D)
@@ -677,423 +646,215 @@ INPUT_PORTS_END
 
 
 /* Initialise the vc20 palette */
-static void vc20_init_palette (unsigned char *sys_palette,
-							   unsigned short *sys_colortable,
-							   const unsigned char *color_prom)
+static PALETTE_INIT( vc20 )
 {
-	memcpy (sys_palette, vic6560_palette, sizeof (vic6560_palette));
+	palette_set_colors(0, vic6560_palette, sizeof(vic6560_palette) / 3);
 /*	memcpy(sys_colortable,colortable,sizeof(colortable)); */
 }
 
 #if 0
 	/* chargen */
-	ROM_LOAD ("901460.03", 0x8000, 0x1000, 0x83e032a6)
+	ROM_LOAD ("901460.03", 0x8000, 0x1000, CRC(83e032a6))
 	/* basic */
-	ROM_LOAD ("901486.01", 0xc000, 0x2000, 0xdb4c43c1)
+	ROM_LOAD ("901486.01", 0xc000, 0x2000, CRC(db4c43c1))
 	/* kernel ntsc-m of vic1001? */
-	ROM_LOAD ("901486.02", 0xe000, 0x2000, 0x336900d7)
+	ROM_LOAD ("901486.02", 0xe000, 0x2000, CRC(336900d7))
 	/* kernel ntsc */
-	ROM_LOAD ("901486.06", 0xe000, 0x2000, 0xe5e7c174)
+	ROM_LOAD ("901486.06", 0xe000, 0x2000, CRC(e5e7c174))
 	/* kernel pal */
-	ROM_LOAD ("901486.07", 0xe000, 0x2000, 0x4be07cb4)
+	ROM_LOAD ("901486.07", 0xe000, 0x2000, CRC(4be07cb4))
 
 	/* patched pal system for swedish/finish keyboard and chars */
 	/* but in rom? (maybe patched means in this case nec version) */
-	ROM_LOAD ("nec22101.207", 0x8000, 0x1000, 0xd808551d)
-	ROM_LOAD ("nec22081.206", 0xe000, 0x2000, 0xb2a60662)
+	ROM_LOAD ("nec22101.207", 0x8000, 0x1000, CRC(d808551d))
+	ROM_LOAD ("nec22081.206", 0xe000, 0x2000, CRC(b2a60662))
 
 	/* ieee488 cartridge */
-	ROM_LOAD ("325329-04.bin", 0xb000, 0x800, 0xd37b6335)
+	ROM_LOAD ("325329-04.bin", 0xb000, 0x800, CRC(d37b6335))
 #endif
 
 ROM_START (vic20)
 	ROM_REGION (0x10000, REGION_CPU1,0)
-	ROM_LOAD ("901460.03", 0x8000, 0x1000, 0x83e032a6)
-	ROM_LOAD ("901486.01", 0xc000, 0x2000, 0xdb4c43c1)
-	ROM_LOAD ("901486.06", 0xe000, 0x2000, 0xe5e7c174)
+	ROM_LOAD ("901460.03", 0x8000, 0x1000, CRC(83e032a6))
+	ROM_LOAD ("901486.01", 0xc000, 0x2000, CRC(db4c43c1))
+	ROM_LOAD ("901486.06", 0xe000, 0x2000, CRC(e5e7c174))
 ROM_END
 
 ROM_START (vic1001)
 	ROM_REGION (0x10000, REGION_CPU1,0)
-	ROM_LOAD ("901460.02", 0x8000, 0x1000, 0xfcfd8a4b)
-	ROM_LOAD ("901486.01", 0xc000, 0x2000, 0xdb4c43c1)
-	ROM_LOAD ("901486.02", 0xe000, 0x2000, 0x336900d7)
+	ROM_LOAD ("901460.02", 0x8000, 0x1000, CRC(fcfd8a4b))
+	ROM_LOAD ("901486.01", 0xc000, 0x2000, CRC(db4c43c1))
+	ROM_LOAD ("901486.02", 0xe000, 0x2000, CRC(336900d7))
 ROM_END
 
 ROM_START (vic20swe)
 	ROM_REGION (0x10000, REGION_CPU1,0)
-	ROM_LOAD ("nec22101.207", 0x8000, 0x1000, 0xd808551d)
-	ROM_LOAD ("901486.01", 0xc000, 0x2000, 0xdb4c43c1)
-	ROM_LOAD ("nec22081.206", 0xe000, 0x2000, 0xb2a60662)
+	ROM_LOAD ("nec22101.207", 0x8000, 0x1000, CRC(d808551d))
+	ROM_LOAD ("901486.01", 0xc000, 0x2000, CRC(db4c43c1))
+	ROM_LOAD ("nec22081.206", 0xe000, 0x2000, CRC(b2a60662))
 ROM_END
 
 ROM_START (vic20v)
 	ROM_REGION (0x10000, REGION_CPU1,0)
-	ROM_LOAD ("901460.03", 0x8000, 0x1000, 0x83e032a6)
-	ROM_LOAD ("901486.01", 0xc000, 0x2000, 0xdb4c43c1)
-	ROM_LOAD ("901486.06", 0xe000, 0x2000, 0xe5e7c174)
+	ROM_LOAD ("901460.03", 0x8000, 0x1000, CRC(83e032a6))
+	ROM_LOAD ("901486.01", 0xc000, 0x2000, CRC(db4c43c1))
+	ROM_LOAD ("901486.06", 0xe000, 0x2000, CRC(e5e7c174))
 	VC1540_ROM (REGION_CPU2)
 ROM_END
 
 ROM_START (vic20i)
 	ROM_REGION (0x10000, REGION_CPU1,0)
-	ROM_LOAD ("901460.03", 0x8000, 0x1000, 0x83e032a6)
-	ROM_LOAD ("325329.04", 0xb000, 0x800, 0xd37b6335)
-	ROM_LOAD ("901486.01", 0xc000, 0x2000, 0xdb4c43c1)
-	ROM_LOAD ("901486.06", 0xe000, 0x2000, 0xe5e7c174)
+	ROM_LOAD ("901460.03", 0x8000, 0x1000, CRC(83e032a6))
+	ROM_LOAD ("325329.04", 0xb000, 0x800, CRC(d37b6335))
+	ROM_LOAD ("901486.01", 0xc000, 0x2000, CRC(db4c43c1))
+	ROM_LOAD ("901486.06", 0xe000, 0x2000, CRC(e5e7c174))
 /*	C2031_ROM (REGION_CPU2) */
 ROM_END
 
 ROM_START (vc20)
 	ROM_REGION (0x10000, REGION_CPU1,0)
-	ROM_LOAD ("901460.03", 0x8000, 0x1000, 0x83e032a6)
-	ROM_LOAD ("901486.01", 0xc000, 0x2000, 0xdb4c43c1)
-	ROM_LOAD ("901486.07", 0xe000, 0x2000, 0x4be07cb4)
+	ROM_LOAD ("901460.03", 0x8000, 0x1000, CRC(83e032a6))
+	ROM_LOAD ("901486.01", 0xc000, 0x2000, CRC(db4c43c1))
+	ROM_LOAD ("901486.07", 0xe000, 0x2000, CRC(4be07cb4))
 ROM_END
 
 ROM_START (vc20v)
 	ROM_REGION (0x10000, REGION_CPU1,0)
-	ROM_LOAD ("901460.03", 0x8000, 0x1000, 0x83e032a6)
-	ROM_LOAD ("901486.01", 0xc000, 0x2000, 0xdb4c43c1)
-	ROM_LOAD ("901486.07", 0xe000, 0x2000, 0x4be07cb4)
+	ROM_LOAD ("901460.03", 0x8000, 0x1000, CRC(83e032a6))
+	ROM_LOAD ("901486.01", 0xc000, 0x2000, CRC(db4c43c1))
+	ROM_LOAD ("901486.07", 0xe000, 0x2000, CRC(4be07cb4))
 	VC1541_ROM (REGION_CPU2)
 ROM_END
 
-static struct MachineDriver machine_driver_vic20 =
-{
+static MACHINE_DRIVER_START( vic20 )
 	/* basic machine hardware */
-	{
-		{
-			CPU_M6502,
-			VIC6560_CLOCK,
-			vc20_readmem, vc20_writemem,
-			0, 0,
-			vc20_frame_interrupt, 1,
-			vic656x_raster_interrupt, VIC656X_HRETRACERATE,
-		},
-	},
-	VIC6560_VRETRACERATE, DEFAULT_REAL_60HZ_VBLANK_DURATION,	/* frames per second, vblank duration */
-	0,
-	vc20_init_machine,
-	vc20_shutdown_machine,
+	MDRV_CPU_ADD_TAG("main", M6502, VIC6560_CLOCK)        /* 7.8336 Mhz */
+	MDRV_CPU_PROGRAM_MAP(vc20_readmem, vc20_writemem)
+	MDRV_CPU_VBLANK_INT(vc20_frame_interrupt, 1)
+	MDRV_CPU_PERIODIC_INT(vic656x_raster_interrupt, TIME_IN_HZ(VIC656X_HRETRACERATE))
+	MDRV_FRAMES_PER_SECOND(VIC6560_VRETRACERATE)
+	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
+	MDRV_INTERLEAVE(0)
 
-	/* video hardware */
-	(VIC6560_XSIZE + 7) & ~7,		   /* screen width */
-	VIC6560_YSIZE,					   /* screen height */
-	{VIC6560_MAME_XPOS, VIC6560_MAME_XPOS + VIC6560_MAME_XSIZE - 1,
-	 VIC6560_MAME_YPOS, VIC6560_MAME_YPOS + VIC6560_MAME_YSIZE - 1},
-	0,								   /* graphics decode info */
-	sizeof (vic6560_palette) / sizeof (vic6560_palette[0]) / 3,
-	0,
-	vc20_init_palette,				   /* convert color prom */
-	VIDEO_TYPE_RASTER,
-	0,
-	vic6560_vh_start,
-	vic6560_vh_stop,
-	vic6560_vh_screenrefresh,
+	MDRV_MACHINE_INIT( vc20 )
+
+    /* video hardware */
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_SIZE((VIC6560_XSIZE + 7) & ~7, VIC6560_YSIZE)
+	MDRV_VISIBLE_AREA(VIC6560_MAME_XPOS, VIC6560_MAME_XPOS + VIC6560_MAME_XSIZE - 1, VIC6560_MAME_YPOS, VIC6560_MAME_YPOS + VIC6560_MAME_YSIZE - 1)
+	MDRV_PALETTE_LENGTH(sizeof (vic6560_palette) / sizeof (vic6560_palette[0]) / 3)
+	MDRV_PALETTE_INIT( vc20 )
+
+	MDRV_VIDEO_START( vic6560 )
+	MDRV_VIDEO_STOP( vic6560 )
+	MDRV_VIDEO_UPDATE( vic6560 )
 
 	/* sound hardware */
-	0, 0, 0, 0,
-	{
-		{SOUND_CUSTOM, &vic6560_sound_interface},
-		{SOUND_DAC, &vc20tape_sound_interface}
-	}
-};
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(CUSTOM, 0)
+	MDRV_SOUND_CONFIG(vic6560_sound_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+MACHINE_DRIVER_END
 
-static struct MachineDriver machine_driver_vic20v =
-{
-	/* basic machine hardware */
-	{
-		{
-			CPU_M6502,
-			VIC6560_CLOCK,
-			vc20_readmem, vc20_writemem,
-			0, 0,
-			vc20_frame_interrupt, 1,
-			vic656x_raster_interrupt, VIC656X_HRETRACERATE,
-		},
-		VC1540_CPU,
-	},
-	VIC6560_VRETRACERATE, DEFAULT_REAL_60HZ_VBLANK_DURATION,	/* frames per second, vblank duration */
+
+static MACHINE_DRIVER_START( vic20v )
+	MDRV_IMPORT_FROM( vic20 )
+	MDRV_IMPORT_FROM( cpu_vc1540 )
 #ifdef CPU_SYNC
-	1,
+	MDRV_INTERLEAVE(1)
 #else
-	3000,
+	MDRV_INTERLEAVE(3000)
 #endif
-	vc20_init_machine,
-	vc20_shutdown_machine,
+MACHINE_DRIVER_END
 
-	/* video hardware */
-	(VIC6560_XSIZE + 7) & ~7,		   /* screen width */
-	VIC6560_YSIZE,					   /* screen height */
-	{VIC6560_MAME_XPOS, VIC6560_MAME_XPOS + VIC6560_MAME_XSIZE - 1,
-	 VIC6560_MAME_YPOS, VIC6560_MAME_YPOS + VIC6560_MAME_YSIZE - 1},
-	0,								   /* graphics decode info */
-	sizeof (vic6560_palette) / sizeof (vic6560_palette[0]) / 3,
-	0,
-	vc20_init_palette,				   /* convert color prom */
-	VIDEO_TYPE_RASTER,
-	0,
-	vic6560_vh_start,
-	vic6560_vh_stop,
-	vic6560_vh_screenrefresh,
 
-	/* sound hardware */
-	0, 0, 0, 0,
-	{
-		{SOUND_CUSTOM, &vic6560_sound_interface},
-		{SOUND_DAC, &vc20tape_sound_interface}
-	}
-};
-
-static struct MachineDriver machine_driver_vic20i =
-{
-	/* basic machine hardware */
-	{
-		{
-			CPU_M6502,
-			VIC6560_CLOCK,
-			vc20i_readmem, vc20i_writemem,
-			0, 0,
-			vc20_frame_interrupt, 1,
-			vic656x_raster_interrupt, VIC656X_HRETRACERATE,
-		},
-/*		C2031_CPU, */
-	},
-	VIC6560_VRETRACERATE, DEFAULT_REAL_60HZ_VBLANK_DURATION,	/* frames per second, vblank duration */
-#if 1 || defined CPU_SYNC
-	1,
+static MACHINE_DRIVER_START( vic20i )
+	MDRV_IMPORT_FROM( vic20 )
+	/*MDRV_IMPORT_FROM( cpu_c2031 )*/
+#if 1 || CPU_SYNC
+	MDRV_INTERLEAVE(1)
 #else
-	3000,
+	MDRV_INTERLEAVE(3000)
 #endif
-	vc20_init_machine,
-	vc20_shutdown_machine,
 
-	/* video hardware */
-	(VIC6560_XSIZE + 7) & ~7,		   /* screen width */
-	VIC6560_YSIZE,					   /* screen height */
-	{VIC6560_MAME_XPOS, VIC6560_MAME_XPOS + VIC6560_MAME_XSIZE - 1,
-	 VIC6560_MAME_YPOS, VIC6560_MAME_YPOS + VIC6560_MAME_YSIZE - 1},
-	0,								   /* graphics decode info */
-	sizeof (vic6560_palette) / sizeof (vic6560_palette[0]) / 3,
-	0,
-	vc20_init_palette,				   /* convert color prom */
-	VIDEO_TYPE_RASTER,
-	0,
-	vic6560_vh_start,
-	vic6560_vh_stop,
-	vic6560_vh_screenrefresh,
+	MDRV_CPU_MODIFY( "main" )
+	MDRV_CPU_PROGRAM_MAP( vc20i_readmem, vc20i_writemem )
+MACHINE_DRIVER_END
 
-	/* sound hardware */
-	0, 0, 0, 0,
-	{
-		{SOUND_CUSTOM, &vic6560_sound_interface},
-		{SOUND_DAC, &vc20tape_sound_interface}
-	}
-};
 
-static struct MachineDriver machine_driver_vc20 =
-{
-	/* basic machine hardware */
-	{
-		{
-			CPU_M6502,
-			VIC6561_CLOCK,
-			vc20_readmem, vc20_writemem,
-			0, 0,
-			vc20_frame_interrupt, 1,
-			vic656x_raster_interrupt, VIC656X_HRETRACERATE,
-		},
-	},
-	VIC6561_VRETRACERATE, DEFAULT_REAL_60HZ_VBLANK_DURATION,	/* frames per second, vblank duration */
-	0,
-	vc20_init_machine,
-	vc20_shutdown_machine,
+static MACHINE_DRIVER_START( vc20 )
+	MDRV_IMPORT_FROM( vic20 )
 
-	/* video hardware */
-	(VIC6561_XSIZE + 7) & ~7,		   /* screen width */
-	VIC6561_YSIZE,					   /* screen height */
-	{VIC6561_MAME_XPOS, VIC6561_MAME_XPOS + VIC6561_MAME_XSIZE - 1,
-	 VIC6561_MAME_YPOS, VIC6561_MAME_YPOS + VIC6561_MAME_YSIZE - 1},	/* visible_area */
-	0,								   /* graphics decode info */
-	sizeof (vic6560_palette) / sizeof (vic6560_palette[0]) / 3,
-	0,
-	vc20_init_palette,				   /* convert color prom */
-	VIDEO_TYPE_RASTER,
-	0,
-	vic6560_vh_start,
-	vic6560_vh_stop,
-	vic6560_vh_screenrefresh,
+	MDRV_CPU_REPLACE( "main", M6502, VIC6561_CLOCK )
+	MDRV_CPU_PROGRAM_MAP( vc20i_readmem, vc20i_writemem )
 
-	/* sound hardware */
-	0, 0, 0, 0,
-	{
-		{SOUND_CUSTOM, &vic6560_sound_interface},
-		{SOUND_DAC, &vc20tape_sound_interface}
-	}
-};
+	MDRV_FRAMES_PER_SECOND(VIC6561_VRETRACERATE)
+	MDRV_SCREEN_SIZE((VIC6561_XSIZE + 7) & ~7, VIC6561_YSIZE)
+	MDRV_VISIBLE_AREA(VIC6561_MAME_XPOS, VIC6561_MAME_XPOS + VIC6561_MAME_XSIZE - 1, VIC6561_MAME_YPOS, VIC6561_MAME_YPOS + VIC6561_MAME_YSIZE - 1)
+MACHINE_DRIVER_END
 
-static struct MachineDriver machine_driver_vc20v =
-{
-	/* basic machine hardware */
-	{
-		{
-			CPU_M6502,
-			VIC6561_CLOCK,
-			vc20_readmem, vc20_writemem,
-			0, 0,
-			vc20_frame_interrupt, 1,
-			vic656x_raster_interrupt, VIC656X_HRETRACERATE,
-		},
-		VC1541_CPU,
-	},
-	VIC6561_VRETRACERATE, DEFAULT_REAL_60HZ_VBLANK_DURATION,	/* frames per second, vblank duration */
+
+static MACHINE_DRIVER_START( vc20v )
+	MDRV_IMPORT_FROM( vc20 )
+	MDRV_IMPORT_FROM( cpu_vc1540 )
 #ifdef CPU_SYNC
-	1,
+	MDRV_INTERLEAVE(1)
 #else
-	3000,
-#endif
-	vc20_init_machine,
-	vc20_shutdown_machine,
-
-	/* video hardware */
-	(VIC6561_XSIZE + 7) & ~7,		   /* screen width */
-	VIC6561_YSIZE,					   /* screen height */
-	{VIC6561_MAME_XPOS, VIC6561_MAME_XPOS + VIC6561_MAME_XSIZE - 1,
-	 VIC6561_MAME_YPOS, VIC6561_MAME_YPOS + VIC6561_MAME_YSIZE - 1},	/* visible_area */
-	0,								   /* graphics decode info */
-	sizeof (vic6560_palette) / sizeof (vic6560_palette[0]) / 3,
-	0,
-	vc20_init_palette,				   /* convert color prom */
-	VIDEO_TYPE_RASTER,
-	0,
-	vic6560_vh_start,
-	vic6560_vh_stop,
-	vic6560_vh_screenrefresh,
-
-	/* sound hardware */
-	0, 0, 0, 0,
-	{
-		{SOUND_CUSTOM, &vic6560_sound_interface},
-		{SOUND_DAC, &vc20tape_sound_interface}
-	}
-};
-
-static const struct IODevice io_vc20[] =
-{
-	IODEVICE_CBM_QUICK,
-	{
-		IO_CARTSLOT,				   /* type */
-		2,							   /* normal 1 *//* count */
-		"a0\00020\00040\00060\0rom\0bin\0",/* file extensions */
-		IO_RESET_ALL,				   /* reset if file changed */
-		0,
-		vc20_rom_load,				   /* init */
-		NULL,						   /* exit */
-		NULL,						   /* info */
-		NULL,						   /* open */
-		NULL,						   /* close */
-		NULL,						   /* status */
-		NULL,						   /* seek */
-		NULL,						   /* input */
-		NULL,						   /* output */
-		NULL,						   /* input_chunk */
-		NULL						   /* output_chunk */
-	},
-	IODEVICE_VC20TAPE,
-	IODEVICE_CBM_DRIVE,
-	{IO_END}
-};
-
-static const struct IODevice io_vc20v[] =
-{
-	IODEVICE_CBM_QUICK,
-	{
-		IO_CARTSLOT,				   /* type */
-		2,							   /* normal 1 *//* count */
-		"a0\00020\00040\00060\0rom\0bin\0",/* file extensions */
-		IO_RESET_ALL,				   /* reset if file changed */
-		0,
-		vc20_rom_load,				   /* init */
-		NULL,						   /* exit */
-		NULL,						   /* info */
-		NULL,						   /* open */
-		NULL,						   /* close */
-		NULL,						   /* status */
-		NULL,						   /* seek */
-		NULL,						   /* input */
-		NULL,						   /* output */
-		NULL,						   /* input_chunk */
-		NULL						   /* output_chunk */
-	},
-	IODEVICE_VC20TAPE,
-	IODEVICE_VC1541,
-	{IO_END}
-};
-
-#ifdef PET_TEST_CODE
-static const struct IODevice io_vc20i[] =
-{
-	IODEVICE_CBM_QUICK,
-	{
-		IO_CARTSLOT,				   /* type */
-		2,							   /* normal 1 *//* count */
-		"a0\00020\00040\00060\0rom\0bin\0",/* file extensions */
-		IO_RESET_ALL,				   /* reset if file changed */
-		0,
-		vc20_rom_load,				   /* init */
-		NULL,						   /* exit */
-		NULL,						   /* info */
-		NULL,						   /* open */
-		NULL,						   /* close */
-		NULL,						   /* status */
-		NULL,						   /* seek */
-		NULL,						   /* input */
-		NULL,						   /* output */
-		NULL,						   /* input_chunk */
-		NULL						   /* output_chunk */
-	},
-	IODEVICE_VC20TAPE,
-	IODEVICE_C2031,
-	{IO_END}
-};
+	MDRV_INTERLEAVE(3000)
 #endif
+MACHINE_DRIVER_END
 
 #define init_vc20		vc20_driver_init
 #define init_vic20		vic20_driver_init
-#define init_vic1001		vic20_driver_init
+#define init_vic1001	vic20_driver_init
 #define init_vic20i 	vic20ieee_driver_init
-#define io_vic20		io_vc20
-#define io_vic1001		io_vc20
-#define io_vic20swe 	io_vc20
-#define io_vic20v		io_vc20v
-/*#define io_vic20i 	io_vc20i */
-#define io_vic20i		io_vc20
 
-/*		YEAR	NAME		PARENT	MACHINE INPUT		INIT	COMPANY 							FULLNAME */
-
-COMPX ( 1981,	vic20,		0,		vic20,	vic20,		vic20,	"Commodore Business Machines Co.",  "VIC20 (NTSC)", GAME_IMPERFECT_SOUND)
-COMPX ( 1981,	vic20i, 	vic20,	vic20i, vic20i, 	vic20i, "Commodore Business Machines Co.",  "VIC20 (NTSC), IEEE488 Interface (SYS45065)",   GAME_IMPERFECT_SOUND)
-COMPX ( 1981,	vic1001,	vic20,	vic20,	vic1001,		vic20,	"Commodore Business Machines Co.",  "VIC1001 (NTSC)", GAME_IMPERFECT_SOUND)
-COMPX ( 1981,	vc20,		vic20,	vc20,	vc20,		vc20,	"Commodore Business Machines Co.",  "VIC20/VC20(German) PAL",       GAME_IMPERFECT_SOUND)
-COMPX ( 1981,	vic20swe,	vic20,	vc20,	vic20swe,		vc20,	"Commodore Business Machines Co.",  "VIC20 PAL, Swedish Expansion Kit", GAME_IMPERFECT_SOUND)
-/* please leave the following as testdriver only */
-COMPX ( 1981,	vic20v, 	vic20,	vic20v, vic20,		vic20,	"Commodore Business Machines Co.",  "VIC20 (NTSC), VC1540", GAME_IMPERFECT_SOUND)
-COMPX ( 1981,	vc20v,		vic20,	vc20v,	vic20,		vc20,	"Commodore Business Machines Co.",  "VC20 (PAL), VC1541", GAME_IMPERFECT_SOUND)
-
-
-#ifdef RUNTIME_LOADER
-extern void vc20_runtime_loader_init(void)
+static void cbmvc20_cartslot_getinfo(struct IODevice *dev)
 {
-	int i;
-	for (i=0; drivers[i]; i++) {
-		if ( strcmp(drivers[i]->name,"vic20")==0) drivers[i]=&driver_vic20;
-		if ( strcmp(drivers[i]->name,"vic1001")==0) drivers[i]=&driver_vic1001;
-		if ( strcmp(drivers[i]->name,"vic20i")==0) drivers[i]=&driver_vic20i;
-		if ( strcmp(drivers[i]->name,"vc20")==0) drivers[i]=&driver_vc20;
-		if ( strcmp(drivers[i]->name,"vic20swe")==0) drivers[i]=&driver_vic20swe;
-		if ( strcmp(drivers[i]->name,"vic20v")==0) drivers[i]=&driver_vic20v;
-		if ( strcmp(drivers[i]->name,"vc20v")==0) drivers[i]=&driver_vc20v;
-	}
+	cartslot_device_getinfo(dev);
+	dev->count = 2;
+	dev->file_extensions = "a0\00020\00040\00060\0rom\0bin\0";
+	dev->init = device_init_vc20_rom;
+	dev->load = device_load_vc20_rom;
 }
+
+static void vc20_quickload_getinfo(struct IODevice *dev)
+{
+	quickload_device_getinfo(dev, quickload_load_cbm_vc20, CBM_QUICKLOAD_DELAY);
+	dev->file_extensions = "p00\0prg\0";
+}
+
+SYSTEM_CONFIG_START(vc20)
+	CONFIG_DEVICE(cbmvc20_cartslot_getinfo)
+	CONFIG_DEVICE(cbmfloppy_device_getinfo)
+	CONFIG_DEVICE(vc20_quickload_getinfo)
+	CONFIG_DEVICE(vc20tape_device_getinfo)
+SYSTEM_CONFIG_END
+
+SYSTEM_CONFIG_START(vc20v)
+	CONFIG_DEVICE(cbmvc20_cartslot_getinfo)
+	CONFIG_DEVICE(vc20_quickload_getinfo)
+	CONFIG_DEVICE(vc20tape_device_getinfo)
+	CONFIG_DEVICE(vc1541_device_getinfo)
+SYSTEM_CONFIG_END
+
+#ifdef PET_TEST_CODE
+SYSTEM_CONFIG_START(vc20i)
+	CONFIG_DEVICE(cbmvc20_cartslot_getinfo)
+	CONFIG_DEVICE(vc20_quickload_getinfo)
+	CONFIG_DEVICE(vc20tape_device_getinfo)
+	CONFIG_DEVICE(c2031_device_getinfo)
+SYSTEM_CONFIG_END
 #endif
+
+/*		YEAR	NAME		PARENT	COMPAT	MACHINE INPUT		INIT	CONFIG     COMPANY 							FULLNAME */
+COMPX ( 1981,	vic20,		0,		0,		vic20,	vic20,		vic20,	vc20,      "Commodore Business Machines Co.",  "VIC20 (NTSC)", GAME_IMPERFECT_SOUND)
+COMPX ( 1981,	vic20i, 	vic20,	0,		vic20i, vic20i, 	vic20i, vc20,      "Commodore Business Machines Co.",  "VIC20 (NTSC), IEEE488 Interface (SYS45065)",   GAME_IMPERFECT_SOUND)
+COMPX ( 1981,	vic1001,	vic20,	0,		vic20,	vic1001,	vic20,	vc20,      "Commodore Business Machines Co.",  "VIC1001 (NTSC)", GAME_IMPERFECT_SOUND)
+COMPX ( 1981,	vc20,		vic20,	0,		vc20,	vc20,		vc20,	vc20,      "Commodore Business Machines Co.",  "VIC20/VC20(German) PAL",       GAME_IMPERFECT_SOUND)
+COMPX ( 1981,	vic20swe,	vic20,	0,		vc20,	vic20swe,	vc20,	vc20,      "Commodore Business Machines Co.",  "VIC20 PAL, Swedish Expansion Kit", GAME_IMPERFECT_SOUND)
+/* please leave the following as testdriver only */
+COMPX ( 1981,	vic20v, 	vic20,	0,		vic20v, vic20,		vic20,	vc20v,     "Commodore Business Machines Co.",  "VIC20 (NTSC), VC1540", GAME_IMPERFECT_SOUND)
+COMPX ( 1981,	vc20v,		vic20,	0,		vc20v,	vic20,		vc20,	vc20v,     "Commodore Business Machines Co.",  "VC20 (PAL), VC1541", GAME_IMPERFECT_SOUND)
