@@ -83,6 +83,7 @@ Bit 6 	Bit 5
 
 
 static crtc6845_state crtc;
+static m6845_personality_t personality;
 
 #if 0
 /* VSYNC functions */
@@ -134,6 +135,7 @@ void crtc6845_config(const struct crtc6845_interface *intf)
 	crct6845_calls.out_DE_func=*intf->out_DE_func;
 	crct6845_calls.out_CR_func=*intf->out_CR_func;
 	crct6845_calls.out_CRE_func=*intf->out_CRE_func;
+	personality = M6845_PERSONALITY_GENUINE;
 }
 
 void	crtc6845_start(void)
@@ -144,15 +146,6 @@ void	crtc6845_start(void)
 #endif
 }
 
-void	crtc6845_stop(void)
-{
-#if 0
-	crtc6845_remove_vsync_set_timer();
-	crtc6845_remove_vsync_clear_timer();
-#endif
-}
-
-
 /* 6845 registers */
 
 /* functions to set the 6845 registers */
@@ -265,10 +258,42 @@ void crtc6845_register_w(int offset, int data)
 
 int crtc6845_register_r(int offset)
 {
-	int retval=0;
+	int retval;
 
 	switch (crtc.address_register)
 	{
+		case 12:
+			switch(personality)
+			{
+				case M6845_PERSONALITY_UM6845:
+				case M6845_PERSONALITY_HD6845S:
+				case M6845_PERSONALITY_AMS40489:
+				case M6845_PERSONALITY_PREASIC:
+					/* not sure about M6845_PERSONALITY_PREASIC */
+					retval=R12_screen_start_address_H;
+					break;
+					
+				default:
+					retval = 0;
+					break;
+			}
+			break;
+		case 13:
+			switch(personality)
+			{
+				case M6845_PERSONALITY_UM6845:
+				case M6845_PERSONALITY_HD6845S:
+				case M6845_PERSONALITY_AMS40489:
+				case M6845_PERSONALITY_PREASIC:
+					/* not sure about M6845_PERSONALITY_PREASIC */
+					retval=R13_screen_start_address_L;
+					break;
+					
+				default:
+					retval = 0;
+					break;
+			}
+			break;
 		case 14:
 			retval=R14_cursor_address_H;
 			break;
@@ -282,6 +307,7 @@ int crtc6845_register_r(int offset)
 			retval=R17_light_pen_address_L;
 			break;
 		default:
+			retval = 0;
 			break;
 	}
 	return retval;
@@ -327,7 +353,7 @@ void	crtc6845_reset(int which)
 /* called when the internal horizontal display enabled or the
 vertical display enabled changed to set up the real
 display enabled output (which may be delayed 0,1 or 2 characters */
-void check_display_enabled(void)
+static void check_display_enabled(void)
 {
 	int Next_Display_Enabled;
 
@@ -638,6 +664,11 @@ int crtc6845_vertical_sync_r(int offset)   { return crtc.VSYNC; }             /*
 int crtc6845_display_enabled_r(int offset) { return crtc.Display_Delayed_Enabled; }   /* DE = Display Enabled */
 int crtc6845_cursor_enabled_r(int offset)  { return crtc.Cursor_Delayed_Status; }             /* CR = Cursor Enabled */
 
+void crtc6845_set_personality(m6845_personality_t p)
+{
+	personality = p;
+}
+
 #if 0
 
 /* KT:
@@ -733,7 +764,7 @@ static void crtc6845_remove_vsync_set_timer(void)
 {
 	if (crtc6845_vsync_set_timer!=NULL)
 	{
-		timer_remove(crtc6845_vsync_set_timer);
+		timer_remove(crtc6845_vsync_set_timer);	/* FIXME - timers should only be allocated once */
 		crtc6845_vsync_set_timer = NULL;
 	}
 }
@@ -743,7 +774,7 @@ static void crtc6845_remove_vsync_clear_timer(void)
 {
 	if (crtc6845_vsync_clear_timer!=NULL)
 	{
-		timer_remove(crtc6845_vsync_clear_timer);
+		timer_reset(crtc6845_vsync_clear_timer, TIME_NEVER);	/* FIXME - timers should only be allocated once */
 		crtc6845_vsync_clear_timer = NULL;
 	}
 }
