@@ -13,9 +13,14 @@ to a NOP to jump to it immediately at the beginning of a round.
 I'm not sure about the refresh rate, 60Hz makes time match the dip switch
 settings, but music runs too fast.
 
+TS 20050212:
+- added Kyuukyoku no Othello - problems with gfx
+  (wrong data copied to HD63484 ?)
+
 ***************************************************************************/
 
 #include "driver.h"
+#include "sndhrdw/seibu.h"
 
 /* the on-chip FIFO is 16 bytes long, but we use a larger one to simplify */
 /* decoding of long commands. Commands can be up to 64KB long... but Shanghai */
@@ -52,7 +57,7 @@ static int instruction_length[64] =
 	 5, 5, 5, 5 	/* Fx */
 };
 
-static char *instruction_name[64] =
+static const char *instruction_name[64] =
 {
 	"undef","ORG  ","WPR  ","RPR  ",	/* 0x */
 	"undef","undef","WPTN ","RPTN ",	/* 1x */
@@ -75,7 +80,7 @@ static char *instruction_name[64] =
 int HD63484_start(void)
 {
 	fifo_counter = 0;
-	HD63484_ram = malloc(HD63484_RAM_SIZE);
+	HD63484_ram = auto_malloc(HD63484_RAM_SIZE);
 	if (!HD63484_ram) return 1;
 	memset(HD63484_ram,0,HD63484_RAM_SIZE);
 	return 0;
@@ -83,8 +88,6 @@ int HD63484_start(void)
 
 void HD63484_stop(void)
 {
-	free(HD63484_ram);
-	HD63484_ram = 0;
 }
 
 static void doclr(int opcode,UINT16 fill,int *dst,INT16 _ax,INT16 _ay)
@@ -318,7 +321,7 @@ void HD63484_command_w(UINT16 cmd)
 	{
 		int i;
 
-		logerror("PC %05x: HD63484 command %s (%04x) ",cpu_get_pc(),instruction_name[fifo[0]>>10],fifo[0]);
+		logerror("PC %05x: HD63484 command %s (%04x) ",activecpu_get_pc(),instruction_name[fifo[0]>>10],fifo[0]);
 		for (i = 1;i < fifo_counter;i++)
 			logerror("%04x ",fifo[i]);
 		logerror("\n");
@@ -390,7 +393,7 @@ rwp /= 2;
 			cpx = fifo[1];
 			cpy = fifo[2];
 		}
-/*		else if ((fifo[0] & 0xff00) == 0x8800)	   ALINE    */
+/*      else if ((fifo[0] & 0xff00) == 0x8800)     ALINE    */
 		else if ((fifo[0] & 0xfff8) == 0x8800)	/* ALINE */
 		{
 			INT16 ex,ey,sx,sy;
@@ -446,7 +449,7 @@ rwp /= 2;
 				}
 			}
 		}
-/*		else if ((fifo[0] & 0xff00) == 0x9000)	   ARCT    */
+/*      else if ((fifo[0] & 0xff00) == 0x9000)     ARCT    */
 		else if ((fifo[0] & 0xfff8) == 0x9000)	/* ARCT */
 		{
 			INT16 pcx,pcy;
@@ -529,7 +532,7 @@ rwp /= 2;
 				}
 			}
 		}
-/*		else if ((fifo[0] & 0xff00) == 0xc000)	   AFRCT    */
+/*      else if ((fifo[0] & 0xff00) == 0xc000)     AFRCT    */
 		else if ((fifo[0] & 0xfff8) == 0xc000)	/* AFRCT */
 		{
 			INT16 pcx,pcy;
@@ -576,7 +579,7 @@ rwp /= 2;
 				}
 			}
 		}
-/*		else if ((fifo[0] & 0xff00) == 0xcc00)	   DOT    */
+/*      else if ((fifo[0] & 0xff00) == 0xcc00)     DOT    */
 		else if ((fifo[0] & 0xfff8) == 0xcc00)	/* DOT */
 		{
 			int dst;
@@ -585,7 +588,7 @@ rwp /= 2;
 
 			PLOT(dst,fifo[0] & 0x0007)
 		}
-/*		else if ((fifo[0] & 0xf000) == 0xe000)	   AGCPY    */
+/*      else if ((fifo[0] & 0xf000) == 0xe000)     AGCPY    */
 		else if ((fifo[0] & 0xf0f8) == 0xe000)	/* AGCPY */
 		{
 			INT16 pcx,pcy;
@@ -604,7 +607,7 @@ rwp /= 2;
 		else
 {
 logerror("unsupported command\n");
-usrintf_showmessage("unsupported command %s (%04x)",instruction_name[fifo[0]>>10],fifo[0]);
+ui_popup("unsupported command %s (%04x)",instruction_name[fifo[0]>>10],fifo[0]);
 }
 
 		fifo_counter = 0;
@@ -613,25 +616,25 @@ usrintf_showmessage("unsupported command %s (%04x)",instruction_name[fifo[0]>>10
 
 static int regno;
 
-static READ_HANDLER( HD63484_status_r )
+static READ8_HANDLER( HD63484_status_r )
 {
 	if (offset == 1) return 0xff;	/* high 8 bits - not used */
 
-	if (cpu_get_pc() != 0xfced6 && cpu_get_pc() != 0xfe1d6) logerror("%05x: HD63484 status read\n",cpu_get_pc());
+	if (activecpu_get_pc() != 0xfced6 && activecpu_get_pc() != 0xfe1d6) logerror("%05x: HD63484 status read\n",activecpu_get_pc());
 	return 0x22|4;	/* write FIFO ready + command end    + read FIFO ready */
 }
 
-static WRITE_HANDLER( HD63484_address_w )
+static WRITE8_HANDLER( HD63484_address_w )
 {
 	static unsigned char reg[2];
 
 	reg[offset] = data;
 	regno = reg[0];	/* only low 8 bits are used */
 /*if (offset == 0) */
-/*	logerror("PC %05x: HD63484 select register %02x\n",cpu_get_pc(),regno); */
+/*  logerror("PC %05x: HD63484 select register %02x\n",activecpu_get_pc(),regno); */
 }
 
-static WRITE_HANDLER( HD63484_data_w )
+static WRITE8_HANDLER( HD63484_data_w )
 {
 	static unsigned char dat[2];
 
@@ -644,14 +647,14 @@ static WRITE_HANDLER( HD63484_data_w )
 			HD63484_command_w(val);
 		else
 		{
-logerror("PC %05x: HD63484 register %02x write %04x\n",cpu_get_pc(),regno,val);
+logerror("PC %05x: HD63484 register %02x write %04x\n",activecpu_get_pc(),regno,val);
 			HD63484_reg[regno/2] = val;
 			if (regno & 0x80) regno += 2;	/* autoincrement */
 		}
 	}
 }
 
-static READ_HANDLER( HD63484_data_r )
+static READ8_HANDLER( HD63484_data_r )
 {
 	int res;
 
@@ -661,12 +664,12 @@ static READ_HANDLER( HD63484_data_r )
 	}
 	else if (regno == 0)
 	{
-logerror("%05x: HD63484 read FIFO\n",cpu_get_pc());
+logerror("%05x: HD63484 read FIFO\n",activecpu_get_pc());
 		res = readfifo;
 	}
 	else
 	{
-logerror("%05x: HD63484 read register %02x\n",cpu_get_pc(),regno);
+logerror("%05x: HD63484 read register %02x\n",activecpu_get_pc(),regno);
 		res = 0;
 	}
 
@@ -679,45 +682,47 @@ logerror("%05x: HD63484 read register %02x\n",cpu_get_pc(),regno);
 
 
 
-void shanghai_vh_convert_color_prom(unsigned char *palette, unsigned short *colortable,const unsigned char *color_prom)
+PALETTE_INIT( shanghai )
 {
 	int i;
 
 
 	for (i = 0;i < Machine->drv->total_colors;i++)
 	{
-		int bit0,bit1,bit2;
+		int bit0,bit1,bit2,r,g,b;
 
 
 		/* red component */
 		bit0 = (i >> 2) & 0x01;
 		bit1 = (i >> 3) & 0x01;
 		bit2 = (i >> 4) & 0x01;
-		*(palette++) = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
+		r = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
 		/* green component */
 		bit0 = (i >> 5) & 0x01;
 		bit1 = (i >> 6) & 0x01;
 		bit2 = (i >> 7) & 0x01;
-		*(palette++) = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
+		g = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
 		/* blue component */
 		bit0 = 0;
 		bit1 = (i >> 0) & 0x01;
 		bit2 = (i >> 1) & 0x01;
-		*(palette++) = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
+		b = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
+
+		palette_set_color(i,r,g,b);
 	}
 }
 
-int shanghai_vh_start(void)
+VIDEO_START( shanghai )
 {
 	return HD63484_start();
 }
 
-void shanghai_vh_stop(void)
+VIDEO_STOP( shanghai )
 {
 	HD63484_stop();
 }
 
-void shanghai_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( shanghai )
 {
 	int x,y,b;
 
@@ -756,97 +761,124 @@ void shanghai_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 }
 
 
-static int shanghai_interrupt(void)
+static INTERRUPT_GEN( shanghai_interrupt )
 {
-	interrupt_vector_w(0,0x80);
-	return interrupt();
+	cpunum_set_input_line_and_vector(0,0,HOLD_LINE,0x80);
 }
 
-static WRITE_HANDLER( shanghai_coin_w )
+static WRITE8_HANDLER( shanghai_coin_w )
 {
 	coin_counter_w(0,data & 1);
 	coin_counter_w(1,data & 2);
 }
 
-static MEMORY_READ_START( readmem )
-	{ 0x00000, 0x03fff, MRA_RAM },
-	{ 0x80000, 0xfffff, MRA_ROM },
-MEMORY_END
+static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x00000, 0x03fff) AM_READ(MRA8_RAM)
+	AM_RANGE(0x80000, 0xfffff) AM_READ(MRA8_ROM)
+ADDRESS_MAP_END
 
-static MEMORY_WRITE_START( writemem )
-	{ 0x00000, 0x03fff, MWA_RAM },
-	{ 0x80000, 0xfffff, MWA_ROM },
-MEMORY_END
+static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x00000, 0x03fff) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0x80000, 0xfffff) AM_WRITE(MWA8_ROM)
+ADDRESS_MAP_END
 
-static PORT_READ_START( readport )
-	{ 0x00, 0x01, HD63484_status_r },
-	{ 0x02, 0x03, HD63484_data_r },
-	{ 0x20, 0x20, YM2203_status_port_0_r },
-	{ 0x22, 0x22, YM2203_read_port_0_r },
-	{ 0x40, 0x40, input_port_0_r },
-	{ 0x44, 0x44, input_port_1_r },
-	{ 0x48, 0x48, input_port_2_r },
-PORT_END
+static ADDRESS_MAP_START( readport, ADDRESS_SPACE_IO, 8 )
+	AM_RANGE(0x00, 0x01) AM_READ(HD63484_status_r)
+	AM_RANGE(0x02, 0x03) AM_READ(HD63484_data_r)
+	AM_RANGE(0x20, 0x20) AM_READ(YM2203_status_port_0_r)
+	AM_RANGE(0x22, 0x22) AM_READ(YM2203_read_port_0_r)
+	AM_RANGE(0x40, 0x40) AM_READ(input_port_0_r)
+	AM_RANGE(0x44, 0x44) AM_READ(input_port_1_r)
+	AM_RANGE(0x48, 0x48) AM_READ(input_port_2_r)
+ADDRESS_MAP_END
 
-static PORT_WRITE_START( writeport )
-	{ 0x00, 0x01, HD63484_address_w },
-	{ 0x02, 0x03, HD63484_data_w },
-	{ 0x20, 0x20, YM2203_control_port_0_w },
-	{ 0x22, 0x22, YM2203_write_port_0_w },
-	{ 0x4c, 0x4c, shanghai_coin_w },
-PORT_END
+static ADDRESS_MAP_START( writeport, ADDRESS_SPACE_IO, 8 )
+	AM_RANGE(0x00, 0x01) AM_WRITE(HD63484_address_w)
+	AM_RANGE(0x02, 0x03) AM_WRITE(HD63484_data_w)
+	AM_RANGE(0x20, 0x20) AM_WRITE(YM2203_control_port_0_w)
+	AM_RANGE(0x22, 0x22) AM_WRITE(YM2203_write_port_0_w)
+	AM_RANGE(0x4c, 0x4c) AM_WRITE(shanghai_coin_w)
+ADDRESS_MAP_END
 
 
-static MEMORY_READ_START( shangha2_readmem )
-	{ 0x00000, 0x03fff, MRA_RAM },
-	{ 0x80000, 0xfffff, MRA_ROM },
-MEMORY_END
+static ADDRESS_MAP_START( shangha2_readmem, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x00000, 0x03fff) AM_READ(MRA8_RAM)
+	AM_RANGE(0x80000, 0xfffff) AM_READ(MRA8_ROM)
+ADDRESS_MAP_END
 
-static MEMORY_WRITE_START( shangha2_writemem )
-	{ 0x00000, 0x03fff, MWA_RAM },
-	{ 0x04000, 0x041ff, paletteram_xxxxBBBBGGGGRRRR_w, &paletteram },
-	{ 0x80000, 0xfffff, MWA_ROM },
-MEMORY_END
+static ADDRESS_MAP_START( shangha2_writemem, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x00000, 0x03fff) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0x04000, 0x041ff) AM_WRITE(paletteram_xxxxBBBBGGGGRRRR_w) AM_BASE(&paletteram)
+	AM_RANGE(0x80000, 0xfffff) AM_WRITE(MWA8_ROM)
+ADDRESS_MAP_END
 
-static PORT_READ_START( shangha2_readport )
-	{ 0x00, 0x00, input_port_0_r },
-	{ 0x10, 0x10, input_port_1_r },
-	{ 0x20, 0x20, input_port_2_r },
-	{ 0x30, 0x31, HD63484_status_r },
-	{ 0x32, 0x33, HD63484_data_r },
-	{ 0x40, 0x40, YM2203_status_port_0_r },
-	{ 0x42, 0x42, YM2203_read_port_0_r },
-PORT_END
+static ADDRESS_MAP_START( shangha2_readport, ADDRESS_SPACE_IO, 8 )
+	AM_RANGE(0x00, 0x00) AM_READ(input_port_0_r)
+	AM_RANGE(0x10, 0x10) AM_READ(input_port_1_r)
+	AM_RANGE(0x20, 0x20) AM_READ(input_port_2_r)
+	AM_RANGE(0x30, 0x31) AM_READ(HD63484_status_r)
+	AM_RANGE(0x32, 0x33) AM_READ(HD63484_data_r)
+	AM_RANGE(0x40, 0x40) AM_READ(YM2203_status_port_0_r)
+	AM_RANGE(0x42, 0x42) AM_READ(YM2203_read_port_0_r)
+ADDRESS_MAP_END
 
-static PORT_WRITE_START( shangha2_writeport )
-	{ 0x30, 0x31, HD63484_address_w },
-	{ 0x32, 0x33, HD63484_data_w },
-	{ 0x40, 0x40, YM2203_control_port_0_w },
-	{ 0x42, 0x42, YM2203_write_port_0_w },
-	{ 0x50, 0x50, shanghai_coin_w },
-PORT_END
+static ADDRESS_MAP_START( shangha2_writeport, ADDRESS_SPACE_IO, 8 )
+	AM_RANGE(0x30, 0x31) AM_WRITE(HD63484_address_w)
+	AM_RANGE(0x32, 0x33) AM_WRITE(HD63484_data_w)
+	AM_RANGE(0x40, 0x40) AM_WRITE(YM2203_control_port_0_w)
+	AM_RANGE(0x42, 0x42) AM_WRITE(YM2203_write_port_0_w)
+	AM_RANGE(0x50, 0x50) AM_WRITE(shanghai_coin_w)
+ADDRESS_MAP_END
 
 
 
+
+
+static READ8_HANDLER(shanghai_rand_r)
+{
+	return rand();
+}
+
+static READ8_HANDLER( kothello_HD63484_status_r )
+{
+	if (offset == 1) return 0xff;	/* high 8 bits - not used */
+	return 0x22;	/* write FIFO ready + command end    + read FIFO ready */
+}
+
+static ADDRESS_MAP_START( kothello_mem, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x00000, 0x07fff) AM_RAM
+	AM_RANGE(0x08010, 0x08011) AM_READ(kothello_HD63484_status_r) AM_WRITE(HD63484_address_w)
+	AM_RANGE(0x08012, 0x08013) AM_READ(HD63484_data_r) AM_WRITE(HD63484_data_w)
+	AM_RANGE(0x09010, 0x0901f) AM_READ(shanghai_rand_r)AM_WRITENOP /* unknown, sub cpu communication ? */
+	AM_RANGE(0x0a000, 0x0a1ff) AM_WRITE(paletteram_xxxxBBBBGGGGRRRR_w) AM_BASE(&paletteram)
+	AM_RANGE(0x0b010, 0x0b01f) AM_READ(seibu_main_v30_r) AM_WRITE(seibu_main_v30_w)
+	AM_RANGE(0x80000, 0xfffff) AM_ROM
+ADDRESS_MAP_END
+
+INPUT_PORTS_START( kothello )
+	SEIBU_COIN_INPUTS
+INPUT_PORTS_END
+
+
 INPUT_PORTS_START( shanghai )
 	PORT_START	/* IN0 */
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_8WAY )
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_8WAY )
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_8WAY )
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_8WAY )
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 )
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON3 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 	PORT_START	/* IN1 */
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_8WAY | IPF_COCKTAIL )
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_8WAY | IPF_COCKTAIL )
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_8WAY | IPF_COCKTAIL )
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_8WAY | IPF_COCKTAIL )
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 | IPF_COCKTAIL )
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 | IPF_COCKTAIL )
-	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON3 | IPF_COCKTAIL )
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_COCKTAIL
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_COCKTAIL
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_COCKTAIL
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_COCKTAIL
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_COCKTAIL
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_COCKTAIL
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_COCKTAIL
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 	PORT_START	/* IN2 */
@@ -861,7 +893,7 @@ INPUT_PORTS_START( shanghai )
 
 	PORT_START	/* DSW0 */
 	PORT_SERVICE( 0x01, IP_ACTIVE_LOW )
-	PORT_DIPNAME( 0x02, 0x02, "Allow Continue" )
+	PORT_DIPNAME( 0x02, 0x02, DEF_STR( Allow_Continue ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( No ) )
 	PORT_DIPSETTING(    0x02, DEF_STR( Yes ) )
 	PORT_DIPNAME( 0x1c, 0x1c, DEF_STR( Coin_B ) )
@@ -909,23 +941,23 @@ INPUT_PORTS_END
 
 INPUT_PORTS_START( shangha2 )
 	PORT_START	/* IN0 */
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_8WAY )
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_8WAY )
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_8WAY )
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_8WAY )
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 )
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON3 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 	PORT_START	/* IN1 */
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_8WAY | IPF_COCKTAIL )
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_8WAY | IPF_COCKTAIL )
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_8WAY | IPF_COCKTAIL )
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_8WAY | IPF_COCKTAIL )
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 | IPF_COCKTAIL )
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 | IPF_COCKTAIL )
-	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON3 | IPF_COCKTAIL )
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_COCKTAIL
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_COCKTAIL
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_COCKTAIL
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_COCKTAIL
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_COCKTAIL
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_COCKTAIL
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_COCKTAIL
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 	PORT_START	/* IN2 */
@@ -941,10 +973,10 @@ INPUT_PORTS_START( shangha2 )
 	PORT_START	/* DSW0 */
 	PORT_SERVICE( 0x01, IP_ACTIVE_LOW )
 	PORT_DIPNAME( 0x06, 0x06, DEF_STR( Difficulty ) )
-	PORT_DIPSETTING(    0x06, "Easy" )
-	PORT_DIPSETTING(    0x04, "Normal" )
-	PORT_DIPSETTING(    0x02, "Hard" )
-	PORT_DIPSETTING(    0x00, "Hardest" )
+	PORT_DIPSETTING(    0x06, DEF_STR( Easy ) )
+	PORT_DIPSETTING(    0x04, DEF_STR( Normal ) )
+	PORT_DIPSETTING(    0x02, DEF_STR( Hard ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Hardest ) )
 	PORT_DIPNAME( 0x08, 0x00, "2 Players Move Time" )
 	PORT_DIPSETTING(    0x08, "8" )
 	PORT_DIPSETTING(    0x00, "10" )
@@ -987,94 +1019,111 @@ INPUT_PORTS_END
 
 
 
-static struct YM2203interface ym2203_interface =
+static struct YM2203interface sh_ym2203_interface =
 {
-	1,			/* 1 chip */
-	16000000/4,	/* ? */
-	{ YM2203_VOL(80,15) },
-	{ input_port_3_r },
-	{ input_port_4_r },
-	{ 0 },
-	{ 0 }
+	input_port_3_r,
+	input_port_4_r
 };
 
 
 
-static const struct MachineDriver machine_driver_shanghai =
-{
+static MACHINE_DRIVER_START( shanghai )
+
 	/* basic machine hardware */
-	{
-		{
-			CPU_V30,
-			16000000/2,	/* ? */
-			readmem,writemem,readport,writeport,
-			shanghai_interrupt,1,
-			0,0
-		}
-	},
-	30, DEFAULT_60HZ_VBLANK_DURATION,	/* frames per second, vblank duration */
-	1,	/* single CPU, no need for interleaving */
-	0,
+	MDRV_CPU_ADD(V30,16000000/2)	/* ? */
+	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
+	MDRV_CPU_IO_MAP(readport,writeport)
+	MDRV_CPU_VBLANK_INT(shanghai_interrupt,1)
+
+	MDRV_FRAMES_PER_SECOND(30)
+	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
 	/* video hardware */
-	384, 280, { 0, 384-1, 0, 280-1 },
-	0,
-	256,0,
-	shanghai_vh_convert_color_prom,
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_SIZE(384, 280)
+	MDRV_VISIBLE_AREA(0, 384-1, 0, 280-1)
+	MDRV_PALETTE_LENGTH(256)
 
-	VIDEO_TYPE_RASTER,
-	0,
-	shanghai_vh_start,
-	shanghai_vh_stop,
-	shanghai_vh_screenrefresh,
+	MDRV_PALETTE_INIT(shanghai)
+	MDRV_VIDEO_START(shanghai)
+	MDRV_VIDEO_UPDATE(shanghai)
 
 	/* sound hardware */
-	0,0,0,0,
-	{
-		{
-			SOUND_YM2203,
-			&ym2203_interface
-		}
-	}
-};
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 16000000/4)
+	MDRV_SOUND_CONFIG(sh_ym2203_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.15)
+	MDRV_SOUND_ROUTE(1, "mono", 0.15)
+	MDRV_SOUND_ROUTE(2, "mono", 0.15)
+	MDRV_SOUND_ROUTE(3, "mono", 0.80)
+MACHINE_DRIVER_END
+
+
+static MACHINE_DRIVER_START( shangha2 )
 
-static const struct MachineDriver machine_driver_shangha2 =
-{
 	/* basic machine hardware */
-	{
-		{
-			CPU_V30,
-			16000000/2,	/* ? */
-			shangha2_readmem,shangha2_writemem,shangha2_readport,shangha2_writeport,
-			shanghai_interrupt,1,
-			0,0
-		}
-	},
-	30, DEFAULT_60HZ_VBLANK_DURATION,	/* frames per second, vblank duration */
-	1,	/* single CPU, no need for interleaving */
-	0,
+	MDRV_CPU_ADD(V30,16000000/2)	/* ? */
+	MDRV_CPU_PROGRAM_MAP(shangha2_readmem,shangha2_writemem)
+	MDRV_CPU_IO_MAP(shangha2_readport,shangha2_writeport)
+	MDRV_CPU_VBLANK_INT(shanghai_interrupt,1)
+
+	MDRV_FRAMES_PER_SECOND(30)
+	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
 	/* video hardware */
-	384, 280, { 0, 384-1, 0, 280-1 },
-	0,
-	256,0,
-	0,
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_SIZE(384, 280)
+	MDRV_VISIBLE_AREA(0, 384-1, 0, 280-1)
+	MDRV_PALETTE_LENGTH(256)
 
-	VIDEO_TYPE_RASTER,
-	0,
-	shanghai_vh_start,
-	shanghai_vh_stop,
-	shanghai_vh_screenrefresh,
+	MDRV_VIDEO_START(shanghai)
+	MDRV_VIDEO_UPDATE(shanghai)
 
 	/* sound hardware */
-	0,0,0,0,
-	{
-		{
-			SOUND_YM2203,
-			&ym2203_interface
-		}
-	}
-};
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM2203, 16000000/4)
+	MDRV_SOUND_CONFIG(sh_ym2203_interface)
+	MDRV_SOUND_ROUTE(0, "mono", 0.15)
+	MDRV_SOUND_ROUTE(1, "mono", 0.15)
+	MDRV_SOUND_ROUTE(2, "mono", 0.15)
+	MDRV_SOUND_ROUTE(3, "mono", 0.80)
+MACHINE_DRIVER_END
+
+SEIBU_SOUND_SYSTEM_YM2203_HARDWARE
+
+SEIBU_SOUND_SYSTEM_ADPCM_HARDWARE
+
+
+static MACHINE_DRIVER_START( kothello )
+
+	/* basic machine hardware */
+	MDRV_CPU_ADD(V30,16000000/2)	/* ? */
+	MDRV_CPU_PROGRAM_MAP(kothello_mem, 0)
+	MDRV_CPU_VBLANK_INT(shanghai_interrupt,1)
+
+	SEIBU3A_SOUND_SYSTEM_CPU(14318180/4)
+
+	MDRV_FRAMES_PER_SECOND(30)
+	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
+	MDRV_INTERLEAVE(200)
+
+	MDRV_MACHINE_INIT(seibu_sound_1)
+
+	/* video hardware */
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_SIZE(384, 384)
+	MDRV_VISIBLE_AREA(0, 384-1, 0, 280-1)
+	MDRV_PALETTE_LENGTH(256)
+
+	MDRV_VIDEO_START(shanghai)
+	MDRV_VIDEO_UPDATE(shanghai)
+
+	/* sound hardware */
+	SEIBU_SOUND_SYSTEM_YM2203_INTERFACE(14318180/4)
+	SEIBU_SOUND_SYSTEM_ADPCM_INTERFACE
+MACHINE_DRIVER_END
 
 
 
@@ -1086,23 +1135,92 @@ static const struct MachineDriver machine_driver_shangha2 =
 
 ROM_START( shanghai )
 	ROM_REGION( 0x100000, REGION_CPU1, 0 )
-	ROM_LOAD16_BYTE( "shg-22a.rom", 0xa0001, 0x10000, 0xe0a085be )
-	ROM_LOAD16_BYTE( "shg-21a.rom", 0xa0000, 0x10000, 0x4ab06d32 )
-	ROM_LOAD16_BYTE( "shg-28a.rom", 0xc0001, 0x10000, 0x983ec112 )
-	ROM_LOAD16_BYTE( "shg-27a.rom", 0xc0000, 0x10000, 0x41af0945 )
-	ROM_LOAD16_BYTE( "shg-37b.rom", 0xe0001, 0x10000, 0x3f192da0 )
-	ROM_LOAD16_BYTE( "shg-36b.rom", 0xe0000, 0x10000, 0xa1d6af96 )
+	ROM_LOAD16_BYTE( "shg-22a.rom", 0xa0001, 0x10000, CRC(e0a085be) SHA1(e281043f97c4cd34a33eb1ec7154abbe67a9aa03) )
+	ROM_LOAD16_BYTE( "shg-21a.rom", 0xa0000, 0x10000, CRC(4ab06d32) SHA1(02667d1270b101386b947d5b9bfe64052e498041) )
+	ROM_LOAD16_BYTE( "shg-28a.rom", 0xc0001, 0x10000, CRC(983ec112) SHA1(110e120e35815d055d6108a7603e83d2d990c666) )
+	ROM_LOAD16_BYTE( "shg-27a.rom", 0xc0000, 0x10000, CRC(41af0945) SHA1(dfc4638a17f716ccc8e59f275571d6dc1093a745) )
+	ROM_LOAD16_BYTE( "shg-37b.rom", 0xe0001, 0x10000, CRC(3f192da0) SHA1(e70d5da5d702e9bf9ac6b77df62bcf51894aadcf) )
+	ROM_LOAD16_BYTE( "shg-36b.rom", 0xe0000, 0x10000, CRC(a1d6af96) SHA1(01c4c22bf03b3d260fffcbc6dfc5f2dd2bcba14a) )
 ROM_END
 
 ROM_START( shangha2 )
 	ROM_REGION( 0x100000, REGION_CPU1, 0 )
-	ROM_LOAD16_BYTE( "sht-27j", 0x80001, 0x20000, 0x969cbf00 )
-	ROM_LOAD16_BYTE( "sht-26j", 0x80000, 0x20000, 0x4bf01ab4 )
-	ROM_LOAD16_BYTE( "sht-31j", 0xc0001, 0x20000, 0x312e3b9d )
-	ROM_LOAD16_BYTE( "sht-30j", 0xc0000, 0x20000, 0x2861a894 )
+	ROM_LOAD16_BYTE( "sht-27j", 0x80001, 0x20000, CRC(969cbf00) SHA1(350025f4e39c7d89cb72e46b52fb467e3e9056f4) )
+	ROM_LOAD16_BYTE( "sht-26j", 0x80000, 0x20000, CRC(4bf01ab4) SHA1(6928374db080212a371991ee98cd563e158907f0) )
+	ROM_LOAD16_BYTE( "sht-31j", 0xc0001, 0x20000, CRC(312e3b9d) SHA1(f15f76a087d4972aa72145eced8d1fb15329b359) )
+	ROM_LOAD16_BYTE( "sht-30j", 0xc0000, 0x20000, CRC(2861a894) SHA1(6da99d15f41e900735f8943f2710487817f98579) )
+ROM_END
+
+/*
+
+Kyuukyoku no Othello
+Success Corp. 1990
+
+PCB Layout
+
+SSS8906
+|------------------------------------------|
+| YM3014 DSW2  DSW1           4464    4464 |
+|                             4464    4464 |
+|              YM2203         4464    4464 |
+|J      M5205  Z80            4464    4464 |
+|A             6116           4464    4464 |
+|M             PAL            4464    4464 |
+|M                            4464    4464 |
+|A  ROM6                      4464    4464 |
+|              ROM5           HD63484      |
+| YM3931                             898-3 |
+|                  SIS6091                 |
+|                                          |
+|                                          |
+| PAL                                      |
+| PAL              ROM3  ROM4              |
+|                                    PAL   |
+|                  ROM2  ROM1              |
+| CXQ70116                                 |
+| D71011           6264  6264              |
+|16MHz     PAL     6264  6264              |
+|------------------------------------------|
+Notes:
+      Z80 clock     : 4.000MHz
+      CXQ70116 clock: 16.000MHz
+      YM3931 clock  : 4.000MHz
+      YM2203 clock  : 4.000MHz
+      M5205 clock   : 444598Hz; sample rate = M5205 clock / 48
+      HD63484 clock : pin50- 4.000MHz, pin52- 2.000MHz
+      VSync         : 57Hz
+
+      HD63484  : Crt Controller
+      CXQ70116 : Compatible with NEC V30 (DIP40)
+      D71011   : ? (DIP18) 710xx is series of common NEC ICs; timers, counters, parallel interface, interrupt controllers etc
+      898-3    : BI 898-3-R 22  8920  (?, DIP16, tied to HD63484)
+      YM3931   : Also printed 'SEI0100BU' (SDIP64)
+      SIS6091  : Custom QFP80 (Graphics controller?)
+      4464     : 64K x4 DRAM
+      6264       8K x8 SRAM
+      6116     : 2K x8 SRAM
+
+*/
+
+
+ROM_START( kothello )
+	ROM_REGION( 0x100000, REGION_CPU1, 0 )
+	ROM_LOAD16_BYTE( "rom1.3e", 0x80001, 0x20000, CRC(8601dcfa) SHA1(e7ffc6da0bfb5cec5a543a2a5223b235c3428eb3) )
+	ROM_LOAD16_BYTE( "rom2.5e", 0x80000, 0x20000, CRC(68f6b7a3) SHA1(9f7e217e07bc79b1e95551cd0fe107294bf5889f) )
+	ROM_LOAD16_BYTE( "rom3.3f", 0xc0001, 0x20000, CRC(2f3dacd1) SHA1(35bfdc1f377b87a80c3abbb48f9f0b52108fbfc0) )
+	ROM_LOAD16_BYTE( "rom4.5f", 0xc0000, 0x20000, CRC(ee8bbea7) SHA1(35dfa7aa89cecba6482b18a5233511bacc4bf331) )
+
+	ROM_REGION( 0x20000, REGION_CPU2, 0 )
+	ROM_LOAD( "rom5.5l",   0x00000, 0x02000, CRC(7eb6e697) SHA1(4476e13f9a9e04472581f2c069760f53b33d5672))
+	ROM_CONTINUE(          0x10000, 0x0e000 )
+
+	ROM_REGION( 0x10000, REGION_SOUND1, 0 )
+	ROM_LOAD( "rom6.7m",   0x00000, 0x10000, CRC(4ab1335d) SHA1(3a803e8a7e9b0c2a26ee23e7ac9c89c70cf2504b))
 ROM_END
 
 
 
-GAME( 1988, shanghai, 0, shanghai, shanghai, 0, ROT0, "Sunsoft", "Shanghai (Japan)" )
-GAME( 1989, shangha2, 0, shangha2, shangha2, 0, ROT0, "Sunsoft", "Shanghai II (Japan)" )
+GAME( 1988, shanghai, 0, shanghai, shanghai, 0, ROT0, "Sunsoft", "Shanghai (Japan)", GAME_IMPERFECT_GRAPHICS )
+GAME( 1989, shangha2, 0, shangha2, shangha2, 0, ROT0, "Sunsoft", "Shanghai II (Japan)", 0 )
+GAME( 1990, kothello, 0, kothello, kothello, 0, ROT0, "Success", "Kyuukyoku no Othello", GAME_NOT_WORKING )
+
