@@ -4,28 +4,28 @@
 
 *********************************************************************
 
-	Each game uses the MXC-06 chip to produce sprites.
+    Each game uses the MXC-06 chip to produce sprites.
 
-	Sprite data:  The unknown bits seem to be unused.
+    Sprite data:  The unknown bits seem to be unused.
 
-	Byte 0:
-		Bit 0 : Y co-ord hi bit
-		Bit 1,2: ?
-		Bit 3,4 : Sprite height (1x, 2x, 4x, 8x)
-		Bit 5  - X flip
-		Bit 6  - Y flip
-		Bit 7  - Only display Sprite if set
-	Byte 1: Y-coords
-	Byte 2:
-		Bit 0,1,2,3: Hi bits of sprite number
-		Bit 4,5,6,7: (Probably unused MSB's of sprite)
-	Byte 3: Low bits of sprite number
-	Byte 4:
-		Bit 0 : X co-ords hi bit
-		Bit 1,2: ??
-		Bit 3: Sprite flash (sprite is displayed every other frame)
-		Bit 4,5,6,7:  - Colour
-	Byte 5: X-coords
+    Byte 0:
+        Bit 0 : Y co-ord hi bit
+        Bit 1,2: ?
+        Bit 3,4 : Sprite height (1x, 2x, 4x, 8x)
+        Bit 5  - X flip
+        Bit 6  - Y flip
+        Bit 7  - Only display Sprite if set
+    Byte 1: Y-coords
+    Byte 2:
+        Bit 0,1,2,3: Hi bits of sprite number
+        Bit 4,5,6,7: (Probably unused MSB's of sprite)
+    Byte 3: Low bits of sprite number
+    Byte 4:
+        Bit 0 : X co-ords hi bit
+        Bit 1,2: ??
+        Bit 3: Sprite flash (sprite is displayed every other frame)
+        Bit 4,5,6,7:  - Colour
+    Byte 5: X-coords
 
 **********************************************************************
 
@@ -34,14 +34,14 @@
     0x000 - character palettes (Sprites on Midnight R)
     0x200 - sprite palettes (Characters on Midnight R)
     0x400 - tiles 1
-  	0x600 - tiles 2
+    0x600 - tiles 2
 
-	Bad Dudes, Robocop, Heavy Barrel, Hippodrome - 24 bit rgb
-	Sly Spy, Midnight Resistance - 12 bit rgb
+    Bad Dudes, Robocop, Heavy Barrel, Hippodrome - 24 bit rgb
+    Sly Spy, Midnight Resistance - 12 bit rgb
 
   Tile data
 
-  	4 bit palette select, 12 bit tile select
+    4 bit palette select, 12 bit tile select
 
 **********************************************************************
 
@@ -51,12 +51,12 @@ configuration is 2 chips of 16*16 tiles, 1 of 8*8.
  Playfield control registers:
    bank 0:
    0:
-		bit 0 (0x1) set = 8*8 tiles, else 16*16 tiles
-		Bit 1 (0x2) unknown
-		bit 2 (0x4) set enables rowscroll
-		bit 3 (0x8) set enables colscroll
-		bit 7 (0x80) set in playfield 1 is reverse screen (set via dip-switch)
-		bit 7 (0x80) in other playfields unknown
+        bit 0 (0x1) set = 8*8 tiles, else 16*16 tiles
+        Bit 1 (0x2) unknown
+        bit 2 (0x4) set enables rowscroll
+        bit 3 (0x8) set enables colscroll
+        bit 7 (0x80) set in playfield 1 is reverse screen (set via dip-switch)
+        bit 7 (0x80) in other playfields unknown
    2: unknown (00 in bg, 03 in fg+text - maybe controls pf transparency?)
    4: unknown (always 00)
    6: playfield shape: 00 = 4x1, 01 = 2x2, 02 = 1x4 (low 4 bits only)
@@ -68,54 +68,54 @@ configuration is 2 chips of 16*16 tiles, 1 of 8*8.
    6: Style of rowscroll (low 4 bits, top 4 bits do nothing)
 
 Rowscroll/Colscroll styles:
-	0: 256 scroll registers (Robocop)
-	1: 128 scroll registers
-	2:  64 scroll registers
-	3:  32 scroll registers (Heavy Barrel, Midres)
-	4:  16 scroll registers (Bad Dudes, Sly Spy)
-	5:   8 scroll registers (Hippodrome)
-	6:   4 scroll registers (Heavy Barrel)
-	7:   2 scroll registers (Heavy Barrel, used on other games but registers kept at 0)
-	8:   1 scroll register (ie, none)
+    0: 256 scroll registers (Robocop)
+    1: 128 scroll registers
+    2:  64 scroll registers
+    3:  32 scroll registers (Heavy Barrel, Midres)
+    4:  16 scroll registers (Bad Dudes, Sly Spy)
+    5:   8 scroll registers (Hippodrome)
+    6:   4 scroll registers (Heavy Barrel)
+    7:   2 scroll registers (Heavy Barrel, used on other games but registers kept at 0)
+    8:   1 scroll register (ie, none)
 
-	Values above are *multiplied* by playfield shape.
+    Values above are *multiplied* by playfield shape.
 
 Playfield priority (Bad Dudes, etc):
-	In the bottommost playfield, pens 8-15 can have priority over the next playfield.
-	In that next playfield, pens 8-15 can have priority over sprites.
+    In the bottommost playfield, pens 8-15 can have priority over the next playfield.
+    In that next playfield, pens 8-15 can have priority over sprites.
 
 Bit 0:  Playfield inversion
 Bit 1:  Enable playfield mixing (for palettes 8-15 only)
 Bit 2:  Enable playfield/sprite mixing (for palettes 8-15 only)
 
 Priority word (Midres):
-	Bit 0 set = Playfield 3 drawn over Playfield 2
-			~ = Playfield 2 drawn over Playfield 3
-	Bit 1 set = Sprites are drawn inbetween playfields
-			~ = Sprites are on top of playfields
-	Bit 2
-	Bit 3 set = ...
+    Bit 0 set = Playfield 3 drawn over Playfield 2
+            ~ = Playfield 2 drawn over Playfield 3
+    Bit 1 set = Sprites are drawn inbetween playfields
+            ~ = Sprites are on top of playfields
+    Bit 2
+    Bit 3 set = ...
 
 ***************************************************************************/
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
 
-static struct tilemap *pf1_tilemap_0,*pf1_tilemap_1,*pf1_tilemap_2;
-static struct tilemap *pf2_tilemap_0,*pf2_tilemap_1,*pf2_tilemap_2;
-static struct tilemap *pf3_tilemap_0,*pf3_tilemap_1,*pf3_tilemap_2;
+static tilemap *pf1_tilemap_0,*pf1_tilemap_1,*pf1_tilemap_2;
+static tilemap *pf2_tilemap_0,*pf2_tilemap_1,*pf2_tilemap_2;
+static tilemap *pf3_tilemap_0,*pf3_tilemap_1,*pf3_tilemap_2;
 
-data16_t *dec0_pf1_data,*dec0_pf2_data,*dec0_pf3_data;
-data16_t *dec0_pf1_rowscroll,*dec0_pf2_rowscroll,*dec0_pf3_rowscroll;
-data16_t *dec0_pf1_colscroll,*dec0_pf2_colscroll,*dec0_pf3_colscroll;
-static data16_t dec0_pf1_control_0[4];
-static data16_t dec0_pf1_control_1[4];
-static data16_t dec0_pf2_control_0[4];
-static data16_t dec0_pf2_control_1[4];
-static data16_t dec0_pf3_control_0[4];
-static data16_t dec0_pf3_control_1[4];
-static data16_t *dec0_spriteram;
-static data16_t dec0_pri;
+UINT16 *dec0_pf1_data,*dec0_pf2_data,*dec0_pf3_data;
+UINT16 *dec0_pf1_rowscroll,*dec0_pf2_rowscroll,*dec0_pf3_rowscroll;
+UINT16 *dec0_pf1_colscroll,*dec0_pf2_colscroll,*dec0_pf3_colscroll;
+static UINT16 dec0_pf1_control_0[4];
+static UINT16 dec0_pf1_control_1[4];
+static UINT16 dec0_pf2_control_0[4];
+static UINT16 dec0_pf2_control_1[4];
+static UINT16 dec0_pf3_control_0[4];
+static UINT16 dec0_pf3_control_1[4];
+static UINT16 *dec0_spriteram;
+static UINT16 dec0_pri;
 
 /******************************************************************************/
 
@@ -151,7 +151,7 @@ WRITE16_HANDLER( dec0_paletteram_b_w )
 
 /******************************************************************************/
 
-static void dec0_drawsprites(struct mame_bitmap *bitmap,int pri_mask,int pri_val)
+static void dec0_drawsprites(mame_bitmap *bitmap,const rectangle *cliprect,int pri_mask,int pri_val)
 {
 	int offs;
 
@@ -210,7 +210,7 @@ static void dec0_drawsprites(struct mame_bitmap *bitmap,int pri_mask,int pri_val
 					colour,
 					fx,fy,
 					x,y + mult * multi,
-					&Machine->visible_area,TRANSPARENCY_PEN,0);
+					cliprect,TRANSPARENCY_PEN,0);
 
 			multi--;
 		}
@@ -222,7 +222,7 @@ static void dec0_drawsprites(struct mame_bitmap *bitmap,int pri_mask,int pri_val
 static void dec0_pf1_update(void)
 {
 	int offs,lines,height,scrolly,scrollx;
-	struct tilemap *tilemap_ptr;
+	tilemap *tilemap_ptr;
 
 	/* Flipscreen */
 	flip_screen_set(dec0_pf1_control_0[0]&0x80);
@@ -281,7 +281,7 @@ static void dec0_pf1_update(void)
 static void dec0_pf2_update(void)
 {
 	int offs,lines,height,scrolly,scrollx;
-	struct tilemap *tilemap_ptr;
+	tilemap *tilemap_ptr;
 
 	/* Master scroll registers */
 	scrollx = dec0_pf2_control_1[0];
@@ -350,7 +350,7 @@ static void dec0_pf2_update(void)
 static void dec0_pf3_update(void)
 {
 	int offs,lines,height,scrolly,scrollx;
-	struct tilemap *tilemap_ptr;
+	tilemap *tilemap_ptr;
 
 	/* Master scroll registers */
 	scrollx = dec0_pf3_control_1[0];
@@ -419,7 +419,7 @@ static void dec0_pf3_update(void)
 
 /******************************************************************************/
 
-static void dec0_pf1_draw(struct mame_bitmap *bitmap,int flags,int pri)
+static void dec0_pf1_draw(mame_bitmap *bitmap,const rectangle *cliprect,int flags,int pri)
 {
 	tilemap_set_enable(pf1_tilemap_0,0);
 	tilemap_set_enable(pf1_tilemap_1,0);
@@ -428,21 +428,21 @@ static void dec0_pf1_draw(struct mame_bitmap *bitmap,int flags,int pri)
 	switch (dec0_pf1_control_0[3]&0x3) {
 		case 0:	/* 4x1 */
 			tilemap_set_enable(pf1_tilemap_0,1);
-			tilemap_draw(bitmap,pf1_tilemap_0,flags,pri);
+			tilemap_draw(bitmap,cliprect,pf1_tilemap_0,flags,pri);
 			break;
 		case 1:	/* 2x2 */
 		default:
 			tilemap_set_enable(pf1_tilemap_1,1);
-			tilemap_draw(bitmap,pf1_tilemap_1,flags,pri);
+			tilemap_draw(bitmap,cliprect,pf1_tilemap_1,flags,pri);
 			break;
 		case 2:	/* 1x4 */
 			tilemap_set_enable(pf1_tilemap_2,1);
-			tilemap_draw(bitmap,pf1_tilemap_2,flags,pri);
+			tilemap_draw(bitmap,cliprect,pf1_tilemap_2,flags,pri);
 			break;
 	}
 }
 
-static void dec0_pf2_draw(struct mame_bitmap *bitmap,int flags,int pri)
+static void dec0_pf2_draw(mame_bitmap *bitmap,const rectangle *cliprect,int flags,int pri)
 {
 	tilemap_set_enable(pf2_tilemap_0,0);
 	tilemap_set_enable(pf2_tilemap_1,0);
@@ -451,21 +451,21 @@ static void dec0_pf2_draw(struct mame_bitmap *bitmap,int flags,int pri)
 	switch (dec0_pf2_control_0[3]&0x3) {
 		case 0:	/* 4x1 */
 			tilemap_set_enable(pf2_tilemap_0,1);
-			tilemap_draw(bitmap,pf2_tilemap_0,flags,pri);
+			tilemap_draw(bitmap,cliprect,pf2_tilemap_0,flags,pri);
 			break;
 		case 1:	/* 2x2 */
 		default:
 			tilemap_set_enable(pf2_tilemap_1,1);
-			tilemap_draw(bitmap,pf2_tilemap_1,flags,pri);
+			tilemap_draw(bitmap,cliprect,pf2_tilemap_1,flags,pri);
 			break;
 		case 2:	/* 1x4 */
 			tilemap_set_enable(pf2_tilemap_2,1);
-			tilemap_draw(bitmap,pf2_tilemap_2,flags,pri);
+			tilemap_draw(bitmap,cliprect,pf2_tilemap_2,flags,pri);
 			break;
 	}
 }
 
-static void dec0_pf3_draw(struct mame_bitmap *bitmap,int flags,int pri)
+static void dec0_pf3_draw(mame_bitmap *bitmap,const rectangle *cliprect,int flags,int pri)
 {
 	tilemap_set_enable(pf3_tilemap_0,0);
 	tilemap_set_enable(pf3_tilemap_1,0);
@@ -474,43 +474,43 @@ static void dec0_pf3_draw(struct mame_bitmap *bitmap,int flags,int pri)
 	switch (dec0_pf3_control_0[3]&0x3) {
 		case 0:	/* 4x1 */
 			tilemap_set_enable(pf3_tilemap_0,1);
-			tilemap_draw(bitmap,pf3_tilemap_0,flags,pri);
+			tilemap_draw(bitmap,cliprect,pf3_tilemap_0,flags,pri);
 			break;
 		case 1:	/* 2x2 */
 		default:
 			tilemap_set_enable(pf3_tilemap_1,1);
-			tilemap_draw(bitmap,pf3_tilemap_1,flags,pri);
+			tilemap_draw(bitmap,cliprect,pf3_tilemap_1,flags,pri);
 			break;
 		case 2:	/* 1x4 */
 			tilemap_set_enable(pf3_tilemap_2,1);
-			tilemap_draw(bitmap,pf3_tilemap_2,flags,pri);
+			tilemap_draw(bitmap,cliprect,pf3_tilemap_2,flags,pri);
 			break;
 	}
 }
 
 /******************************************************************************/
 
-void hbarrel_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( hbarrel )
 {
 	dec0_pf1_update();
 	dec0_pf2_update();
 	dec0_pf3_update();
 
-	dec0_pf3_draw(bitmap,TILEMAP_BACK|TILEMAP_IGNORE_TRANSPARENCY,0);
-	dec0_pf3_draw(bitmap,TILEMAP_FRONT|TILEMAP_IGNORE_TRANSPARENCY,1);
-	dec0_drawsprites(bitmap,0x08,0x08);
-	dec0_pf2_draw(bitmap,TILEMAP_BACK,0);
-	dec0_pf2_draw(bitmap,TILEMAP_FRONT,1);
+	dec0_pf3_draw(bitmap,cliprect,TILEMAP_BACK|TILEMAP_IGNORE_TRANSPARENCY,0);
+	dec0_pf3_draw(bitmap,cliprect,TILEMAP_FRONT|TILEMAP_IGNORE_TRANSPARENCY,1);
+	dec0_drawsprites(bitmap,cliprect,0x08,0x08);
+	dec0_pf2_draw(bitmap,cliprect,TILEMAP_BACK,0);
+	dec0_pf2_draw(bitmap,cliprect,TILEMAP_FRONT,1);
 
 	/* HB always keeps pf2 on top of pf3, no need explicitly support priority register */
 
-	dec0_drawsprites(bitmap,0x08,0x00);
-	dec0_pf1_draw(bitmap,0,0);
+	dec0_drawsprites(bitmap,cliprect,0x08,0x00);
+	dec0_pf1_draw(bitmap,cliprect,0,0);
 }
 
 /******************************************************************************/
 
-void baddudes_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( baddudes )
 {
 	/* WARNING: priority inverted wrt all the other games */
 	dec0_pf1_update();
@@ -520,47 +520,47 @@ void baddudes_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 	/* WARNING: inverted wrt Midnight Resistance */
 	if ((dec0_pri & 0x01) == 0)
 	{
-		dec0_pf2_draw(bitmap,TILEMAP_BACK|TILEMAP_IGNORE_TRANSPARENCY,0);
+		dec0_pf2_draw(bitmap,cliprect,TILEMAP_BACK|TILEMAP_IGNORE_TRANSPARENCY,0);
 		if (!(dec0_pri & 2))
-			dec0_pf2_draw(bitmap,TILEMAP_FRONT|TILEMAP_IGNORE_TRANSPARENCY,1);
+			dec0_pf2_draw(bitmap,cliprect,TILEMAP_FRONT|TILEMAP_IGNORE_TRANSPARENCY,1);
 
-		dec0_pf3_draw(bitmap,TILEMAP_BACK,0);
+		dec0_pf3_draw(bitmap,cliprect,TILEMAP_BACK,0);
 		if (!(dec0_pri & 4))
-			dec0_pf3_draw(bitmap,TILEMAP_FRONT,1);
+			dec0_pf3_draw(bitmap,cliprect,TILEMAP_FRONT,1);
 
 		if (dec0_pri & 2)
-			dec0_pf2_draw(bitmap,TILEMAP_FRONT,1);
+			dec0_pf2_draw(bitmap,cliprect,TILEMAP_FRONT,1);
 
-		dec0_drawsprites(bitmap,0x00,0x00);
+		dec0_drawsprites(bitmap,cliprect,0x00,0x00);
 
 		if (dec0_pri & 4)
-			dec0_pf3_draw(bitmap,TILEMAP_FRONT,1); /* Foreground pens only */
+			dec0_pf3_draw(bitmap,cliprect,TILEMAP_FRONT,1); /* Foreground pens only */
 	}
 	else
 	{
-		dec0_pf3_draw(bitmap,TILEMAP_BACK|TILEMAP_IGNORE_TRANSPARENCY,0);
+		dec0_pf3_draw(bitmap,cliprect,TILEMAP_BACK|TILEMAP_IGNORE_TRANSPARENCY,0);
 		if (!(dec0_pri & 2))
-			dec0_pf3_draw(bitmap,TILEMAP_FRONT|TILEMAP_IGNORE_TRANSPARENCY,1);
+			dec0_pf3_draw(bitmap,cliprect,TILEMAP_FRONT|TILEMAP_IGNORE_TRANSPARENCY,1);
 
-		dec0_pf2_draw(bitmap,TILEMAP_BACK,0);
+		dec0_pf2_draw(bitmap,cliprect,TILEMAP_BACK,0);
 		if (!(dec0_pri & 4))
-			dec0_pf2_draw(bitmap,TILEMAP_FRONT,1);
+			dec0_pf2_draw(bitmap,cliprect,TILEMAP_FRONT,1);
 
 		if (dec0_pri & 2)
-			dec0_pf3_draw(bitmap,TILEMAP_FRONT,1);
+			dec0_pf3_draw(bitmap,cliprect,TILEMAP_FRONT,1);
 
-		dec0_drawsprites(bitmap,0x00,0x00);
+		dec0_drawsprites(bitmap,cliprect,0x00,0x00);
 
 		if (dec0_pri & 4)
-			dec0_pf2_draw(bitmap,TILEMAP_FRONT,1);
+			dec0_pf2_draw(bitmap,cliprect,TILEMAP_FRONT,1);
 	}
 
-	dec0_pf1_draw(bitmap,0,0);
+	dec0_pf1_draw(bitmap,cliprect,0,0);
 }
 
 /******************************************************************************/
 
-void robocop_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( robocop )
 {
 	int trans;
 
@@ -579,51 +579,51 @@ void robocop_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 		/* Robocop uses it only for the title screen, so this might be just */
 		/* completely wrong. The top 8 bits of the register might mean */
 		/* something (they are 0x80 in midres, 0x00 here) */
-		dec0_pf2_draw(bitmap,TILEMAP_BACK|TILEMAP_IGNORE_TRANSPARENCY,0);
-		dec0_pf2_draw(bitmap,TILEMAP_FRONT|TILEMAP_IGNORE_TRANSPARENCY,1);
+		dec0_pf2_draw(bitmap,cliprect,TILEMAP_BACK|TILEMAP_IGNORE_TRANSPARENCY,0);
+		dec0_pf2_draw(bitmap,cliprect,TILEMAP_FRONT|TILEMAP_IGNORE_TRANSPARENCY,1);
 
 		if (dec0_pri & 0x02)
-			dec0_drawsprites(bitmap,0x08,trans);
+			dec0_drawsprites(bitmap,cliprect,0x08,trans);
 
-		dec0_pf3_draw(bitmap,TILEMAP_BACK,0);
-		dec0_pf3_draw(bitmap,TILEMAP_FRONT,1);
+		dec0_pf3_draw(bitmap,cliprect,TILEMAP_BACK,0);
+		dec0_pf3_draw(bitmap,cliprect,TILEMAP_FRONT,1);
 	}
 	else
 	{
-		dec0_pf3_draw(bitmap,TILEMAP_BACK|TILEMAP_IGNORE_TRANSPARENCY,0);
-		dec0_pf3_draw(bitmap,TILEMAP_FRONT|TILEMAP_IGNORE_TRANSPARENCY,1);
+		dec0_pf3_draw(bitmap,cliprect,TILEMAP_BACK|TILEMAP_IGNORE_TRANSPARENCY,0);
+		dec0_pf3_draw(bitmap,cliprect,TILEMAP_FRONT|TILEMAP_IGNORE_TRANSPARENCY,1);
 
 		if (dec0_pri & 0x02)
-			dec0_drawsprites(bitmap,0x08,trans);
+			dec0_drawsprites(bitmap,cliprect,0x08,trans);
 
-		dec0_pf2_draw(bitmap,TILEMAP_BACK,0);
-		dec0_pf2_draw(bitmap,TILEMAP_FRONT,1);
+		dec0_pf2_draw(bitmap,cliprect,TILEMAP_BACK,0);
+		dec0_pf2_draw(bitmap,cliprect,TILEMAP_FRONT,1);
 	}
 
 	if (dec0_pri & 0x02)
-		dec0_drawsprites(bitmap,0x08,trans ^ 0x08);
+		dec0_drawsprites(bitmap,cliprect,0x08,trans ^ 0x08);
 	else
-		dec0_drawsprites(bitmap,0x00,0x00);
+		dec0_drawsprites(bitmap,cliprect,0x00,0x00);
 
-	dec0_pf1_draw(bitmap,0,0);
+	dec0_pf1_draw(bitmap,cliprect,0,0);
 }
 
 /******************************************************************************/
 
-void birdtry_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( birdtry )
 {
 	/* This game doesn't have the extra playfield chip on the game board */
 	dec0_pf1_update();
 	dec0_pf2_update();
-	dec0_pf2_draw(bitmap,TILEMAP_BACK|TILEMAP_IGNORE_TRANSPARENCY,0);
-	dec0_pf2_draw(bitmap,TILEMAP_FRONT|TILEMAP_IGNORE_TRANSPARENCY,1);
-	dec0_drawsprites(bitmap,0x00,0x00);
-	dec0_pf1_draw(bitmap,0,0);
+	dec0_pf2_draw(bitmap,cliprect,TILEMAP_BACK|TILEMAP_IGNORE_TRANSPARENCY,0);
+	dec0_pf2_draw(bitmap,cliprect,TILEMAP_FRONT|TILEMAP_IGNORE_TRANSPARENCY,1);
+	dec0_drawsprites(bitmap,cliprect,0x00,0x00);
+	dec0_pf1_draw(bitmap,cliprect,0,0);
 }
 
 /******************************************************************************/
 
-void hippodrm_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( hippodrm )
 {
 	dec0_pf1_update();
 	dec0_pf2_update();
@@ -631,48 +631,48 @@ void hippodrm_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 
 	if (dec0_pri & 0x01)
 	{
-		dec0_pf2_draw(bitmap,TILEMAP_BACK|TILEMAP_IGNORE_TRANSPARENCY,0);
-		dec0_pf2_draw(bitmap,TILEMAP_FRONT|TILEMAP_IGNORE_TRANSPARENCY,1);
-		dec0_pf3_draw(bitmap,TILEMAP_BACK,0);
-		dec0_pf3_draw(bitmap,TILEMAP_FRONT,1);
+		dec0_pf2_draw(bitmap,cliprect,TILEMAP_BACK|TILEMAP_IGNORE_TRANSPARENCY,0);
+		dec0_pf2_draw(bitmap,cliprect,TILEMAP_FRONT|TILEMAP_IGNORE_TRANSPARENCY,1);
+		dec0_pf3_draw(bitmap,cliprect,TILEMAP_BACK,0);
+		dec0_pf3_draw(bitmap,cliprect,TILEMAP_FRONT,1);
 	}
 	else
 	{
-		dec0_pf3_draw(bitmap,TILEMAP_BACK|TILEMAP_IGNORE_TRANSPARENCY,0);
-		dec0_pf3_draw(bitmap,TILEMAP_FRONT|TILEMAP_IGNORE_TRANSPARENCY,1);
-		dec0_pf2_draw(bitmap,TILEMAP_BACK,0);
-		dec0_pf2_draw(bitmap,TILEMAP_FRONT,1);
+		dec0_pf3_draw(bitmap,cliprect,TILEMAP_BACK|TILEMAP_IGNORE_TRANSPARENCY,0);
+		dec0_pf3_draw(bitmap,cliprect,TILEMAP_FRONT|TILEMAP_IGNORE_TRANSPARENCY,1);
+		dec0_pf2_draw(bitmap,cliprect,TILEMAP_BACK,0);
+		dec0_pf2_draw(bitmap,cliprect,TILEMAP_FRONT,1);
 	}
 
-	dec0_drawsprites(bitmap,0x00,0x00);
-	dec0_pf1_draw(bitmap,0,0);
+	dec0_drawsprites(bitmap,cliprect,0x00,0x00);
+	dec0_pf1_draw(bitmap,cliprect,0,0);
 }
 
 /******************************************************************************/
 
-void slyspy_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( slyspy )
 {
 	dec0_pf1_update();
 	dec0_pf2_update();
 	dec0_pf3_update();
 
-	dec0_pf3_draw(bitmap,TILEMAP_BACK|TILEMAP_IGNORE_TRANSPARENCY,0);
-	dec0_pf3_draw(bitmap,TILEMAP_FRONT|TILEMAP_IGNORE_TRANSPARENCY,1);
-	dec0_pf2_draw(bitmap,TILEMAP_BACK,0);
+	dec0_pf3_draw(bitmap,cliprect,TILEMAP_BACK|TILEMAP_IGNORE_TRANSPARENCY,0);
+	dec0_pf3_draw(bitmap,cliprect,TILEMAP_FRONT|TILEMAP_IGNORE_TRANSPARENCY,1);
+	dec0_pf2_draw(bitmap,cliprect,TILEMAP_BACK,0);
 	if (!(dec0_pri&0x80))
-		dec0_pf2_draw(bitmap,TILEMAP_FRONT,1);
+		dec0_pf2_draw(bitmap,cliprect,TILEMAP_FRONT,1);
 
-	dec0_drawsprites(bitmap,0x00,0x00);
+	dec0_drawsprites(bitmap,cliprect,0x00,0x00);
 
 	if (dec0_pri&0x80)
-		dec0_pf2_draw(bitmap,TILEMAP_FRONT,1);
+		dec0_pf2_draw(bitmap,cliprect,TILEMAP_FRONT,1);
 
-	dec0_pf1_draw(bitmap,0,0);
+	dec0_pf1_draw(bitmap,cliprect,0,0);
 }
 
 /******************************************************************************/
 
-void midres_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( midres )
 {
 	int trans;
 
@@ -686,33 +686,33 @@ void midres_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 
 	if (dec0_pri & 0x01)
 	{
-		dec0_pf2_draw(bitmap,TILEMAP_BACK|TILEMAP_IGNORE_TRANSPARENCY,0);
-		dec0_pf2_draw(bitmap,TILEMAP_FRONT|TILEMAP_IGNORE_TRANSPARENCY,1);
+		dec0_pf2_draw(bitmap,cliprect,TILEMAP_BACK|TILEMAP_IGNORE_TRANSPARENCY,0);
+		dec0_pf2_draw(bitmap,cliprect,TILEMAP_FRONT|TILEMAP_IGNORE_TRANSPARENCY,1);
 
 		if (dec0_pri & 0x02)
-			dec0_drawsprites(bitmap,0x08,trans);
+			dec0_drawsprites(bitmap,cliprect,0x08,trans);
 
-		dec0_pf3_draw(bitmap,TILEMAP_BACK,0);
-		dec0_pf3_draw(bitmap,TILEMAP_FRONT,1);
+		dec0_pf3_draw(bitmap,cliprect,TILEMAP_BACK,0);
+		dec0_pf3_draw(bitmap,cliprect,TILEMAP_FRONT,1);
 	}
 	else
 	{
-		dec0_pf3_draw(bitmap,TILEMAP_BACK|TILEMAP_IGNORE_TRANSPARENCY,0);
-		dec0_pf3_draw(bitmap,TILEMAP_FRONT|TILEMAP_IGNORE_TRANSPARENCY,1);
+		dec0_pf3_draw(bitmap,cliprect,TILEMAP_BACK|TILEMAP_IGNORE_TRANSPARENCY,0);
+		dec0_pf3_draw(bitmap,cliprect,TILEMAP_FRONT|TILEMAP_IGNORE_TRANSPARENCY,1);
 
 		if (dec0_pri & 0x02)
-			dec0_drawsprites(bitmap,0x08,trans);
+			dec0_drawsprites(bitmap,cliprect,0x08,trans);
 
-		dec0_pf2_draw(bitmap,TILEMAP_BACK,0);
-		dec0_pf2_draw(bitmap,TILEMAP_FRONT,1);
+		dec0_pf2_draw(bitmap,cliprect,TILEMAP_BACK,0);
+		dec0_pf2_draw(bitmap,cliprect,TILEMAP_FRONT,1);
 	}
 
 	if (dec0_pri & 0x02)
-		dec0_drawsprites(bitmap,0x08,trans ^ 0x08);
+		dec0_drawsprites(bitmap,cliprect,0x08,trans ^ 0x08);
 	else
-		dec0_drawsprites(bitmap,0x00,0x00);
+		dec0_drawsprites(bitmap,cliprect,0x00,0x00);
 
-	dec0_pf1_draw(bitmap,0,0);
+	dec0_pf1_draw(bitmap,cliprect,0,0);
 }
 
 /******************************************************************************/
@@ -729,7 +729,7 @@ WRITE16_HANDLER( dec0_pf1_control_1_w )
 
 WRITE16_HANDLER( dec0_pf1_data_w )
 {
-	data16_t oldword=dec0_pf1_data[offset];
+	UINT16 oldword=dec0_pf1_data[offset];
 	COMBINE_DATA(&dec0_pf1_data[offset]);
 	if (oldword!=dec0_pf1_data[offset]) {
 		tilemap_mark_tile_dirty(pf1_tilemap_0,offset);
@@ -750,7 +750,7 @@ WRITE16_HANDLER( dec0_pf2_control_1_w )
 
 WRITE16_HANDLER( dec0_pf2_data_w )
 {
-	data16_t oldword=dec0_pf2_data[offset];
+	UINT16 oldword=dec0_pf2_data[offset];
 	COMBINE_DATA(&dec0_pf2_data[offset]);
 	if (oldword!=dec0_pf2_data[offset]) {
 		tilemap_mark_tile_dirty(pf2_tilemap_0,offset);
@@ -771,7 +771,7 @@ WRITE16_HANDLER( dec0_pf3_control_1_w )
 
 WRITE16_HANDLER( dec0_pf3_data_w )
 {
-	data16_t oldword=dec0_pf3_data[offset];
+	UINT16 oldword=dec0_pf3_data[offset];
 	COMBINE_DATA(&dec0_pf3_data[offset]);
 	if (oldword!=dec0_pf3_data[offset]) {
 		tilemap_mark_tile_dirty(pf3_tilemap_0,offset);
@@ -785,10 +785,10 @@ WRITE16_HANDLER( dec0_priority_w )
   	COMBINE_DATA(&dec0_pri);
 }
 
-WRITE_HANDLER( dec0_pf3_control_8bit_w )
+WRITE8_HANDLER( dec0_pf3_control_8bit_w )
 {
 	static int buffer[0x20];
-	data16_t myword;
+	UINT16 myword;
 
 	buffer[offset]=data;
 
@@ -800,16 +800,16 @@ WRITE_HANDLER( dec0_pf3_control_8bit_w )
 	else dec0_pf3_control_1_w((offset-0x10)/2,myword,0);
 }
 
-WRITE_HANDLER( dec0_pf3_data_8bit_w )
+WRITE8_HANDLER( dec0_pf3_data_8bit_w )
 {
 	if (offset&1) { /* MSB has changed */
-		data16_t lsb=dec0_pf3_data[offset>>1];
-		data16_t newword=(lsb&0xff) | (data<<8);
+		UINT16 lsb=dec0_pf3_data[offset>>1];
+		UINT16 newword=(lsb&0xff) | (data<<8);
 		dec0_pf3_data[offset>>1]=newword;
 	}
 	else { /* LSB has changed */
-		data16_t msb=dec0_pf3_data[offset>>1];
-		data16_t newword=(msb&0xff00) | data;
+		UINT16 msb=dec0_pf3_data[offset>>1];
+		UINT16 newword=(msb&0xff00) | data;
 		dec0_pf3_data[offset>>1]=newword;
 	}
 	tilemap_mark_tile_dirty(pf3_tilemap_0,offset>>1);
@@ -817,7 +817,7 @@ WRITE_HANDLER( dec0_pf3_data_8bit_w )
 	tilemap_mark_tile_dirty(pf3_tilemap_2,offset>>1);
 }
 
-READ_HANDLER( dec0_pf3_data_8bit_r )
+READ8_HANDLER( dec0_pf3_data_8bit_r )
 {
 	if (offset&1) /* MSB */
 		return dec0_pf3_data[offset>>1]>>8;
@@ -877,16 +877,7 @@ static void get_pf3_tile_info(int tile_index)
 	SET_TILE_INFO(2,tile&0xfff,tile>>12,TILE_SPLIT(pri))
 }
 
-void dec0_nodma_vh_stop (void)
-{
-}
-
-void dec0_vh_stop (void)
-{
-	free(dec0_spriteram);
-}
-
-int dec0_nodma_vh_start (void)
+VIDEO_START( dec0_nodma )
 {
 	pf1_tilemap_0 = tilemap_create(get_pf1_tile_info,tile_shape0_8x8_scan,TILEMAP_TRANSPARENT, 8, 8,128, 32);
 	pf1_tilemap_1 = tilemap_create(get_pf1_tile_info,tile_shape1_8x8_scan,TILEMAP_TRANSPARENT, 8, 8, 64, 64);
@@ -930,10 +921,10 @@ int dec0_nodma_vh_start (void)
 	return 0;
 }
 
-int dec0_vh_start (void)
+VIDEO_START( dec0 )
 {
-	dec0_nodma_vh_start();
-	dec0_spriteram=malloc(0x800);
+	video_start_dec0_nodma();
+	dec0_spriteram=auto_malloc(0x800);
 
 	return 0;
 }
