@@ -11,10 +11,7 @@
 #include "driver.h"
 #include "vidhrdw/generic.h"
 
-
-
-static struct mame_bitmap *tmpbitmap1;
-
+static tilemap *bg_tilemap, *fg_tilemap;
 
 /***************************************************************************
 
@@ -33,7 +30,7 @@ static struct mame_bitmap *tmpbitmap1;
   bit 0 -- 390 ohm resistor  -- BLUE
 
 ***************************************************************************/
-static void convert_color_prom(unsigned char *palette, unsigned short *colortable,const unsigned char *color_prom,
+static void convert_color_prom(unsigned short *colortable,const unsigned char *color_prom,
 		int priority)
 {
 	int i,j;
@@ -43,37 +40,34 @@ static void convert_color_prom(unsigned char *palette, unsigned short *colortabl
 
 	for (i = 0;i < 256;i++)
 	{
-		int bit0,bit1,bit2;
+		int bit0,bit1,bit2,r,g,b;
 
 
 		/* red component */
 		bit0 = (*color_prom >> 5) & 0x01;
 		bit1 = (*color_prom >> 6) & 0x01;
 		bit2 = (*color_prom >> 7) & 0x01;
-		*(palette++) = 0x23 * bit0 + 0x4b * bit1 + 0x91 * bit2;
+		r = 0x23 * bit0 + 0x4b * bit1 + 0x91 * bit2;
 		/* green component */
 		bit0 = (*color_prom >> 2) & 0x01;
 		bit1 = (*color_prom >> 3) & 0x01;
 		bit2 = (*color_prom >> 4) & 0x01;
-		*(palette++) = 0x23 * bit0 + 0x4b * bit1 + 0x91 * bit2;
+		g = 0x23 * bit0 + 0x4b * bit1 + 0x91 * bit2;
 		/* blue component */
 		bit0 = 0;
 		bit1 = (*color_prom >> 0) & 0x01;
 		bit2 = (*color_prom >> 1) & 0x01;
-		*(palette++) = 0x23 * bit0 + 0x4b * bit1 + 0x91 * bit2;
+		b = 0x23 * bit0 + 0x4b * bit1 + 0x91 * bit2;
 
+		palette_set_color(i,r,g,b);
 		color_prom++;
 	}
 
 	/* reserve one color for the transparent pen (none of the game colors can have */
 	/* these RGB components) */
-	*(palette++) = 1;
-	*(palette++) = 1;
-	*(palette++) = 1;
+	palette_set_color(256,1,1,1);
 	/* and the last color for the sprite covering pen */
-	*(palette++) = 2;
-	*(palette++) = 2;
-	*(palette++) = 2;
+	palette_set_color(257,2,2,2);
 
 
 	/* characters */
@@ -115,8 +109,8 @@ static void convert_color_prom(unsigned char *palette, unsigned short *colortabl
 	for (i = 0;i < 32;i++)
 	{
 		/* build two versions of the colortable, one with the covering color
-		   mapped to transparent, and one with all colors but the covering one
-		   mapped to transparent. */
+           mapped to transparent, and one with all colors but the covering one
+           mapped to transparent. */
 		for (j = 0;j < 16;j++)
 		{
 			if (j < 8)
@@ -136,154 +130,159 @@ static void convert_color_prom(unsigned char *palette, unsigned short *colortabl
 	}
 }
 
-
-
-void docastle_vh_convert_color_prom(unsigned char *palette,unsigned short *colortable,const unsigned char *color_prom)
+PALETTE_INIT( docastle )
 {
-	convert_color_prom(palette,colortable,color_prom,0);
+	convert_color_prom(colortable,color_prom,0);
 }
 
-void dorunrun_vh_convert_color_prom(unsigned char *palette,unsigned short *colortable,const unsigned char *color_prom)
+PALETTE_INIT( dorunrun )
 {
-	convert_color_prom(palette,colortable,color_prom,1);
+	convert_color_prom(colortable,color_prom,1);
 }
 
-
-
-/***************************************************************************
-
-  Start the video hardware emulation.
-
-***************************************************************************/
-int docastle_vh_start(void)
+WRITE8_HANDLER( docastle_videoram_w )
 {
-	if (generic_vh_start() != 0)
-		return 1;
-
-	if ((tmpbitmap1 = bitmap_alloc(Machine->drv->screen_width,Machine->drv->screen_height)) == 0)
+	if (videoram[offset] != data)
 	{
-		generic_vh_stop();
-		return 1;
+		videoram[offset] = data;
+		tilemap_mark_tile_dirty(bg_tilemap, offset);
+		tilemap_mark_tile_dirty(fg_tilemap, offset);
 	}
-
-	return 0;
 }
 
-
-
-/***************************************************************************
-
-  Stop the video hardware emulation.
-
-***************************************************************************/
-void docastle_vh_stop(void)
+WRITE8_HANDLER( docastle_colorram_w )
 {
-	bitmap_free(tmpbitmap1);
-	generic_vh_stop();
+	if (colorram[offset] != data)
+	{
+		colorram[offset] = data;
+		tilemap_mark_tile_dirty(bg_tilemap, offset);
+		tilemap_mark_tile_dirty(fg_tilemap, offset);
+	}
 }
 
-
-READ_HANDLER( docastle_flipscreen_off_r )
+READ8_HANDLER( docastle_flipscreen_off_r )
 {
 	flip_screen_set(0);
+	tilemap_mark_all_tiles_dirty(ALL_TILEMAPS);
 	return 0;
 }
 
-READ_HANDLER( docastle_flipscreen_on_r )
+READ8_HANDLER( docastle_flipscreen_on_r )
 {
 	flip_screen_set(1);
-	return 0;
+	tilemap_mark_all_tiles_dirty(ALL_TILEMAPS);
+	return 1;
 }
 
-WRITE_HANDLER( docastle_flipscreen_off_w )
+WRITE8_HANDLER( docastle_flipscreen_off_w )
 {
 	flip_screen_set(0);
+	tilemap_mark_all_tiles_dirty(ALL_TILEMAPS);
 }
 
-WRITE_HANDLER( docastle_flipscreen_on_w )
+WRITE8_HANDLER( docastle_flipscreen_on_w )
 {
 	flip_screen_set(1);
+	tilemap_mark_all_tiles_dirty(ALL_TILEMAPS);
 }
 
+static void get_bg_tile_info(int tile_index)
+{
+	int code = videoram[tile_index] + 8 * (colorram[tile_index] & 0x20);
+	int color = colorram[tile_index] & 0x1f;
 
+	SET_TILE_INFO(0, code, color, 0)
+}
 
-/***************************************************************************
+static void get_fg_tile_info(int tile_index)
+{
+	int code = videoram[tile_index] + 8 * (colorram[tile_index] & 0x20);
+	int color = (colorram[tile_index] & 0x1f) + 32;
 
-  Draw the game screen in the given mame_bitmap.
-  Do NOT call osd_update_display() from this function, it will be called by
-  the main emulation engine.
+	SET_TILE_INFO(0, code, color, 0)
+}
 
-***************************************************************************/
-void docastle_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_START( docastle )
+{
+	bg_tilemap = tilemap_create(get_bg_tile_info, tilemap_scan_rows,
+		TILEMAP_OPAQUE, 8, 8, 32, 32);
+
+	if ( !bg_tilemap )
+		return 1;
+
+	fg_tilemap = tilemap_create(get_fg_tile_info, tilemap_scan_rows,
+		TILEMAP_TRANSPARENT_COLOR, 8, 8, 32, 32);
+
+	if ( !fg_tilemap )
+		return 1;
+
+	tilemap_set_transparent_pen(fg_tilemap, 256);
+
+	return 0;
+}
+
+static void docastle_draw_sprites( mame_bitmap *bitmap )
 {
 	int offs;
 
-
-	if (full_refresh)
-	{
-		memset(dirtybuffer,1,videoram_size);
-	}
-
-
-	/* for every character in the Video RAM, check if it has been modified */
-	/* since last time and update it accordingly. */
-	for (offs = videoram_size - 1;offs >= 0;offs--)
-	{
-		if (dirtybuffer[offs])
-		{
-			int sx,sy;
-
-
-			dirtybuffer[offs] = 0;
-
-			sx = offs % 32;
-			sy = offs / 32;
-
-			if (flip_screen)
-			{
-				sx = 31 - sx;
-				sy = 31 - sy;
-			}
-
-			drawgfx(tmpbitmap,Machine->gfx[0],
-					videoram[offs] + 8*(colorram[offs] & 0x20),
-					colorram[offs] & 0x1f,
-					flip_screen,flip_screen,
-					8*sx,8*sy,
-					&Machine->visible_area,TRANSPARENCY_NONE,0);
-
-			/* also draw the part of the character which has priority over the */
-			/* sprites in another bitmap */
-			drawgfx(tmpbitmap1,Machine->gfx[0],
-					videoram[offs] + 8*(colorram[offs] & 0x20),
-					32 + (colorram[offs] & 0x1f),
-					flip_screen,flip_screen,
-					8*sx,8*sy,
-					&Machine->visible_area,TRANSPARENCY_NONE,0);
-		}
-	}
-
-
-	/* copy the character mapped graphics */
-	copybitmap(bitmap,tmpbitmap,0,0,0,0,&Machine->visible_area,TRANSPARENCY_NONE,0);
-
-
 	fillbitmap(priority_bitmap,1,NULL);
 
-
-	/* Draw the sprites */
 	for (offs = spriteram_size - 4;offs >= 0;offs -= 4)
 	{
 		int sx,sy,flipx,flipy,code,color;
 
+		if (Machine->gfx[1]->total_elements > 256)
+		{
+			/* spriteram
 
-		code = spriteram[offs + 3];
-		color = spriteram[offs + 2] & 0x1f;
-		sx = spriteram[offs + 1];
-		sy = spriteram[offs];
-		flipx = spriteram[offs + 2] & 0x40;
-		flipy = spriteram[offs + 2] & 0x80;
+             indoor soccer appears to have a slightly different spriteram
+             format to the other games, allowing a larger number of sprite
+             tiles
 
+             yyyy yyyy  xxxx xxxx  TX-T pppp  tttt tttt
+
+             y = ypos
+             x = xpos
+             X = x-flip
+             T = extra tile number bits
+             p = palette
+             t = tile number
+
+             */
+
+			code = spriteram[offs + 3];
+			color = spriteram[offs + 2] & 0x0f;
+			sx = ((spriteram[offs + 1] + 8) & 0xff) - 8;
+			sy = spriteram[offs];
+			flipx = spriteram[offs + 2] & 0x40;
+			flipy = 0;
+			if (spriteram[offs + 2] & 0x10) code += 0x100;
+			if (spriteram[offs + 2] & 0x80) code += 0x200;
+		}
+		else
+		{
+			/* spriteram
+
+            this is the standard spriteram layout, used by most games
+
+             yyyy yyyy  xxxx xxxx  YX-p pppp  tttt tttt
+
+             y = ypos
+             x = xpos
+             X = x-flip
+             Y = y-flip
+             p = palette
+             t = tile number
+
+             */
+
+			code = spriteram[offs + 3];
+			color = spriteram[offs + 2] & 0x1f;
+			sx = ((spriteram[offs + 1] + 8) & 0xff) - 8;
+			sy = spriteram[offs];
+			flipx = spriteram[offs + 2] & 0x40;
+			flipy = spriteram[offs + 2] & 0x80;
+		}
 
 		if (flip_screen)
 		{
@@ -311,8 +310,11 @@ void docastle_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 				&Machine->visible_area,TRANSPARENCY_COLOR,256,
 				0x02);
 	}
+}
 
-
-	/* now redraw the portions of the background which have priority over sprites */
-	copybitmap(bitmap,tmpbitmap1,0,0,0,0,&Machine->visible_area,TRANSPARENCY_COLOR,256);
+VIDEO_UPDATE( docastle )
+{
+	tilemap_draw(bitmap, &Machine->visible_area, bg_tilemap, 0, 0);
+	docastle_draw_sprites(bitmap);
+	tilemap_draw(bitmap, &Machine->visible_area, fg_tilemap, 0, 0);
 }
