@@ -1,13 +1,12 @@
 /***************************************************************************
 
-  vidhrdw.c
-
-  Functions to emulate the video hardware of the machine.
+    Jaleco Exerion
 
 ***************************************************************************/
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "exerion.h"
 
 /*#define DEBUG_SPRITES */
 
@@ -55,30 +54,31 @@ static UINT8 *background_mixer;
 
 ***************************************************************************/
 
-void exerion_vh_convert_color_prom(unsigned char *palette, unsigned short *colortable, const unsigned char *color_prom)
+PALETTE_INIT( exerion )
 {
 	int i;
 
 	for (i = 0; i < Machine->drv->total_colors; i++)
 	{
-		int bit0, bit1, bit2;
+		int bit0, bit1, bit2, r, g, b;
 
 		/* red component */
 		bit0 = (*color_prom >> 0) & 0x01;
 		bit1 = (*color_prom >> 1) & 0x01;
 		bit2 = (*color_prom >> 2) & 0x01;
-		*palette++ = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
+		r = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
 		/* green component */
 		bit0 = (*color_prom >> 3) & 0x01;
 		bit1 = (*color_prom >> 4) & 0x01;
 		bit2 = (*color_prom >> 5) & 0x01;
-		*palette++ = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
+		g = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
 		/* blue component */
 		bit0 = 0;
 		bit1 = (*color_prom >> 6) & 0x01;
 		bit2 = (*color_prom >> 7) & 0x01;
-		*palette++ = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
+		b = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
 
+		palette_set_color(i,r,g,b);
 		color_prom++;
 	}
 
@@ -106,11 +106,11 @@ void exerion_vh_convert_color_prom(unsigned char *palette, unsigned short *color
 
 /*************************************
  *
- *		Video system startup
+ *  Video system startup
  *
  *************************************/
 
-int exerion_vh_start (void)
+VIDEO_START( exerion )
 {
 	UINT16 *dst;
 	UINT8 *src;
@@ -124,37 +124,33 @@ int exerion_vh_start (void)
 	background_mixer = memory_region(REGION_PROMS) + 0x320;
 
 	/* allocate memory to track the background latches */
-	background_latches = malloc(Machine->drv->screen_height * 16);
+	background_latches = auto_malloc(Machine->drv->screen_height * 16);
 	if (!background_latches)
 		return 1;
 
 	/* allocate memory for the decoded background graphics */
-	background_gfx[0] = malloc(2 * 256 * 256 * 4);
+	background_gfx[0] = auto_malloc(2 * 256 * 256 * 4);
 	background_gfx[1] = background_gfx[0] + 256 * 256;
 	background_gfx[2] = background_gfx[1] + 256 * 256;
 	background_gfx[3] = background_gfx[2] + 256 * 256;
 	if (!background_gfx[0])
-	{
-		free(background_latches);
-		background_latches = NULL;
 		return 1;
-	}
 
 	/*---------------------------------
-	 * Decode the background graphics
-	 *
-	 * We decode the 4 background layers separately, but shuffle the bits so that
-	 * we can OR all four layers together. Each layer has 2 bits per pixel. Each
-	 * layer is decoded into the following bit patterns:
-	 *
-	 *	000a 0000 00AA
-	 *  00b0 0000 BB00
-	 *  0c00 00CC 0000
-	 *  d000 DD00 0000
-	 *
-	 * Where AA,BB,CC,DD are the 2bpp data for the pixel,and a,b,c,d are the OR
-	 * of these two bits together.
-	 */
+     * Decode the background graphics
+     *
+     * We decode the 4 background layers separately, but shuffle the bits so that
+     * we can OR all four layers together. Each layer has 2 bits per pixel. Each
+     * layer is decoded into the following bit patterns:
+     *
+     *  000a 0000 00AA
+     *  00b0 0000 BB00
+     *  0c00 00CC 0000
+     *  d000 DD00 0000
+     *
+     * Where AA,BB,CC,DD are the 2bpp data for the pixel,and a,b,c,d are the OR
+     * of these two bits together.
+     */
 	for (i = 0; i < 4; i++)
 	{
 		src = memory_region(REGION_GFX3) + i * 0x2000;
@@ -188,47 +184,18 @@ int exerion_vh_start (void)
 		}
 	}
 
-	return generic_vh_start();
-}
-
-
-/*************************************
- *
- *		Video system shutdown
- *
- *************************************/
-
-void exerion_vh_stop (void)
-{
-#ifdef DEBUG_SPRITES
-	fclose (sprite_log);
-#endif
-
-	/* free the background graphics data */
-	if (background_gfx[0])
-		free(background_gfx[0]);
-	background_gfx[0] = NULL;
-	background_gfx[1] = NULL;
-	background_gfx[2] = NULL;
-	background_gfx[3] = NULL;
-
-	/* free the background latches data */
-	if (background_latches)
-		free(background_latches);
-	background_latches = NULL;
-
-	generic_vh_stop();
+	return video_start_generic();
 }
 
 
 
 /*************************************
  *
- *		Video register I/O
+ *  Video register I/O
  *
  *************************************/
 
-WRITE_HANDLER( exerion_videoreg_w )
+WRITE8_HANDLER( exerion_videoreg_w )
 {
 	/* bit 0 = flip screen and joystick input multiplexor */
 	exerion_cocktail_flip = data & 1;
@@ -246,7 +213,7 @@ WRITE_HANDLER( exerion_videoreg_w )
 }
 
 
-WRITE_HANDLER( exerion_video_latch_w )
+WRITE8_HANDLER( exerion_video_latch_w )
 {
 	int ybeam = cpu_getscanline();
 
@@ -266,7 +233,7 @@ WRITE_HANDLER( exerion_video_latch_w )
 }
 
 
-READ_HANDLER( exerion_video_timing_r )
+READ8_HANDLER( exerion_video_timing_r )
 {
 	/* bit 1 is VBLANK */
 	/* bit 0 is the SNMI signal, which is low for H >= 0x1c0 and /VBLANK */
@@ -286,17 +253,17 @@ READ_HANDLER( exerion_video_timing_r )
 
 /*************************************
  *
- *		Background rendering
+ *  Background rendering
  *
  *************************************/
 
-void draw_background(struct mame_bitmap *bitmap)
+void draw_background(mame_bitmap *bitmap, const rectangle *cliprect)
 {
-	UINT8 *latches = &background_latches[VISIBLE_Y_MIN * 16];
+	UINT8 *latches = &background_latches[cliprect->min_y * 16];
 	int x, y;
 
 	/* loop over all visible scanlines */
-	for (y = VISIBLE_Y_MIN; y < VISIBLE_Y_MAX; y++, latches += 16)
+	for (y = cliprect->min_y; y <= cliprect->max_y; y++, latches += 16)
 	{
 		UINT16 *src0 = &background_gfx[0][latches[1] * 256];
 		UINT16 *src1 = &background_gfx[1][latches[3] * 256];
@@ -322,7 +289,7 @@ void draw_background(struct mame_bitmap *bitmap)
 		if (!exerion_cocktail_flip)
 		{
 			/* skip processing anything that's not visible */
-			for (x = BACKGROUND_X_START; x < VISIBLE_X_MIN; x++)
+			for (x = BACKGROUND_X_START; x < cliprect->min_x; x++)
 			{
 				if (!(++xoffs0 & 0x1f)) start0++, stop0++;
 				if (!(++xoffs1 & 0x1f)) start1++, stop1++;
@@ -331,7 +298,7 @@ void draw_background(struct mame_bitmap *bitmap)
 			}
 
 			/* draw the rest of the scanline fully */
-			for (x = VISIBLE_X_MIN; x < VISIBLE_X_MAX; x++)
+			for (x = cliprect->min_x; x <= cliprect->max_x; x++)
 			{
 				UINT16 combined = 0;
 				UINT8 lookupval;
@@ -359,7 +326,7 @@ void draw_background(struct mame_bitmap *bitmap)
 		else
 		{
 			/* skip processing anything that's not visible */
-			for (x = BACKGROUND_X_START; x < VISIBLE_X_MIN; x++)
+			for (x = BACKGROUND_X_START; x < cliprect->min_x; x++)
 			{
 				if (!(xoffs0-- & 0x1f)) start0++, stop0++;
 				if (!(xoffs1-- & 0x1f)) start1++, stop1++;
@@ -368,7 +335,7 @@ void draw_background(struct mame_bitmap *bitmap)
 			}
 
 			/* draw the rest of the scanline fully */
-			for (x = VISIBLE_X_MIN; x < VISIBLE_X_MAX; x++)
+			for (x = cliprect->min_x; x <= cliprect->max_x; x++)
 			{
 				UINT16 combined = 0;
 				UINT8 lookupval;
@@ -396,18 +363,18 @@ void draw_background(struct mame_bitmap *bitmap)
 
 		/* draw the scanline */
 		pens = &Machine->remapped_colortable[0x200 + (latches[12] >> 4) * 16];
-		draw_scanline8(bitmap, VISIBLE_X_MIN, y, VISIBLE_X_MAX - VISIBLE_X_MIN, &scanline[VISIBLE_X_MIN], pens, -1);
+		draw_scanline8(bitmap, cliprect->min_x, y, cliprect->max_x - cliprect->min_x + 1, &scanline[cliprect->min_x], pens, -1);
 	}
 }
 
 
 /*************************************
  *
- *		Core refresh routine
+ *  Core refresh routine
  *
  *************************************/
 
-void exerion_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh)
+VIDEO_UPDATE( exerion )
 {
 	int sx, sy, offs, i;
 
@@ -415,7 +382,7 @@ void exerion_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh)
 	exerion_video_latch_w(-1, 0);
 
 	/* draw background */
-	draw_background(bitmap);
+	draw_background(bitmap, cliprect);
 
 #ifdef DEBUG_SPRITES
 	if (sprite_log)
@@ -447,7 +414,7 @@ void exerion_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh)
 		int code2 = code;
 
 		int color = ((flags >> 1) & 0x03) | ((code >> 5) & 0x04) | (code & 0x08) | (sprite_palette * 16);
-		const struct GfxElement *gfx = doubled ? Machine->gfx[2] : Machine->gfx[1];
+		const gfx_element *gfx = doubled ? Machine->gfx[2] : Machine->gfx[1];
 
 		if (exerion_cocktail_flip)
 		{
@@ -466,11 +433,11 @@ void exerion_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh)
 				code &= ~0x10, code2 |= 0x10;
 
 			drawgfx(bitmap, gfx, code2, color, xflip, yflip, x, y + gfx->height,
-			        &Machine->visible_area, TRANSPARENCY_COLOR, 16);
+			        cliprect, TRANSPARENCY_COLOR, 16);
 		}
 
 		drawgfx(bitmap, gfx, code, color, xflip, yflip, x, y,
-		        &Machine->visible_area, TRANSPARENCY_COLOR, 16);
+		        cliprect, TRANSPARENCY_COLOR, 16);
 
 		if (doubled) i += 4;
 	}
@@ -487,6 +454,6 @@ void exerion_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh)
 				videoram[offs] + 256 * char_bank,
 				((videoram[offs] & 0xf0) >> 4) + char_palette * 16,
 				exerion_cocktail_flip, exerion_cocktail_flip, x, y,
-				&Machine->visible_area, TRANSPARENCY_PEN, 0);
+				cliprect, TRANSPARENCY_PEN, 0);
 		}
 }
