@@ -1,77 +1,78 @@
 /***************************************************************************
 
-							  -= Metro Games =-
+                              -= Metro Games =-
 
-					driver by	Luca Elia (l.elia@tin.it)
+                    driver by   Luca Elia (l.elia@tin.it)
 
 
-Note:	if MAME_DEBUG is defined, pressing Z with:
+Note:   if MAME_DEBUG is defined, pressing Z with:
 
-				Q		Shows Layer 0
-				W		Shows Layer 1
-				E		Shows Layer 2
-				A		Shows Sprites
+                Q       Shows Layer 0
+                W       Shows Layer 1
+                E       Shows Layer 2
+                A       Shows Sprites
 
-		Keys can be used together!
+        Keys can be used together!
 
 
-							[ 3 Scrolling Layers ]
+                            [ 3 Scrolling Layers ]
 
-		There is memory for a huge layer, but the actual tilemap
-		is a smaller window (of fixed size) carved from anywhere
-		inside that layer.
+        There is memory for a huge layer, but the actual tilemap
+        is a smaller window (of fixed size) carved from anywhere
+        inside that layer.
 
-		Tile Size:				  	8 x 8 x 4
-		(later games can switch to  8 x 8 x 8, 16 x 16 x 4/8 at run time)
+        Tile Size:                  8 x 8 x 4
+        (later games can switch to  8 x 8 x 8, 16 x 16 x 4/8 at run time)
 
-		Big Layer Size:			2048 x 2048 (8x8 tiles) or 4096 x 4096 (16x16 tiles)
+        Big Layer Size:         2048 x 2048 (8x8 tiles) or 4096 x 4096 (16x16 tiles)
 
-		Tilemap Window Size:	512 x 256 (8x8 tiles) or 1024 x 512 (16x16 tiles)
+        Tilemap Window Size:    512 x 256 (8x8 tiles) or 1024 x 512 (16x16 tiles)
 
-		The tile codes in memory do not map directly to tiles. They
-		are indexes into a table (with 0x200 entries) that defines
-		a virtual set of tiles for the 3 layers. Each entry in that
-		table adds 16 tiles to the set of available tiles, and decides
-		their color code.
+        The tile codes in memory do not map directly to tiles. They
+        are indexes into a table (with 0x200 entries) that defines
+        a virtual set of tiles for the 3 layers. Each entry in that
+        table adds 16 tiles to the set of available tiles, and decides
+        their color code.
 
-		Tile code with their msbit set are different as they mean:
-		draw a tile filled with a single color (0-1ff)
+        Tile code with their msbit set are different as they mean:
+        draw a tile filled with a single color (0-1ff)
 
 
-							[ 512 Zooming Sprites ]
+                            [ 512 Zooming Sprites ]
 
-		The sprites are NOT tile based: the "tile" size can vary from
-		8 to 64 (independently for width and height) with an 8 pixel
-		granularity. The "tile" address is a multiple of 8x8 pixels.
+        The sprites are NOT tile based: the "tile" size can vary from
+        8 to 64 (independently for width and height) with an 8 pixel
+        granularity. The "tile" address is a multiple of 8x8 pixels.
 
-		Each sprite can be shrinked to ~1/4 or enlarged to ~32x following
-		an exponential curve of sizes (with one zoom value for both width
-		and height)
+        Each sprite can be shrinked to ~1/4 or enlarged to ~32x following
+        an exponential curve of sizes (with one zoom value for both width
+        and height)
 
 
 ***************************************************************************/
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "vidhrdw/konamiic.h"
 
 /* Variables that driver has access to: */
 
-data16_t *metro_videoregs;
-data16_t *metro_screenctrl;
-data16_t *metro_scroll;
-data16_t *metro_tiletable;
+UINT16 *metro_videoregs;
+UINT16 *metro_screenctrl;
+UINT16 *metro_scroll;
+UINT16 *metro_tiletable;
 size_t metro_tiletable_size;
-data16_t *metro_vram_0,*metro_vram_1,*metro_vram_2;
-data16_t *metro_window;
+UINT16 *metro_vram_0,*metro_vram_1,*metro_vram_2;
+UINT16 *metro_window;
 
 static int support_8bpp,support_16x16;
 static int has_zoom;
 
 
-data16_t *metro_K053936_ram,*metro_K053936_ctrl;
-static struct tilemap *metro_K053936_tilemap;
+UINT16 *metro_K053936_ram;
+static tilemap *metro_K053936_tilemap;
 
-static data16_t *metro_tiletable_old;
+static UINT16 *metro_tiletable_old;
 
 
 static void metro_K053936_get_tile_info(int tile_index)
@@ -85,65 +86,43 @@ static void metro_K053936_get_tile_info(int tile_index)
 			0)
 }
 
+static void metro_K053936_gstrik2_get_tile_info(int tile_index)
+{
+	int code = metro_K053936_ram[tile_index];
+
+	SET_TILE_INFO(
+			2,
+			(code & 0x7fff)>>2,
+			0x1e,
+			0)
+}
 
 WRITE16_HANDLER( metro_K053936_w )
 {
-	data16_t oldword = metro_K053936_ram[offset];
+	UINT16 oldword = metro_K053936_ram[offset];
 	COMBINE_DATA(&metro_K053936_ram[offset]);
 	if (oldword != metro_K053936_ram[offset])
 		tilemap_mark_tile_dirty(metro_K053936_tilemap,offset);
 }
 
-void K053936_zoom_draw(struct mame_bitmap *bitmap)
+UINT32 tilemap_scan_gstrik2( UINT32 col, UINT32 row, UINT32 num_cols, UINT32 num_rows )
 {
-	UINT32 startx,starty;
-	int incxx,incxy,incyx,incyy;
+	/* logical (col,row) -> memory offset */
+	int val;
 
-	startx = 256 * (INT16)(metro_K053936_ctrl[0x00]);
-	starty = 256 * (INT16)(metro_K053936_ctrl[0x01]);
-	incyx  =       (INT16)(metro_K053936_ctrl[0x02]);
-	incxx  =       (INT16)(metro_K053936_ctrl[0x03]);
-	incyy  =       (INT16)(metro_K053936_ctrl[0x04]);
-	incxy  =       (INT16)(metro_K053936_ctrl[0x05]);
+	val = (row&0x3f)*(256*2) + (col*2);
 
-	startx += 21 * incyx;
-	starty += 21 * incyy;
+	if (row&0x40) val+=1;
+	if (row&0x80) val+=256;
 
-	startx += 69 * incxx;
-	starty += 69 * incxy;
-
-	tilemap_draw_roz(bitmap,metro_K053936_tilemap,startx << 5,starty << 5,
-			incxx << 5,incxy << 5,incyx << 5,incyy << 5,
-			0,	/* no wraparound */
-			0,0);
-
-#if 0
-	usrintf_showmessage("%04x%04x%04x%04x %04x%04x%04x%04x\n%04x%04x%04x%04x %04x%04x%04x%04x",
-			metro_K053936_ctrl[0x00],
-			metro_K053936_ctrl[0x01],
-			metro_K053936_ctrl[0x02],
-			metro_K053936_ctrl[0x03],
-			metro_K053936_ctrl[0x04],
-			metro_K053936_ctrl[0x05],
-			metro_K053936_ctrl[0x06],
-			metro_K053936_ctrl[0x07],
-			metro_K053936_ctrl[0x08],
-			metro_K053936_ctrl[0x09],
-			metro_K053936_ctrl[0x0a],
-			metro_K053936_ctrl[0x0b],
-			metro_K053936_ctrl[0x0c],
-			metro_K053936_ctrl[0x0d],
-			metro_K053936_ctrl[0x0e],
-			metro_K053936_ctrl[0x0f]);
-#endif
+	return val;
 }
 
 
-
 /***************************************************************************
 
 
-							Palette GGGGGRRRRRBBBBBx
+                            Palette GGGGGRRRRRBBBBBx
 
 
 ***************************************************************************/
@@ -166,19 +145,19 @@ WRITE16_HANDLER( metro_paletteram_w )
 /***************************************************************************
 
 
-						Tilemaps: Tiles Set & Window
+                        Tilemaps: Tiles Set & Window
 
-	Each entry in the Tiles Set RAM uses 2 words to specify a starting
-	tile code and a color code. This adds 16 consecutive tiles with
-	that color code to the set of available tiles.
+    Each entry in the Tiles Set RAM uses 2 words to specify a starting
+    tile code and a color code. This adds 16 consecutive tiles with
+    that color code to the set of available tiles.
 
-		Offset:		Bits:					Value:
+        Offset:     Bits:                   Value:
 
-		0.w			fedc ---- ---- ----
-					---- ba98 7654 ----		Color Code
-					---- ---- ---- 3210		Code High Bits
+        0.w         fedc ---- ---- ----
+                    ---- ba98 7654 ----     Color Code
+                    ---- ---- ---- 3210     Code High Bits
 
-		2.w									Code Low Bits
+        2.w                                 Code Low Bits
 
 
 ***************************************************************************/
@@ -187,13 +166,13 @@ WRITE16_HANDLER( metro_paletteram_w )
 /***************************************************************************
 
 
-							Tilemaps: Rendering
+                            Tilemaps: Rendering
 
 
 ***************************************************************************/
 
-static struct tilemap *tilemap[3];
-static struct tilemap *tilemap_16x16[3];
+static tilemap *bg_tilemap[3];
+static tilemap *tilemap_16x16[3];
 static UINT8 *empty_tiles;
 
 /* A 2048 x 2048 virtual tilemap */
@@ -205,14 +184,14 @@ static UINT8 *empty_tiles;
 
 #define WIN_NX		(0x40)
 #define WIN_NY		(0x20)
-/*#define WIN_NX		(0x40+1) */
-/*#define WIN_NY		(0x20+1) */
+/*#define WIN_NX        (0x40+1) */
+/*#define WIN_NY        (0x20+1) */
 
 
 /* 8x8x4 tiles only */
-INLINE void get_tile_info(int tile_index,int layer,data16_t *vram)
+INLINE void get_tile_info(int tile_index,int layer,UINT16 *vram)
 {
-	data16_t code;
+	UINT16 code;
 	int      table_index;
 	UINT32   tile;
 
@@ -248,9 +227,9 @@ INLINE void get_tile_info(int tile_index,int layer,data16_t *vram)
 
 /* 8x8x4 or 8x8x8 tiles. It's the tile's color that decides: if its low 4
    bits are high ($f,$1f,$2f etc) the tile is 8bpp, otherwise it's 4bpp */
-INLINE void get_tile_info_8bit(int tile_index,int layer,data16_t *vram)
+INLINE void get_tile_info_8bit(int tile_index,int layer,UINT16 *vram)
 {
-	data16_t code;
+	UINT16 code;
 	int      table_index;
 	UINT32   tile;
 
@@ -291,9 +270,9 @@ INLINE void get_tile_info_8bit(int tile_index,int layer,data16_t *vram)
 
 /* 16x16x4 or 16x16x8 tiles. It's the tile's color that decides: if its low 4
    bits are high ($f,$1f,$2f etc) the tile is 8bpp, otherwise it's 4bpp */
-INLINE void get_tile_info_16x16_8bit(int tile_index,int layer,data16_t *vram)
+INLINE void get_tile_info_16x16_8bit(int tile_index,int layer,UINT16 *vram)
 {
-	data16_t code;
+	UINT16 code;
 	int      table_index;
 	UINT32   tile;
 
@@ -333,10 +312,10 @@ INLINE void get_tile_info_16x16_8bit(int tile_index,int layer,data16_t *vram)
 }
 
 
-INLINE void metro_vram_w(offs_t offset,data16_t data,data16_t mem_mask,int layer,data16_t *vram)
+INLINE void metro_vram_w(offs_t offset,UINT16 data,UINT16 mem_mask,int layer,UINT16 *vram)
 {
-	data16_t olddata = vram[offset];
-	data16_t newdata = COMBINE_DATA(&vram[offset]);
+	UINT16 olddata = vram[offset];
+	UINT16 newdata = COMBINE_DATA(&vram[offset]);
 	if ( newdata != olddata )
 	{
 		/* Account for the window */
@@ -347,7 +326,7 @@ INLINE void metro_vram_w(offs_t offset,data16_t data,data16_t mem_mask,int layer
 		if	( (col >= 0) && (col < WIN_NX) &&
 			  (row >= 0) && (row < WIN_NY) )
 		{
-			tilemap_mark_tile_dirty(tilemap[layer], row * WIN_NX + col );
+			tilemap_mark_tile_dirty(bg_tilemap[layer], row * WIN_NX + col );
 			if (tilemap_16x16[layer])
 				tilemap_mark_tile_dirty(tilemap_16x16[layer], row * WIN_NX + col );
 		}
@@ -377,12 +356,12 @@ WRITE16_HANDLER( metro_vram_2_w ) { metro_vram_w(offset,data,mem_mask,2,metro_vr
 /* Dirty the relevant tilemap when its window changes */
 WRITE16_HANDLER( metro_window_w )
 {
-	data16_t olddata = metro_window[offset];
-	data16_t newdata = COMBINE_DATA( &metro_window[offset] );
+	UINT16 olddata = metro_window[offset];
+	UINT16 newdata = COMBINE_DATA( &metro_window[offset] );
 	if ( newdata != olddata )
 	{
 		offset /= 2;
-		tilemap_mark_all_tiles_dirty(tilemap[offset]);
+		tilemap_mark_all_tiles_dirty(bg_tilemap[offset]);
 		if (tilemap_16x16[offset]) tilemap_mark_all_tiles_dirty(tilemap_16x16[offset]);
 	}
 }
@@ -392,7 +371,7 @@ WRITE16_HANDLER( metro_window_w )
 /***************************************************************************
 
 
-							Video Init Routines
+                            Video Init Routines
 
 
 ***************************************************************************/
@@ -408,20 +387,11 @@ WRITE16_HANDLER( metro_window_w )
 int metro_sprite_xoffs, metro_sprite_yoffs;
 
 
-void metro_vh_stop(void)
-{
-	free(empty_tiles);
-	empty_tiles = NULL;
-
-	free(metro_tiletable_old);
-	metro_tiletable_old = NULL;
-}
-
 static void alloc_empty_tiles(void)
 {
 	int code,i;
 
-	empty_tiles = malloc(16*16*16);
+	empty_tiles = auto_malloc(16*16*16);
 	if (!empty_tiles) return;
 
 	for (code = 0;code < 0x10;code++)
@@ -429,98 +399,89 @@ static void alloc_empty_tiles(void)
 			empty_tiles[16*16*code + i] = code ^ 0x0f;
 }
 
-int metro_vh_start_14100(void)
+VIDEO_START( metro_14100 )
 {
 	support_8bpp = 0;
 	support_16x16 = 0;
 	has_zoom = 0;
 
 	alloc_empty_tiles();
-	metro_tiletable_old = malloc(metro_tiletable_size);
+	metro_tiletable_old = auto_malloc(metro_tiletable_size);
 
-	tilemap[0] = tilemap_create(get_tile_info_0,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,WIN_NX,WIN_NY);
-	tilemap[1] = tilemap_create(get_tile_info_1,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,WIN_NX,WIN_NY);
-	tilemap[2] = tilemap_create(get_tile_info_2,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,WIN_NX,WIN_NY);
+	bg_tilemap[0] = tilemap_create(get_tile_info_0,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,WIN_NX,WIN_NY);
+	bg_tilemap[1] = tilemap_create(get_tile_info_1,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,WIN_NX,WIN_NY);
+	bg_tilemap[2] = tilemap_create(get_tile_info_2,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,WIN_NX,WIN_NY);
 
 	tilemap_16x16[0] = NULL;
 	tilemap_16x16[1] = NULL;
 	tilemap_16x16[2] = NULL;
 
-	if (!tilemap[0] || !tilemap[1] || !tilemap[2] || !empty_tiles || !metro_tiletable_old)
-	{
-		metro_vh_stop();
+	if (!bg_tilemap[0] || !bg_tilemap[1] || !bg_tilemap[2] || !empty_tiles || !metro_tiletable_old)
 		return 1;
-	}
 
-	tilemap_set_transparent_pen(tilemap[0],0);
-	tilemap_set_transparent_pen(tilemap[1],0);
-	tilemap_set_transparent_pen(tilemap[2],0);
+	tilemap_set_transparent_pen(bg_tilemap[0],0);
+	tilemap_set_transparent_pen(bg_tilemap[1],0);
+	tilemap_set_transparent_pen(bg_tilemap[2],0);
 
 	return 0;
 }
 
-int metro_vh_start_14220(void)
+VIDEO_START( metro_14220 )
 {
 	support_8bpp = 1;
 	support_16x16 = 0;
 	has_zoom = 0;
 
 	alloc_empty_tiles();
-	metro_tiletable_old = malloc(metro_tiletable_size);
+	metro_tiletable_old = auto_malloc(metro_tiletable_size);
 
-	tilemap[0] = tilemap_create(get_tile_info_0_8bit,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,WIN_NX,WIN_NY);
-	tilemap[1] = tilemap_create(get_tile_info_1_8bit,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,WIN_NX,WIN_NY);
-	tilemap[2] = tilemap_create(get_tile_info_2_8bit,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,WIN_NX,WIN_NY);
+	bg_tilemap[0] = tilemap_create(get_tile_info_0_8bit,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,WIN_NX,WIN_NY);
+	bg_tilemap[1] = tilemap_create(get_tile_info_1_8bit,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,WIN_NX,WIN_NY);
+	bg_tilemap[2] = tilemap_create(get_tile_info_2_8bit,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,WIN_NX,WIN_NY);
 
 	tilemap_16x16[0] = NULL;
 	tilemap_16x16[1] = NULL;
 	tilemap_16x16[2] = NULL;
 
-	if (!tilemap[0] || !tilemap[1] || !tilemap[2] || !empty_tiles || !metro_tiletable_old)
-	{
-		metro_vh_stop();
+	if (!bg_tilemap[0] || !bg_tilemap[1] || !bg_tilemap[2] || !empty_tiles || !metro_tiletable_old)
 		return 1;
-	}
 
-	tilemap_set_transparent_pen(tilemap[0],0);
-	tilemap_set_transparent_pen(tilemap[1],0);
-	tilemap_set_transparent_pen(tilemap[2],0);
+	tilemap_set_transparent_pen(bg_tilemap[0],0);
+	tilemap_set_transparent_pen(bg_tilemap[1],0);
+	tilemap_set_transparent_pen(bg_tilemap[2],0);
 
-	tilemap_set_scrolldx(tilemap[0], -2, 2);
-	tilemap_set_scrolldx(tilemap[1], -2, 2);
-	tilemap_set_scrolldx(tilemap[2], -2, 2);
+	tilemap_set_scrolldx(bg_tilemap[0], -2, 2);
+	tilemap_set_scrolldx(bg_tilemap[1], -2, 2);
+	tilemap_set_scrolldx(bg_tilemap[2], -2, 2);
 
 	return 0;
 }
 
-int metro_vh_start_14300(void)
+VIDEO_START( metro_14300 )
 {
 	support_8bpp = 1;
 	support_16x16 = 1;
 	has_zoom = 0;
 
 	alloc_empty_tiles();
-	metro_tiletable_old = malloc(metro_tiletable_size);
+	metro_tiletable_old = auto_malloc(metro_tiletable_size);
 
-	tilemap[0] = tilemap_create(get_tile_info_0_8bit,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,WIN_NX,WIN_NY);
-	tilemap[1] = tilemap_create(get_tile_info_1_8bit,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,WIN_NX,WIN_NY);
-	tilemap[2] = tilemap_create(get_tile_info_2_8bit,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,WIN_NX,WIN_NY);
+	bg_tilemap[0] = tilemap_create(get_tile_info_0_8bit,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,WIN_NX,WIN_NY);
+	bg_tilemap[1] = tilemap_create(get_tile_info_1_8bit,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,WIN_NX,WIN_NY);
+	bg_tilemap[2] = tilemap_create(get_tile_info_2_8bit,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,WIN_NX,WIN_NY);
 
 	tilemap_16x16[0] = tilemap_create(get_tile_info_0_16x16_8bit,tilemap_scan_rows,TILEMAP_TRANSPARENT,16,16,WIN_NX,WIN_NY);
 	tilemap_16x16[1] = tilemap_create(get_tile_info_1_16x16_8bit,tilemap_scan_rows,TILEMAP_TRANSPARENT,16,16,WIN_NX,WIN_NY);
 	tilemap_16x16[2] = tilemap_create(get_tile_info_2_16x16_8bit,tilemap_scan_rows,TILEMAP_TRANSPARENT,16,16,WIN_NX,WIN_NY);
 
-	if (!tilemap[0] || !tilemap[1] || !tilemap[2]
+	if (!bg_tilemap[0] || !bg_tilemap[1] || !bg_tilemap[2]
 			|| !tilemap_16x16[0] || !tilemap_16x16[1] || !tilemap_16x16[2]
 			|| !empty_tiles || !metro_tiletable_old)
-	{
-		metro_vh_stop();
 		return 1;
-	}
 
-	tilemap_set_transparent_pen(tilemap[0],0);
-	tilemap_set_transparent_pen(tilemap[1],0);
-	tilemap_set_transparent_pen(tilemap[2],0);
+	tilemap_set_transparent_pen(bg_tilemap[0],0);
+	tilemap_set_transparent_pen(bg_tilemap[1],0);
+	tilemap_set_transparent_pen(bg_tilemap[2],0);
 	tilemap_set_transparent_pen(tilemap_16x16[0],0);
 	tilemap_set_transparent_pen(tilemap_16x16[1],0);
 	tilemap_set_transparent_pen(tilemap_16x16[2],0);
@@ -528,9 +489,9 @@ int metro_vh_start_14300(void)
 	return 0;
 }
 
-int  blzntrnd_vh_start(void)
+VIDEO_START( blzntrnd )
 {
-	if (metro_vh_start_14220())
+	if (video_start_metro_14220())
 		return 1;
 
 	has_zoom = 1;
@@ -541,37 +502,65 @@ int  blzntrnd_vh_start(void)
 	if (!metro_K053936_tilemap)
 		return 1;
 
-	tilemap_set_scrolldx(tilemap[0], 8, -8);
-	tilemap_set_scrolldx(tilemap[1], 8, -8);
-	tilemap_set_scrolldx(tilemap[2], 8, -8);
+	K053936_wraparound_enable(0, 0);
+	K053936_set_offset(0, -69, -21);
+
+	tilemap_set_scrolldx(bg_tilemap[0], 8, -8);
+	tilemap_set_scrolldx(bg_tilemap[1], 8, -8);
+	tilemap_set_scrolldx(bg_tilemap[2], 8, -8);
 
 	return 0;
 }
 
+VIDEO_START( gstrik2 )
+{
+	if (video_start_metro_14220())
+		return 1;
+
+	has_zoom = 1;
+
+	metro_K053936_tilemap = tilemap_create(metro_K053936_gstrik2_get_tile_info, tilemap_scan_gstrik2,
+								TILEMAP_OPAQUE, 16,16, 128, 256 );
+
+	if (!metro_K053936_tilemap)
+		return 1;
+
+	K053936_wraparound_enable(0, 0);
+	K053936_set_offset(0, -69, -19);
+
+	tilemap_set_scrolldx(bg_tilemap[0], 8, -8);
+	tilemap_set_scrolldx(bg_tilemap[1], 0, 0);
+	tilemap_set_scrolldx(bg_tilemap[2], 8, -8);
+
+	return 0;
+}
 
 /***************************************************************************
 
-								Video Registers
+                                Video Registers
 
 
-		Offset:		Bits:					Value:
+        Offset:     Bits:                   Value:
 
-		0.w									Number Of Sprites To Draw
-		2.w			fedc ba-- ---- ----		?
-					---- --98 ---- ----		Sprites Priority
-					---- ---- 7654 3210		?
-		4.w									Sprites Y Offset
-		6.w									Sprites X Offset
-		8.w									Sprites Color Codes Start
+        0.w                                 Number Of Sprites To Draw
+        2.w         f--- ---- ---- ----     Disable Sprites Layer Priority
+                    -edc ---- ---- ----
+                    ---- ba-- ---- ----     Sprites Masked Layer
+                    ---- --98 ---- ----     Sprites Priority
+                    ---- ---- 765- ----
+                    ---- ---- ---4 3210     Sprites Masked Number
+        4.w                                 Sprites Y Offset
+        6.w                                 Sprites X Offset
+        8.w                                 Sprites Color Codes Start
 
-		-
+        -
 
-		10.w		fedc ba98 76-- ----
-					---- ---- --54 ----		Layer 2 Priority (3 backmost, 0 frontmost)
-					---- ---- ---- 32--		Layer 1 Priority
-					---- ---- ---- --10		Layer 0 Priority
+        10.w        fedc ba98 76-- ----
+                    ---- ---- --54 ----     Layer 2 Priority (3 backmost, 0 frontmost)
+                    ---- ---- ---- 32--     Layer 1 Priority
+                    ---- ---- ---- --10     Layer 0 Priority
 
-		12.w								Backround Color
+        12.w                                Backround Color
 
 
 ***************************************************************************/
@@ -581,34 +570,34 @@ int  blzntrnd_vh_start(void)
 /***************************************************************************
 
 
-								Sprites Drawing
+                                Sprites Drawing
 
 
-		Offset:		Bits:					Value:
+        Offset:     Bits:                   Value:
 
-		0.w			fedc b--- ---- ----		Priority (0 = Max)
-					---- -a98 7654 3210		X
+        0.w         fedc b--- ---- ----     Priority (0 = Max)
+                    ---- -a98 7654 3210     X
 
-		2.w			fedc ba-- ---- ----		Zoom (Both X & Y)
-					---- --98 7654 3210		Y
+        2.w         fedc ba-- ---- ----     Zoom (Both X & Y)
+                    ---- --98 7654 3210     Y
 
-		4.w			f--- ---- ---- ----		Flip X
-					-e-- ---- ---- ----		Flip Y
-					--dc b--- ---- ----		Size X *
-					---- -a98 ---- ----		Size Y *
-					---- ---- 7654 ----		Color
-					---- ---- ---- 3210		Code High Bits **
+        4.w         f--- ---- ---- ----     Flip X
+                    -e-- ---- ---- ----     Flip Y
+                    --dc b--- ---- ----     Size X *
+                    ---- -a98 ---- ----     Size Y *
+                    ---- ---- 7654 ----     Color
+                    ---- ---- ---- 3210     Code High Bits **
 
-		6.w									Code Low Bits  **
+        6.w                                 Code Low Bits  **
 
 *  8 pixel increments
 ** 8x8 pixel increments
 
 ***************************************************************************/
 
-/* Draw sprites of a given priority */
+/* Draw sprites */
 
-void metro_draw_sprites(struct mame_bitmap *bitmap, int pri)
+void metro_draw_sprites(mame_bitmap *bitmap, const rectangle *cliprect)
 {
 	const int region		=	REGION_GFX1;
 
@@ -621,129 +610,152 @@ void metro_draw_sprites(struct mame_bitmap *bitmap, int pri)
 	int max_sprites			=	spriteram_size / 8;
 	int sprites				=	metro_videoregs[0x00/2] % max_sprites;
 
-	data16_t *src			=	spriteram16 + (sprites - 1) * (8/2);
-	data16_t *end			=	spriteram16;
-
 	int color_start			=	((metro_videoregs[0x08/2] & 0xf) << 4 ) + 0x100;
 
-	pri = (~pri & 0x1f) << (16-5);
+	int i, j, pri;
+	int primask[4] = { 0x0000, 0xff00, 0xff00|0xf0f0, 0xff00|0xf0f0|0xcccc };
 
-	for ( ; src >= end; src -= 8/2 )
+	UINT16 *src;
+	int inc;
+
+	if (sprites == 0)
+		return;
+
+	for (i=0; i<0x20; i++)
 	{
-		int x,y, attr,code,color,flipx,flipy, zoom, curr_pri,width,height;
-		unsigned char *gfxdata;
-
-		/* Exponential zoom table extracted from daitoride */
-		const int zoomtable[0x40] =
-		{	0xAAC,0x800,0x668,0x554,0x494,0x400,0x390,0x334,
-			0x2E8,0x2AC,0x278,0x248,0x224,0x200,0x1E0,0x1C8,
-			0x1B0,0x198,0x188,0x174,0x164,0x154,0x148,0x13C,
-			0x130,0x124,0x11C,0x110,0x108,0x100,0x0F8,0x0F0,
-			0x0EC,0x0E4,0x0DC,0x0D8,0x0D4,0x0CC,0x0C8,0x0C4,
-			0x0C0,0x0BC,0x0B8,0x0B4,0x0B0,0x0AC,0x0A8,0x0A4,
-			0x0A0,0x09C,0x098,0x094,0x090,0x08C,0x088,0x080,
-			0x078,0x070,0x068,0x060,0x058,0x050,0x048,0x040	};
-
-		x					=	src[ 0 ];
-		curr_pri			=	x & 0xf800;
-		if ( (curr_pri == 0xf800) || (curr_pri != pri) )	continue;
-		y					=	src[ 1 ];
-		attr				=	src[ 2 ];
-		code				=	src[ 3 ];
-
-		flipx				=	attr & 0x8000;
-		flipy				=	attr & 0x4000;
-		color				=   (attr & 0xf0) >> 4;
-
-		zoom				=	zoomtable[(y & 0xfc00) >> 10] << (16-8);
-
-		x					=	(x & 0x07ff) - metro_sprite_xoffs;
-		y					=	(y & 0x03ff) - metro_sprite_yoffs;
-
-		width				= (( (attr >> 11) & 0x7 ) + 1 ) * 8;
-		height				= (( (attr >>  8) & 0x7 ) + 1 ) * 8;
-
-		gfxdata		=	base_gfx + (8*8*4/8) * (((attr & 0x000f) << 16) + code);
-
-		if (flip_screen)
+		if (!(metro_videoregs[0x02/2] & 0x8000))
 		{
-			flipx = !flipx;		x = max_x - x - width;
-			flipy = !flipy;		y = max_y - y - height;
+			src = spriteram16 + (sprites - 1) * (8/2);
+			inc = -(8/2);
+		} else {
+			src = spriteram16;
+			inc = (8/2);
 		}
 
-		if (support_8bpp && color == 0xf)	/* 8bpp */
+		for (j=0; j<sprites; j++)
 		{
-			/* prepare GfxElement on the fly */
-			struct GfxElement gfx;
-			gfx.width = width;
-			gfx.height = height;
-			gfx.total_elements = 1;
-			gfx.color_granularity = 256;
-			gfx.colortable = Machine->remapped_colortable;
-			gfx.total_colors = 0x20;
-			gfx.pen_usage = NULL;
-			gfx.gfxdata = gfxdata;
-			gfx.line_modulo = width;
-			gfx.char_modulo = 0;	/* doesn't matter */
-			gfx.flags = 0;
-			if (Machine->orientation & ORIENTATION_SWAP_XY)
-				gfx.flags |= GFX_SWAPXY;
+			int x,y, attr,code,color,flipx,flipy, zoom, curr_pri,width,height;
+			unsigned char *gfxdata;
 
-			/* Bounds checking */
-			if ( (gfxdata + width * height - 1) >= gfx_max )
-				continue;
+			/* Exponential zoom table extracted from daitoride */
+			const int zoomtable[0x40] =
+			{	0xAAC,0x800,0x668,0x554,0x494,0x400,0x390,0x334,
+				0x2E8,0x2AC,0x278,0x248,0x224,0x200,0x1E0,0x1C8,
+				0x1B0,0x198,0x188,0x174,0x164,0x154,0x148,0x13C,
+				0x130,0x124,0x11C,0x110,0x108,0x100,0x0F8,0x0F0,
+				0x0EC,0x0E4,0x0DC,0x0D8,0x0D4,0x0CC,0x0C8,0x0C4,
+				0x0C0,0x0BC,0x0B8,0x0B4,0x0B0,0x0AC,0x0A8,0x0A4,
+				0x0A0,0x09C,0x098,0x094,0x090,0x08C,0x088,0x080,
+				0x078,0x070,0x068,0x060,0x058,0x050,0x048,0x040	};
 
-			drawgfxzoom(	bitmap,&gfx,
-							0,
-							color_start >> 4,
-							flipx, flipy,
-							x, y,
-							&Machine->visible_area, TRANSPARENCY_PEN, 0,
-							zoom, zoom	);
-		}
-		else
-		{
-			/* prepare GfxElement on the fly */
-			struct GfxElement gfx;
-			gfx.width = width;
-			gfx.height = height;
-			gfx.total_elements = 1;
-			gfx.color_granularity = 16;
-			gfx.colortable = Machine->remapped_colortable;
-			gfx.total_colors = 0x200;
-			gfx.pen_usage = NULL;
-			gfx.gfxdata = gfxdata;
-			gfx.line_modulo = width/2;
-			gfx.char_modulo = 0;	/* doesn't matter */
-			gfx.flags = GFX_PACKED;
-			if (Machine->orientation & ORIENTATION_SWAP_XY)
+			x					=	src[ 0 ];
+			curr_pri			=	(x & 0xf800) >> 11;
+
+			if ((curr_pri == 0x1f) || (curr_pri != i))
 			{
-				gfx.flags |= GFX_SWAPXY;
-				gfx.width = height;
-				gfx.height = width;
+				src += inc;
+				continue;
 			}
 
-			/* Bounds checking */
-			if ( (gfxdata + width/2 * height - 1) >= gfx_max )
-				continue;
+			pri = (metro_videoregs[0x02/2] & 0x0300) >> 8;
 
-			drawgfxzoom(	bitmap,&gfx,
-							0,
-							(color ^ 0x0f) + color_start,
-							flipx, flipy,
-							x, y,
-							&Machine->visible_area, TRANSPARENCY_PEN, 0,
-							zoom, zoom	);
-		}
+			if (!(metro_videoregs[0x02/2] & 0x8000))
+			{
+				if (curr_pri > (metro_videoregs[0x02/2] & 0x1f))
+					pri = (metro_videoregs[0x02/2] & 0x0c00) >> 10;
+			}
 
+			y					=	src[ 1 ];
+			attr				=	src[ 2 ];
+			code				=	src[ 3 ];
+
+			flipx				=	attr & 0x8000;
+			flipy				=	attr & 0x4000;
+			color				=   (attr & 0xf0) >> 4;
+
+			zoom				=	zoomtable[(y & 0xfc00) >> 10] << (16-8);
+
+			x					=	(x & 0x07ff) - metro_sprite_xoffs;
+			y					=	(y & 0x03ff) - metro_sprite_yoffs;
+
+			width				= (( (attr >> 11) & 0x7 ) + 1 ) * 8;
+			height				= (( (attr >>  8) & 0x7 ) + 1 ) * 8;
+
+			gfxdata		=	base_gfx + (8*8*4/8) * (((attr & 0x000f) << 16) + code);
+
+			if (flip_screen)
+			{
+				flipx = !flipx;		x = max_x - x - width;
+				flipy = !flipy;		y = max_y - y - height;
+			}
+
+			if (support_8bpp && color == 0xf)	/* 8bpp */
+			{
+				/* prepare GfxElement on the fly */
+				gfx_element gfx;
+				gfx.width = width;
+				gfx.height = height;
+				gfx.total_elements = 1;
+				gfx.color_granularity = 256;
+				gfx.colortable = Machine->remapped_colortable;
+				gfx.total_colors = 0x20;
+				gfx.pen_usage = NULL;
+				gfx.gfxdata = gfxdata;
+				gfx.line_modulo = width;
+				gfx.char_modulo = 0;	/* doesn't matter */
+				gfx.flags = 0;
+
+				/* Bounds checking */
+				if ( (gfxdata + width * height - 1) >= gfx_max )
+					continue;
+
+				pdrawgfxzoom(	bitmap,&gfx,
+								0,
+								color_start >> 4,
+								flipx, flipy,
+								x, y,
+								cliprect, TRANSPARENCY_PEN, 0,
+								zoom, zoom,
+								primask[pri]);
+			}
+			else
+			{
+				/* prepare GfxElement on the fly */
+				gfx_element gfx;
+				gfx.width = width;
+				gfx.height = height;
+				gfx.total_elements = 1;
+				gfx.color_granularity = 16;
+				gfx.colortable = Machine->remapped_colortable;
+				gfx.total_colors = 0x200;
+				gfx.pen_usage = NULL;
+				gfx.gfxdata = gfxdata;
+				gfx.line_modulo = width/2;
+				gfx.char_modulo = 0;	/* doesn't matter */
+				gfx.flags = GFX_PACKED;
+
+				/* Bounds checking */
+				if ( (gfxdata + width/2 * height - 1) >= gfx_max )
+					continue;
+
+				pdrawgfxzoom(	bitmap,&gfx,
+								0,
+								(color ^ 0x0f) + color_start,
+								flipx, flipy,
+								x, y,
+								cliprect, TRANSPARENCY_PEN, 0,
+								zoom, zoom,
+								primask[pri]);
+			}
 #if 0
 {	/* Display priority + zoom on each sprite */
-	struct DisplayText dt[2];	char buf[80];
+	char buf[80];
 	sprintf(buf, "%02X %02X",((src[ 0 ] & 0xf800) >> 11)^0x1f,((src[ 1 ] & 0xfc00) >> 10) );
-    dt[0].text = buf;	dt[0].color = UI_COLOR_NORMAL;
-    dt[0].x = x;    dt[0].y = y;    dt[1].text = 0; /* terminate array */
-	displaytext(Machine->scrbitmap,dt);		}
+	ui_draw_text(buf, x, y);
+}
 #endif
+			src += inc;
+		}
 	}
 }
 
@@ -752,27 +764,27 @@ void metro_draw_sprites(struct mame_bitmap *bitmap, int pri)
 /***************************************************************************
 
 
-								Screen Drawing
+                                Screen Drawing
 
 
 ***************************************************************************/
 
-void metro_tilemap_draw	(struct mame_bitmap *bitmap, struct tilemap *tmap, UINT32 flags, UINT32 priority,
+void metro_tilemap_draw	(mame_bitmap *bitmap, const rectangle *cliprect, tilemap *tmap, UINT32 flags, UINT32 priority,
 						 int sx, int sy, int wx, int wy)	/* scroll & window values */
 {
 #if 1
 		tilemap_set_scrollx(tmap, 0, sx - wx + (wx & 7));
 		tilemap_set_scrolly(tmap, 0, sy - wy + (wy & 7));
-		tilemap_draw(bitmap,tmap, flags, priority);
+		tilemap_draw(bitmap,cliprect,tmap, flags, priority);
 #else
 	int x,y,i;
 
 	/* sub tile placement */
-/*	sx		=	sx - (wx & ~7) + (wx & 7); */
+/*  sx      =   sx - (wx & ~7) + (wx & 7); */
 	sx		=	sx - wx;
 	sx		=	( (sx & 0x7fff) - (sx & 0x8000) ) % ((WIN_NX-1)*8);
 
-/*	sy		=	sy - (wy & ~7) + (wy & 7); */
+/*  sy      =   sy - (wy & ~7) + (wy & 7); */
 	sy		=	sy - wy;
 	sy		=	( (sy & 0x7fff) - (sy & 0x8000) ) % ((WIN_NY-1)*8);
 
@@ -783,7 +795,7 @@ void metro_tilemap_draw	(struct mame_bitmap *bitmap, struct tilemap *tmap, UINT3
 
 	for ( i = 0; i < 4 ; i++ )
 	{
-		struct rectangle clip;
+		rectangle clip;
 
 		tilemap_set_scrollx(tmap, 0, sx + ((i & 1) ? -x : 0));
 		tilemap_set_scrolly(tmap, 0, sy + ((i & 2) ? -y : 0));
@@ -807,19 +819,19 @@ void metro_tilemap_draw	(struct mame_bitmap *bitmap, struct tilemap *tmap, UINT3
 		if (clip.max_y > Machine->visible_area.max_y)	clip.max_y = Machine->visible_area.max_y;
 
 		/* The clip region's width must be a multiple of 8!
-		   This fact renderes the function useless, as far as
-		   we are concerned! */
+           This fact renderes the function useless, as far as
+           we are concerned! */
 		tilemap_set_clip(tmap, &clip);
-		tilemap_draw(bitmap,tmap, flags, priority);
+		tilemap_draw(bitmap,cliprect,tmap, flags, priority);
 	}
 #endif
 }
 
 
 /* Draw all the layers that match the given priority */
-static void draw_layers(struct mame_bitmap *bitmap, int pri, int layers_ctrl)
+static void draw_layers(mame_bitmap *bitmap, const rectangle *cliprect, int pri, int layers_ctrl)
 {
-	data16_t layers_pri = metro_videoregs[0x10/2];
+	UINT16 layers_pri = metro_videoregs[0x10/2];
 	int layer;
 
 	/* Draw all the layers with priority == pri */
@@ -828,14 +840,14 @@ static void draw_layers(struct mame_bitmap *bitmap, int pri, int layers_ctrl)
 		if ( pri == ((layers_pri >> (layer*2)) & 3) )
 		{
 			/* Scroll and Window values */
-			data16_t sy = metro_scroll[layer * 2 + 0];	data16_t sx = metro_scroll[layer * 2 + 1];
-			data16_t wy = metro_window[layer * 2 + 0];	data16_t wx = metro_window[layer * 2 + 1];
+			UINT16 sy = metro_scroll[layer * 2 + 0];	UINT16 sx = metro_scroll[layer * 2 + 1];
+			UINT16 wy = metro_window[layer * 2 + 0];	UINT16 wx = metro_window[layer * 2 + 1];
 
 			if (layers_ctrl & (1<<layer))	/* for debug */
 			{
 				/* Only *one* of tilemap_16x16 & tilemap is enabled at any given time! */
-				metro_tilemap_draw(bitmap,tilemap[layer], 0, 0, sx, sy, wx, wy);
-				if (tilemap_16x16[layer]) metro_tilemap_draw(bitmap,tilemap_16x16[layer], 0, 0, sx, sy, wx, wy);
+				metro_tilemap_draw(bitmap,cliprect,bg_tilemap[layer], 0, 1<<(3-pri), sx, sy, wx, wy);
+				if (tilemap_16x16[layer]) metro_tilemap_draw(bitmap,cliprect,tilemap_16x16[layer], 0, 1<<(3-pri), sx, sy, wx, wy);
 			}
 		}
 	}
@@ -844,7 +856,7 @@ static void draw_layers(struct mame_bitmap *bitmap, int pri, int layers_ctrl)
 
 
 /* Dirty tilemaps when the tiles set changes */
-static void dirty_tiles(int layer,data16_t *vram,data8_t *dirtyindex)
+static void dirty_tiles(int layer,UINT16 *vram,UINT8 *dirtyindex)
 {
 	int col,row;
 
@@ -854,11 +866,11 @@ static void dirty_tiles(int layer,data16_t *vram,data8_t *dirtyindex)
 		{
 			int offset = (col + metro_window[layer * 2 + 1] / 8) % BIG_NX +
 						((row + metro_window[layer * 2 + 0] / 8) % BIG_NY) * BIG_NX;
-			data16_t code = vram[offset];
+			UINT16 code = vram[offset];
 
 			if (!(code & 0x8000) && dirtyindex[(code & 0x1ff0) >> 4])
 			{
-				tilemap_mark_tile_dirty(tilemap[layer], row * WIN_NX + col );
+				tilemap_mark_tile_dirty(bg_tilemap[layer], row * WIN_NX + col );
 				if (tilemap_16x16[layer])
 					tilemap_mark_tile_dirty(tilemap_16x16[layer], row * WIN_NX + col );
 			}
@@ -867,11 +879,11 @@ static void dirty_tiles(int layer,data16_t *vram,data8_t *dirtyindex)
 }
 
 
-void metro_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( metro )
 {
-	int i,pri,sprites_pri,layers_ctrl = -1;
-	data8_t *dirtyindex;
-	data16_t screenctrl = *metro_screenctrl;
+	int i,pri,layers_ctrl = -1;
+	UINT8 *dirtyindex;
+	UINT16 screenctrl = *metro_screenctrl;
 
 	dirtyindex = malloc(metro_tiletable_size/4);
 	if (dirtyindex)
@@ -905,25 +917,26 @@ void metro_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 	metro_sprite_yoffs	=	metro_videoregs[0x04/2] - Machine->drv->screen_height / 2;
 
 	/* The background color is selected by a register */
-	fillbitmap(bitmap,Machine->pens[((metro_videoregs[0x12/2] & 0x0fff) ^ 0x0ff) + 0x1000],&Machine->visible_area);
+	fillbitmap(priority_bitmap,0,cliprect);
+	fillbitmap(bitmap,Machine->pens[((metro_videoregs[0x12/2] & 0x0fff) ^ 0x0ff) + 0x1000],cliprect);
 
-	/*	Screen Control Register:
+	/*  Screen Control Register:
 
-		f--- ---- ---- ----		?
-		-edc b--- ---- ----
-		---- -a98 ---- ----		? Leds
-		---- ---- 7--- ----		16x16 Tiles (Layer 2)
-		---- ---- -6-- ----		16x16 Tiles (Layer 1)
-		---- ---- --5- ----		16x16 Tiles (Layer 0)
-		---- ---- ---4 32--
-		---- ---- ---- --1-		? Blank Screen
-		---- ---- ---- ---0		Flip  Screen	*/
+        f--- ---- ---- ----     ?
+        -edc b--- ---- ----
+        ---- -a98 ---- ----     ? Leds
+        ---- ---- 7--- ----     16x16 Tiles (Layer 2)
+        ---- ---- -6-- ----     16x16 Tiles (Layer 1)
+        ---- ---- --5- ----     16x16 Tiles (Layer 0)
+        ---- ---- ---4 32--
+        ---- ---- ---- --1-     ? Blank Screen
+        ---- ---- ---- ---0     Flip  Screen    */
 	if (screenctrl & 2)	return;
 	flip_screen_set(screenctrl & 1);
 
 	/* If the game supports 16x16 tiles, make sure that the
-	   16x16 and 8x8 tilemaps of a given layer are not simultaneously
-	   enabled! */
+       16x16 and 8x8 tilemaps of a given layer are not simultaneously
+       enabled! */
 	if (support_16x16)
 	{
 		int layer;
@@ -932,40 +945,35 @@ void metro_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 		{
 			int big = screenctrl & (0x0020 << layer);
 
-			tilemap_set_enable(tilemap[layer],!big);
+			tilemap_set_enable(bg_tilemap[layer],!big);
 			tilemap_set_enable(tilemap_16x16[layer],big);
 		}
 	}
 
 
 #if 0
-if (keyboard_pressed(KEYCODE_Z))
+if (code_pressed(KEYCODE_Z))
 {	int msk = 0;
-	if (keyboard_pressed(KEYCODE_Q))	msk |= 1;
-	if (keyboard_pressed(KEYCODE_W))	msk |= 2;
-	if (keyboard_pressed(KEYCODE_E))	msk |= 4;
-	if (keyboard_pressed(KEYCODE_A))	msk |= 8;
+	if (code_pressed(KEYCODE_Q))	msk |= 1;
+	if (code_pressed(KEYCODE_W))	msk |= 2;
+	if (code_pressed(KEYCODE_E))	msk |= 4;
+	if (code_pressed(KEYCODE_A))	msk |= 8;
 	if (msk != 0)
-	{	fillbitmap(bitmap,0,&Machine->visible_area);
+	{	fillbitmap(bitmap,0,cliprect);
 		layers_ctrl &= msk;	}
 
-	usrintf_showmessage("l %x-%x-%x r %04x %04x %04x",
+	ui_popup("l %x-%x-%x r %04x %04x %04x",
 				(metro_videoregs[0x10/2]&0x30)>>4,(metro_videoregs[0x10/2]&0xc)>>2,metro_videoregs[0x10/2]&3,
 				metro_videoregs[0x02/2], metro_videoregs[0x12/2],
 				*metro_screenctrl);					}
 #endif
 
-	if (has_zoom) K053936_zoom_draw(bitmap);
+	if (has_zoom) K053936_0_zoom_draw(bitmap,cliprect,metro_K053936_tilemap,0,0);
 
-	/* Sprites priority wrt layers: 3..0 (low..high) */
-	sprites_pri	=	(metro_videoregs[0x02/2] & 0x0300) >> 8;
 
-	for (pri = 3; pri >=0; pri--)
-	{
-		draw_layers(bitmap,pri,layers_ctrl);
+	for (pri=3; pri>=0; pri--)
+		draw_layers(bitmap,cliprect,pri,layers_ctrl);
 
-		if ((layers_ctrl & 8) && (sprites_pri == pri))
-			for (i = 0; i < 0x20; i++)
-				metro_draw_sprites(bitmap, i);
-	}
+	if (layers_ctrl & 0x08)
+		metro_draw_sprites(bitmap,cliprect);
 }
