@@ -9,18 +9,18 @@ static int tile_palbank;
 static int sprite_palbank;
 static int scrollx[30];
 
-static struct tilemap *bg_tilemap;
+static tilemap *bg_tilemap;
 
 
 
-void spdodgeb_vh_convert_color_prom(unsigned char *palette, unsigned short *colortable,const unsigned char *color_prom)
+PALETTE_INIT( spdodgeb )
 {
 	int i;
 
 
 	for (i = 0;i < Machine->drv->total_colors;i++)
 	{
-		int bit0,bit1,bit2,bit3;
+		int bit0,bit1,bit2,bit3,r,g,b;
 
 
 		/* red component */
@@ -28,20 +28,21 @@ void spdodgeb_vh_convert_color_prom(unsigned char *palette, unsigned short *colo
 		bit1 = (color_prom[0] >> 1) & 0x01;
 		bit2 = (color_prom[0] >> 2) & 0x01;
 		bit3 = (color_prom[0] >> 3) & 0x01;
-		*(palette++) = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
+		r = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
 		/* green component */
 		bit0 = (color_prom[0] >> 4) & 0x01;
 		bit1 = (color_prom[0] >> 5) & 0x01;
 		bit2 = (color_prom[0] >> 6) & 0x01;
 		bit3 = (color_prom[0] >> 7) & 0x01;
-		*(palette++) = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
+		g = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
 		/* blue component */
 		bit0 = (color_prom[Machine->drv->total_colors] >> 0) & 0x01;
 		bit1 = (color_prom[Machine->drv->total_colors] >> 1) & 0x01;
 		bit2 = (color_prom[Machine->drv->total_colors] >> 2) & 0x01;
 		bit3 = (color_prom[Machine->drv->total_colors] >> 3) & 0x01;
-		*(palette++) = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
+		b = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
 
+		palette_set_color(i,r,g,b);
 		color_prom++;
 	}
 }
@@ -77,7 +78,7 @@ static void get_bg_tile_info(int tile_index)
 
 ***************************************************************************/
 
-int spdodgeb_vh_start(void)
+VIDEO_START( spdodgeb )
 {
 	bg_tilemap = tilemap_create(get_bg_tile_info,background_scan,TILEMAP_OPAQUE,8,8,64,32);
 
@@ -98,35 +99,33 @@ int spdodgeb_vh_start(void)
 
 static int lastscroll;
 
-int spdodgeb_interrupt(void)
+INTERRUPT_GEN( spdodgeb_interrupt )
 {
-	int line = 33 - cpu_getiloops();
+	int iloop = cpu_getiloops();
 
-	if (line < 30)
+	if (iloop > 1 && iloop < 32)
 	{
-		scrollx[line] = lastscroll;
-		return M6502_INT_IRQ;
+		scrollx[31-iloop] = lastscroll;
+		cpunum_set_input_line(0, M6502_IRQ_LINE, HOLD_LINE);
 	}
-	else if (line == 30)	/* vblank */
-		return M6502_INT_NMI;
-	else 	/* skip 31 32 33 to allow vblank to finish */
-		return ignore_interrupt();
+	else if (!iloop)
+		cpunum_set_input_line(0, INPUT_LINE_NMI, PULSE_LINE);
 }
 
-WRITE_HANDLER( spdodgeb_scrollx_lo_w )
+WRITE8_HANDLER( spdodgeb_scrollx_lo_w )
 {
 	lastscroll = (lastscroll & 0x100) | data;
 }
 
-WRITE_HANDLER( spdodgeb_ctrl_w )
+WRITE8_HANDLER( spdodgeb_ctrl_w )
 {
-	const UINT8 *rom = memory_region(REGION_CPU1);
+	UINT8 *rom = memory_region(REGION_CPU1);
 
 	/* bit 0 = flip screen */
 	flip_screen_set(data & 0x01);
 
 	/* bit 1 = ROM bank switch */
-	cpu_setbank(1,rom + 0x10000 + 0x4000 * ((~data & 0x02) >> 1));
+	memory_set_bankptr(1,rom + 0x10000 + 0x4000 * ((~data & 0x02) >> 1));
 
 	/* bit 2 = scroll high bit */
 	lastscroll = (lastscroll & 0x0ff) | ((data & 0x04) << 6);
@@ -142,7 +141,7 @@ WRITE_HANDLER( spdodgeb_ctrl_w )
 	sprite_palbank = (data & 0xc0) >> 6;
 }
 
-WRITE_HANDLER( spdodgeb_videoram_w )
+WRITE8_HANDLER( spdodgeb_videoram_w )
 {
 	if (spdodgeb_videoram[offset] != data)
 	{
@@ -161,33 +160,31 @@ WRITE_HANDLER( spdodgeb_videoram_w )
 
 #define DRAW_SPRITE( order, sx, sy ) drawgfx( bitmap, gfx, \
 					(which+order),color+ 8 * sprite_palbank,flipx,flipy,sx,sy, \
-					clip,TRANSPARENCY_PEN,0);
+					cliprect,TRANSPARENCY_PEN,0);
 
-static void draw_sprites( struct mame_bitmap *bitmap )
+static void draw_sprites( mame_bitmap *bitmap, const rectangle *cliprect )
 {
-	const struct rectangle *clip = &Machine->visible_area;
-	const struct GfxElement *gfx = Machine->gfx[1];
+	const gfx_element *gfx = Machine->gfx[1];
 	unsigned char *src;
 	int i;
 
 	src = spriteram;
 
-/*	240-Y    S|X|CLR|WCH WHICH    240-X
-	xxxxxxxx x|x|xxx|xxx xxxxxxxx xxxxxxxx
+/*  240-SY   Z|F|CLR|WCH WHICH    SX
+    xxxxxxxx x|x|xxx|xxx xxxxxxxx xxxxxxxx
 */
-
-
 	for (i = 0;i < spriteram_size;i += 4)
 	{
 		int attr = src[i+1];
 		int which = src[i+2]+((attr & 0x07)<<8);
-		int sx = ((src[i+3] + 8) & 0xff) - 8;
+		int sx = src[i+3];
 		int sy = 240 - src[i];
 		int size = (attr & 0x80) >> 7;
 		int color = (attr & 0x38) >> 3;
 		int flipx = ~attr & 0x40;
 		int flipy = 0;
 		int dy = -16;
+		int cy;
 
 		if (flip_screen)
 		{
@@ -198,14 +195,20 @@ static void draw_sprites( struct mame_bitmap *bitmap )
 			dy = -dy;
 		}
 
+		if (sx < -8) sx += 256; else if (sx > 248) sx -= 256;
+
 		switch (size)
 		{
 			case 0: /* normal */
+			if (sy < -8) sy += 256; else if (sy > 248) sy -= 256;
 			DRAW_SPRITE(0,sx,sy);
 			break;
 
 			case 1: /* double y */
-			DRAW_SPRITE(0,sx,sy + dy);
+			if (flip_screen) { if (sy > 240) sy -= 256; } else { if (sy < 0) sy += 256; }
+			cy = sy + dy;
+			which &= ~1;
+			DRAW_SPRITE(0,sx,cy);
 			DRAW_SPRITE(1,sx,sy);
 			break;
 		}
@@ -215,7 +218,7 @@ static void draw_sprites( struct mame_bitmap *bitmap )
 #undef DRAW_SPRITE
 
 
-void spdodgeb_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( spdodgeb )
 {
 	int i;
 
@@ -231,6 +234,6 @@ void spdodgeb_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 			tilemap_set_scrollx(bg_tilemap,i+1,scrollx[i]+5);
 	}
 
-	tilemap_draw(bitmap,bg_tilemap,0,0);
-	draw_sprites(bitmap);
+	tilemap_draw(bitmap,cliprect,bg_tilemap,0,0);
+	draw_sprites(bitmap,cliprect);
 }
