@@ -11,13 +11,13 @@
 #include "state.h"
 
 
-static struct rectangle spritevisiblearea =
+static rectangle spritevisiblearea =
 {
 	2*8, 32*8-1,
 	2*8, 30*8-1
 };
 
-static struct rectangle spritevisibleareaflipx =
+static rectangle spritevisibleareaflipx =
 {
 	0*8, 30*8-1,
 	2*8, 30*8-1
@@ -37,9 +37,9 @@ static unsigned char palbank[2];
 static int palette_bank;
 
 
-int wiz_vh_start(void)
+VIDEO_START( wiz )
 {
-	if (generic_vh_start())
+	if (video_start_generic())
 		return 1;
 
 	state_save_register_UINT8("wiz", 0, "char_bank",   char_bank,   2);
@@ -64,37 +64,39 @@ int wiz_vh_start(void)
   bit 0 -- 1  kohm resistor  -- RED/GREEN/BLUE
 
 ***************************************************************************/
-void wiz_vh_convert_color_prom(unsigned char *palette, unsigned short *colortable,const unsigned char *color_prom)
+PALETTE_INIT( wiz )
 {
 	int i;
 
 
 	for (i = 0;i < Machine->drv->total_colors;i++)
 	{
-		int bit0,bit1,bit2,bit3;
+		int bit0,bit1,bit2,bit3,r,g,b;
 
 
 		bit0 = (color_prom[0] >> 0) & 0x01;
 		bit1 = (color_prom[0] >> 1) & 0x01;
 		bit2 = (color_prom[0] >> 2) & 0x01;
 		bit3 = (color_prom[0] >> 3) & 0x01;
-		*(palette++) = 0x0e * bit0 + 0x1f * bit1 + 0x42 * bit2 + 0x90 * bit3;
+		r = 0x0e * bit0 + 0x1f * bit1 + 0x42 * bit2 + 0x90 * bit3;
 		bit0 = (color_prom[Machine->drv->total_colors] >> 0) & 0x01;
 		bit1 = (color_prom[Machine->drv->total_colors] >> 1) & 0x01;
 		bit2 = (color_prom[Machine->drv->total_colors] >> 2) & 0x01;
 		bit3 = (color_prom[Machine->drv->total_colors] >> 3) & 0x01;
-		*(palette++) = 0x0e * bit0 + 0x1f * bit1 + 0x42 * bit2 + 0x90 * bit3;
+		g = 0x0e * bit0 + 0x1f * bit1 + 0x42 * bit2 + 0x90 * bit3;
 		bit0 = (color_prom[2*Machine->drv->total_colors] >> 0) & 0x01;
 		bit1 = (color_prom[2*Machine->drv->total_colors] >> 1) & 0x01;
 		bit2 = (color_prom[2*Machine->drv->total_colors] >> 2) & 0x01;
 		bit3 = (color_prom[2*Machine->drv->total_colors] >> 3) & 0x01;
-		*(palette++) = 0x0e * bit0 + 0x1f * bit1 + 0x42 * bit2 + 0x90 * bit3;
+		b = 0x0e * bit0 + 0x1f * bit1 + 0x42 * bit2 + 0x90 * bit3;
+
+		palette_set_color(i,r,g,b);
 
 		color_prom++;
 	}
 }
 
-WRITE_HANDLER( wiz_attributes_w )
+WRITE8_HANDLER( wiz_attributes_w )
 {
 	if ((offset & 1) && wiz_attributesram[offset] != data)
 	{
@@ -110,7 +112,7 @@ WRITE_HANDLER( wiz_attributes_w )
 	wiz_attributesram[offset] = data;
 }
 
-WRITE_HANDLER( wiz_palettebank_w )
+WRITE8_HANDLER( wiz_palettebank_w )
 {
 	if (palbank[offset] != (data & 1))
 	{
@@ -121,12 +123,12 @@ WRITE_HANDLER( wiz_palettebank_w )
 	}
 }
 
-WRITE_HANDLER( wiz_bgcolor_w )
+WRITE8_HANDLER( wiz_bgcolor_w )
 {
 	bgpen = data;
 }
 
-WRITE_HANDLER( wiz_char_bank_select_w )
+WRITE8_HANDLER( wiz_char_bank_select_w )
 {
 	if (char_bank[offset] != (data & 1))
 	{
@@ -135,7 +137,7 @@ WRITE_HANDLER( wiz_char_bank_select_w )
 	}
 }
 
-WRITE_HANDLER( wiz_flipx_w )
+WRITE8_HANDLER( wiz_flipx_w )
 {
     if (flipx != data)
     {
@@ -146,7 +148,7 @@ WRITE_HANDLER( wiz_flipx_w )
 }
 
 
-WRITE_HANDLER( wiz_flipy_w )
+WRITE8_HANDLER( wiz_flipy_w )
 {
     if (flipy != data)
     {
@@ -156,7 +158,7 @@ WRITE_HANDLER( wiz_flipy_w )
     }
 }
 
-static void draw_background(struct mame_bitmap *bitmap, int bank, int colortype)
+static void draw_background(mame_bitmap *bitmap, int bank, int colortype)
 {
 	int offs;
 
@@ -196,7 +198,7 @@ static void draw_background(struct mame_bitmap *bitmap, int bank, int colortype)
 	}
 }
 
-static void draw_foreground(struct mame_bitmap *bitmap, int colortype)
+static void draw_foreground(mame_bitmap *bitmap, int colortype)
 {
 	int offs;
 
@@ -235,8 +237,8 @@ static void draw_foreground(struct mame_bitmap *bitmap, int colortype)
 	}
 }
 
-static void draw_sprites(struct mame_bitmap *bitmap, unsigned char* sprite_ram,
-                         int bank, const struct rectangle* visible_area)
+static void draw_sprites(mame_bitmap *bitmap, unsigned char* sprite_ram,
+                         int bank, const rectangle* visible_area)
 {
 	int offs;
 
@@ -269,10 +271,20 @@ static void draw_sprites(struct mame_bitmap *bitmap, unsigned char* sprite_ram,
   the main emulation engine.
 
 ***************************************************************************/
-void wiz_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+
+VIDEO_UPDATE( kungfut )
+{
+	fillbitmap(bitmap,Machine->pens[bgpen],&Machine->visible_area);
+	draw_background(bitmap, 2 + char_bank[0] , 0);
+	draw_foreground(bitmap, 0);
+	draw_sprites(bitmap, spriteram_2, 4, &Machine->visible_area);
+	draw_sprites(bitmap, spriteram  , 5, &Machine->visible_area);
+}
+
+VIDEO_UPDATE( wiz )
 {
 	int bank;
-	const struct rectangle* visible_area;
+	const rectangle* visible_area;
 
 	fillbitmap(bitmap,Machine->pens[bgpen],&Machine->visible_area);
 	draw_background(bitmap, 2 + ((char_bank[0] << 1) | char_bank[1]), 0);
@@ -287,7 +299,7 @@ void wiz_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 }
 
 
-void stinger_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( stinger )
 {
 	fillbitmap(bitmap,Machine->pens[bgpen],&Machine->visible_area);
 	draw_background(bitmap, 2 + char_bank[0], 1);
